module CrvApiClient::Api::Animals

  module RsAnimalMappingRegistry
    EncodedRegistry = ::SOAP::Mapping::EncodedRegistry.new
    LiteralRegistry = ::SOAP::Mapping::LiteralRegistry.new
    NsAnimal = "http://ws.crvholding.com/animal/"
    NsAnimalMessages = "http://ws.crvholding.com/animalMessages/"
    NsAnimalTypes = "http://ws.crvholding.com/animalTypes/"
    NsCommon = "http://ws.crvholding.com/common/"
    NsCommonTypes = "http://ws.crvholding.com/commonTypes/"
    NsDictionary = "http://ws.crvholding.com/dictionary/"
    NsDictionaryTypes = "http://ws.crvholding.com/dictionaryTypes/"
    NsParticipant = "http://ws.crvholding.com/participant/"
    NsParticipantTypes = "http://ws.crvholding.com/participantTypes/"

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::ModifyAnimalManagementRequestType,
        :schema_type => XSD::QName.new(NsAnimalMessages, "modifyAnimalManagementRequestType"),
        :schema_element => [
            ["participantId", "CrvApiClient::Api::Animals::ParticipantId"],
            ["animalManagement", "CrvApiClient::Api::Animals::AnimalManagement[]", [1, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::AddPlannedDepartureRequestType,
        :schema_type => XSD::QName.new(NsAnimalMessages, "addPlannedDepartureRequestType"),
        :schema_element => [
            ["keeper", "CrvApiClient::Api::Animals::ParticipantId"],
            ["animalSupplyChainValue", "CrvApiClient::Api::Animals::AnimalSupplyChainValue[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::AnimalSupplyChainValue,
        :schema_type => XSD::QName.new(NsAnimalMessages, "animalSupplyChainValue"),
        :schema_element => [
            ["animalSupplyId", "CrvApiClient::Api::Animals::AnimalSupplyId"],
            ["chainValue", "CrvApiClient::Api::Animals::ChainValue", [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::DeletePlannedDepartureRequestType,
        :schema_type => XSD::QName.new(NsAnimalMessages, "deletePlannedDepartureRequestType"),
        :schema_element => [
            ["keeper", "CrvApiClient::Api::Animals::ParticipantId"],
            ["animalSupplyId", "CrvApiClient::Api::Animals::AnimalSupplyId[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::AnimalSupplyPlannedDeparture,
        :schema_type => XSD::QName.new(NsAnimalMessages, "animalSupplyPlannedDeparture"),
        :schema_element => [
            ["animalSupplyId", "CrvApiClient::Api::Animals::AnimalSupplyId"],
            ["postpone", "CrvApiClient::Api::Animals::DateReason", [0, 1]],
            ["refusal", "CrvApiClient::Api::Animals::DateReason", [0, 1]],
            ["departure", "CrvApiClient::Api::Animals::DateReason", [0, 1]],
            ["chainValueStatus", "CrvApiClient::Api::Animals::ChainValueStatus", [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::ChainValueStatus,
        :schema_type => XSD::QName.new(NsAnimalMessages, "chainValueStatus"),
        :schema_element => [
            ["chainValue", "CrvApiClient::Api::Animals::ChainValue"],
            ["chainStatus", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "chainStatus")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::GetAverageHerdWeightRequestType,
        :schema_type => XSD::QName.new(NsAnimalMessages, "getAverageHerdWeightRequestType"),
        :schema_element => [
            ["keeper", "CrvApiClient::Api::Animals::ParticipantId"],
            ["year", nil, [0, 1]],
            ["quarter", nil, [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::GetAverageHerdWeightResponseType,
        :schema_type => XSD::QName.new(NsAnimalMessages, "getAverageHerdWeightResponseType"),
        :schema_element => [
            ["averageHerdWeightResult", "CrvApiClient::Api::Animals::AverageHerdWeight"]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::ListPlannedDepartureRequestType,
        :schema_type => XSD::QName.new(NsAnimalMessages, "listPlannedDepartureRequestType"),
        :schema_element => [
            ["keeper", "CrvApiClient::Api::Animals::ParticipantId"],
            ["period", "CrvApiClient::Api::Animals::PeriodRange"],
            ["supplyType", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "supplyType")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::ListPlannedDepartureResponseType,
        :schema_type => XSD::QName.new(NsAnimalMessages, "listPlannedDepartureResponseType"),
        :schema_element => [
            ["keeper", "CrvApiClient::Api::Animals::ParticipantId"],
            ["animalSupplyPlannedDeparture", "CrvApiClient::Api::Animals::AnimalSupplyPlannedDeparture[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::ListFoodChainInformationRequestType,
        :schema_type => XSD::QName.new(NsAnimalMessages, "listFoodChainInformationRequestType"),
        :schema_element => [
            ["chainType", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "chainType")]],
            ["animal", "CrvApiClient::Api::Animals::AnimalId[]", [1, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::ListFoodChainInformationResponseType,
        :schema_type => XSD::QName.new(NsAnimalMessages, "listFoodChainInformationResponseType"),
        :schema_element => [
            ["animalChainValue", "CrvApiClient::Api::Animals::AnimalChainValue[]", [1, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::AnimalChainValue,
        :schema_type => XSD::QName.new(NsAnimalMessages, "animalChainValue"),
        :schema_element => [
            ["animal", "CrvApiClient::Api::Animals::AnimalId"],
            ["chainValue", "CrvApiClient::Api::Animals::ChainValue", [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::ListPlannedArrivalRequestType,
        :schema_type => XSD::QName.new(NsAnimalMessages, "listPlannedArrivalRequestType"),
        :schema_element => [
            ["customer", "CrvApiClient::Api::Animals::ParticipantId"],
            ["source", "CrvApiClient::Api::Animals::ParticipantId"],
            ["period", "CrvApiClient::Api::Animals::PeriodRange_"],
            ["supplyType", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "supplyType")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::ListPlannedArrivalResponseType,
        :schema_type => XSD::QName.new(NsAnimalMessages, "listPlannedArrivalResponseType"),
        :schema_element => [
            ["plannedArrival", "CrvApiClient::Api::Animals::PlannedArrival[]", [0, nil]],
            ["addresses", "CrvApiClient::Api::Animals::Addresses[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::ModifyPlannedArrivalRequestType,
        :schema_type => XSD::QName.new(NsAnimalMessages, "modifyPlannedArrivalRequestType"),
        :schema_element => [
            ["customer", "CrvApiClient::Api::Animals::ParticipantId"],
            ["animalArrivalDetail", "CrvApiClient::Api::Animals::AnimalArrivalDetail[]", [1, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::ListHerdPedigreeRequestType,
        :schema_type => XSD::QName.new(NsAnimalMessages, "listHerdPedigreeRequestType"),
        :schema_element => [
            ["keeper", "CrvApiClient::Api::Animals::ParticipantId"]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::ListHerdPedigreeResponseType,
        :schema_type => XSD::QName.new(NsAnimalMessages, "listHerdPedigreeResponseType"),
        :schema_element => [
            ["keeper", "CrvApiClient::Api::Animals::ParticipantId"],
            ["animalPedigree", "CrvApiClient::Api::Animals::AnimalPedigree[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::LocalTime,
        :schema_type => XSD::QName.new(NsCommonTypes, "localTime"),
        :schema_element => [
            ["hourOfDay", "SOAP::SOAPInt"],
            ["minuteOfHour", "SOAP::SOAPInt"]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::LocalDate,
        :schema_type => XSD::QName.new(NsCommonTypes, "localDate"),
        :schema_element => [
            ["dayOfMonth", "SOAP::SOAPInt"],
            ["monthOfYear", "SOAP::SOAPInt"],
            ["year", "SOAP::SOAPInt"]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::PeriodRange,
        :schema_type => XSD::QName.new(NsCommonTypes, "periodRange"),
        :schema_element => [
            ["beginDate", [nil, XSD::QName.new(NsCommon, "beginDate")], [0, 1]],
            ["endDate", [nil, XSD::QName.new(NsCommon, "endDate")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::ContextMessage,
        :schema_type => XSD::QName.new(NsCommonTypes, "contextMessage"),
        :schema_element => [
            ["sessionId", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "sessionId")], [0, 1]],
            ["processId", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "processId")], [0, 1]],
            ["instanceId", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "instanceId")], [0, 1]],
            ["username", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "username")], [0, 1]],
            ["userType", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "userType")], [0, 1]],
            ["password", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "password")], [0, 1]],
            ["organisation", "CrvApiClient::Api::Animals::ParticipantId", [0, 1]],
            ["provider", "CrvApiClient::Api::Animals::ParticipantId", [0, 1]],
            ["customer", "CrvApiClient::Api::Animals::ParticipantId", [0, 1]],
            ["keeper", "CrvApiClient::Api::Animals::ParticipantId", [0, 1]],
            ["animal", "CrvApiClient::Api::Animals::AnimalId", [0, 1]],
            ["processCode", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "processCode")], [0, 1]],
            ["messageSource", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "messageSource")], [0, 1]],
            ["languageCode", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "languageCode")], [0, 1]],
            ["timeZone", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "timeZone")], [0, 1]],
            ["contextMessageDetail", "CrvApiClient::Api::Animals::ContextMessageDetail[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::ContextMessageDetail,
        :schema_type => XSD::QName.new(NsCommonTypes, "contextMessageDetail"),
        :schema_element => [
            ["contextCode", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "contextCode")], [0, 1]],
            ["contextValue", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "contextValue")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::ServiceMessage,
        :schema_type => XSD::QName.new(NsCommonTypes, "serviceMessage"),
        :schema_element => [
            ["serviceStatus", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "serviceStatus")]],
            ["messageCode", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "messageCode")], [0, 1]],
            ["messageText", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "messageText")], [0, 1]],
            ["messageType", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "messageType")], [0, 1]],
            ["sourceType", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "sourceType")], [0, 1]],
            ["sourceCode", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "sourceCode")], [0, 1]],
            ["serviceMessageDetail", "CrvApiClient::Api::Animals::ServiceMessageDetail[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::ServiceMessageDetail,
        :schema_type => XSD::QName.new(NsCommonTypes, "serviceMessageDetail"),
        :schema_element => [
            ["serviceStatus", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "serviceStatus")], [0, 1]],
            ["codeDetail", "CrvApiClient::Api::Animals::CodeDetail[]", [0, nil]],
            ["messageCode", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "messageCode")], [0, 1]],
            ["messageText", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "messageText")], [0, 1]],
            ["messageType", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "messageType")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::CodeDetail,
        :schema_type => XSD::QName.new(NsCommonTypes, "codeDetail"),
        :schema_element => [
            ["keyId", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "keyId")], [0, 1]],
            ["keyValue", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "keyValue")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::SendNotificationRequestType,
        :schema_type => XSD::QName.new(NsCommonTypes, "sendNotificationRequestType"),
        :schema_element => [
            ["notificationType", ["CrvApiClient::Api::Animals::NotificationType", XSD::QName.new(NsCommon, "notificationType")], [0, 1]],
            ["notificationMessage", "CrvApiClient::Api::Animals::NotificationMessageType[]", [0, nil]],
            ["email", "CrvApiClient::Api::Animals::EmailType[]", [0, nil]],
            ["fax", "CrvApiClient::Api::Animals::FaxType[]", [0, nil]],
            ["sms", "CrvApiClient::Api::Animals::SmsType[]", [0, nil]],
            ["voice", "CrvApiClient::Api::Animals::VoiceType[]", [0, nil]],
            ["pager", "CrvApiClient::Api::Animals::PagerType[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::NotificationMessageType,
        :schema_type => XSD::QName.new(NsCommonTypes, "notificationMessageType"),
        :schema_element => [
            ["messageCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "messageCode")], [0, 1]],
            ["languageCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "languageCode")], [0, 1]],
            ["messageParameter", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "messageParameter")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::EmailType,
        :schema_type => XSD::QName.new(NsCommonTypes, "emailType"),
        :schema_element => [
            ["mailTo", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "mailTo")], [0, 1]],
            ["mailCc", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "mailCc")], [0, 1]],
            ["mailBcc", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "mailBcc")], [0, 1]],
            ["mailReplyTo", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "mailReplyTo")], [0, 1]],
            ["subject", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "subject")], [0, 1]],
            ["textBody", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "textBody")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::FaxType,
        :schema_type => XSD::QName.new(NsCommonTypes, "faxType"),
        :schema_element => [
            ["faxNr", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "faxNr")], [0, 1]],
            ["coverPage", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "coverPage")], [0, 1]],
            ["textBody", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "textBody")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::SmsType,
        :schema_type => XSD::QName.new(NsCommonTypes, "smsType"),
        :schema_element => [
            ["fromNr", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "fromNr")], [0, 1]],
            ["telNr", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "telNr")], [0, 1]],
            ["subject", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "subject")], [0, 1]],
            ["textBody", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "textBody")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::VoiceType,
        :schema_type => XSD::QName.new(NsCommonTypes, "voiceType"),
        :schema_element => [
            ["telNr", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "telNr")], [0, 1]],
            ["textBody", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "textBody")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::PagerType,
        :schema_type => XSD::QName.new(NsCommonTypes, "pagerType"),
        :schema_element => [
            ["fromNr", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "fromNr")], [0, 1]],
            ["pagerNr", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "pagerNr")], [0, 1]],
            ["textBody", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "textBody")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::GetLabel,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "getLabel"),
        :schema_element => [
            ["componentCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "componentCode")], [0, 1]],
            ["itemName", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "itemName")], [0, 1]],
            ["itemType", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "itemType")], [0, 1]],
            ["languageCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "languageCode")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::Component,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "component"),
        :schema_element => [
            ["componentCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "componentCode")], [0, 1]],
            ["processCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "processCode")], [0, 1]],
            ["componentType", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "componentType")], [0, 1]],
            ["componentName", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "componentName")], [0, 1]],
            ["componentItem", "CrvApiClient::Api::Animals::ComponentItem[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::ComponentItem,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "componentItem"),
        :schema_element => [
            ["item", "CrvApiClient::Api::Animals::Item[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::Item,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "item"),
        :schema_element => [
            ["itemName", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "itemName")], [0, 1]],
            ["moduleCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "moduleCode")], [0, 1]],
            ["itemType", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "itemType")], [0, 1]],
            ["itemLng", "CrvApiClient::Api::Animals::ItemLng[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::ItemLng,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "itemLng"),
        :schema_element => [
            ["languageCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "languageCode")], [0, 1]],
            ["itemLabel", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "itemLabel")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::GetSystemMessage,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "getSystemMessage"),
        :schema_element => [
            ["messageCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "messageCode")], [0, 1]],
            ["languageCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "languageCode")], [0, 1]],
            ["messageParameter", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "messageParameter")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::SystemMessage,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "systemMessage"),
        :schema_element => [
            ["message", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "message")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::ListDomain,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "listDomain"),
        :schema_element => [
            ["domain", "CrvApiClient::Api::Animals::Domain[]", [0, nil]],
            ["languageCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "languageCode")], [0, 1]],
            ["representationType", ["CrvApiClient::Api::Animals::RepresentationType", XSD::QName.new(NsDictionary, "representationType")], [0, 1]],
            ["actual", ["CrvApiClient::Api::Animals::BooleanType", XSD::QName.new(NsDictionary, "actual")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::DomainValue,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "domainValue"),
        :schema_element => [
            ["domainCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "domainCode")]],
            ["columnValue", "CrvApiClient::Api::Animals::ColumnValue[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::ColumnValue,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "columnValue"),
        :schema_element => [
            ["value", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "value")], [0, 1]],
            ["representation", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "representation")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::Domain,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "domain"),
        :schema_element => [
            ["domainCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "domainCode")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::TimePeriod,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "timePeriod"),
        :schema_element => [
            ["beginDate", [nil, XSD::QName.new(NsCommon, "beginDate")], [0, 1]],
            ["beginTime", [nil, XSD::QName.new(NsCommon, "beginTime")], [0, 1]],
            ["endDate", [nil, XSD::QName.new(NsCommon, "endDate")], [0, 1]],
            ["endTime", [nil, XSD::QName.new(NsCommon, "endTime")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::IntervalId,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "intervalId"),
        :schema_element => [
            ["nr", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "nr")]],
            ["nrType", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "nrType")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::AnimalNumberCountry,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "animalNumberCountry"),
        :schema_element => [
            ["countryCd", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "countryCd")]],
            ["animalNrLength", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "animalNrLength")]],
            ["animalNrAlphanumeric", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "animalNrAlphanumeric")]],
            ["sortingOrder", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "sortingOrder")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::HourCode,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "hourCode"),
        :schema_element => [
            ["hourCd", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "hourCd")]],
            ["description", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "description")]],
            ["hourMutateAllowed", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "hourMutateAllowed")]],
            ["hourNecessary", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "hourNecessary")]],
            ["addressMutateAllowed", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "addressMutateAllowed")]],
            ["addressNecessary", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "addressNecessary")]],
            ["activityMutateAllowed", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "activityMutateAllowed")]],
            ["activityNecessary", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "activityNecessary")]],
            ["kilometresMutateAllowed", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "kilometresMutateAllowed")]],
            ["kilometresNecessary", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "kilometresNecessary")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::Parameter,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "parameter"),
        :schema_element => [
            ["parameterName", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "parameterName")]],
            ["value", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "value")]],
            ["valueDescription", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "valueDescription")]],
            ["default", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "default")]],
            ["sortingOrder", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "sortingOrder")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::AnimalId,
        :schema_type => XSD::QName.new(NsAnimalTypes, "animalId"),
        :schema_element => [
            ["animalNumber", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalNumber")]],
            ["animalNumberType", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalNumberType")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::AnimalDetailsBirth,
        :schema_type => XSD::QName.new(NsAnimalTypes, "animalDetailsBirth"),
        :schema_element => [
            ["animalId", "CrvApiClient::Api::Animals::AnimalId", [0, 1]],
            ["animalNumberShort", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalNumberShort")], [0, 1]],
            ["sex", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "sex")], [0, 1]],
            ["colourHair", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "colourHair")], [0, 1]],
            ["birthDate", [nil, XSD::QName.new(NsAnimal, "birthDate")], [0, 1]],
            ["animalName", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalName")], [0, 1]],
            ["surrogateDam", "CrvApiClient::Api::Animals::AnimalId", [0, 1]],
            ["dam", "CrvApiClient::Api::Animals::AnimalId", [0, 1]],
            ["sire", "CrvApiClient::Api::Animals::AnimalId", [0, 1]],
            ["breedComposition", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "breedComposition")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::Animal,
        :schema_type => XSD::QName.new(NsAnimalTypes, "animal"),
        :schema_element => [
            ["animalId", "CrvApiClient::Api::Animals::AnimalId"],
            ["animalNumberShort", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalNumberShort")], [0, 1]],
            ["sex", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "sex")]],
            ["colourHair", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "colourHair")], [0, 1]],
            ["birthDate", [nil, XSD::QName.new(NsAnimal, "birthDate")]],
            ["deathDate", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "deathDate")], [0, 1]],
            ["animalName", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalName")], [0, 1]],
            ["breedComposition", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "breedComposition")], [0, 1]],
            ["redFactor", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "redFactor")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::AnimalManagement,
        :schema_type => XSD::QName.new(NsAnimalTypes, "animalManagement"),
        :schema_element => [
            ["animalId", "CrvApiClient::Api::Animals::AnimalId"],
            ["animalName", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalName")], [0, 1]],
            ["farmersAnimalNr", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "farmersAnimalNr")], [0, 1]],
            ["animalGroupNr", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalGroupNr")], [0, 1]],
            ["productionPurposeDate", [nil, XSD::QName.new(NsAnimal, "productionPurposeDate")], [0, 1]],
            ["productionPurpose", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "productionPurpose")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::AnimalPedigree,
        :schema_type => XSD::QName.new(NsAnimalTypes, "animalPedigree"),
        :schema_element => [
            ["animal", "CrvApiClient::Api::Animals::AnimalId", [0, 1]],
            ["animalNrShort", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalNrShort")], [0, 1]],
            ["animalName", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalName")], [0, 1]],
            ["farmersAnimalNr", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "farmersAnimalNr")], [0, 1]],
            ["sex", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "sex")], [0, 1]],
            ["birthDate", [nil, XSD::QName.new(NsAnimal, "birthDate")], [0, 1]],
            ["colourHair", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "colourHair")], [0, 1]],
            ["pedigree", "CrvApiClient::Api::Animals::Pedigree", [0, 1]],
            ["participantAnimal", "CrvApiClient::Api::Animals::ParticipantAnimalId[]", [0, nil]],
            ["groupCode", "CrvApiClient::Api::Animals::AnimalGroup[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::AnimalSupplyId,
        :schema_type => XSD::QName.new(NsAnimalTypes, "animalSupplyId"),
        :schema_element => [
            ["animal", "CrvApiClient::Api::Animals::AnimalId"],
            ["supplyType", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "supplyType")]],
            ["supplyCd", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "supplyCd")]],
            ["plannedDepartureDate", [nil, XSD::QName.new(NsAnimal, "plannedDepartureDate")], [0, 1]],
            ["trader", "CrvApiClient::Api::Animals::ParticipantId", [0, 1]],
            ["destination", "CrvApiClient::Api::Animals::ParticipantId", [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::Addresses,
        :schema_type => XSD::QName.new(NsAnimalTypes, "addresses"),
        :schema_element => [
            ["participant", "CrvApiClient::Api::Animals::Participant[]", [0, nil]],
            ["address", "CrvApiClient::Api::Animals::Address[]", [0, nil]],
            ["trader", "CrvApiClient::Api::Animals::ParticipantId", [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::AnimalArrivalDetail,
        :schema_type => XSD::QName.new(NsAnimalTypes, "animalArrivalDetail"),
        :schema_element => [
            ["animalId", "CrvApiClient::Api::Animals::AnimalId[]", [1, nil]],
            ["plannedArrivalDetail", "CrvApiClient::Api::Animals::PlannedArrivalDetail"]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::AverageHerdWeight,
        :schema_type => XSD::QName.new(NsAnimalTypes, "averageHerdWeight"),
        :schema_element => [
            ["keeper", "CrvApiClient::Api::Animals::ParticipantId"],
            ["referencePeriod", "CrvApiClient::Api::Animals::TimePeriod"],
            ["herdWeightCategoryResult", "CrvApiClient::Api::Animals::HerdWeightCategory[]", [1, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::BreedFraction,
        :schema_type => XSD::QName.new(NsAnimalTypes, "breedFraction"),
        :schema_element => [
            ["breed", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "breed")]],
            ["fraction", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "fraction")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::BullDetails,
        :schema_type => XSD::QName.new(NsAnimalTypes, "bullDetails"),
        :schema_element => [
            ["bullId", "CrvApiClient::Api::Animals::AnimalId"],
            ["aiCode", "CrvApiClient::Api::Animals::AnimalId", [0, 1]],
            ["bullName", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "bullName")], [0, 1]],
            ["bullShortName", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "bullShortName")], [0, 1]],
            ["birthDate", [nil, XSD::QName.new(NsAnimal, "birthDate")], [0, 1]],
            ["colourHair", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "colourHair")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::ColourCode,
        :schema_type => XSD::QName.new(NsAnimalTypes, "colourCode"),
        :schema_element => [
            ["countryCode", "SOAP::SOAPString"],
            ["colourCode", "SOAP::SOAPString"]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::ChainValue,
        :schema_type => XSD::QName.new(NsAnimalTypes, "chainValue"),
        :schema_element => [
            ["chainType", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "chainType")]],
            ["chainVersion", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "chainVersion")]],
            ["chainRowValue", "CrvApiClient::Api::Animals::ChainRowValue[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::ChainRowValue,
        :schema_type => XSD::QName.new(NsAnimalTypes, "chainRowValue"),
        :schema_element => [
            ["rowCd", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "rowCd")]],
            ["rowValue", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "rowValue")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::DateReason,
        :schema_type => XSD::QName.new(NsAnimalTypes, "dateReason"),
        :schema_element => [
            ["date", [nil, XSD::QName.new(NsCommon, "date")]],
            ["reason", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "reason")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::AnimalGroup,
        :schema_type => XSD::QName.new(NsAnimalTypes, "animalGroup"),
        :schema_element => [
            ["animalGroupType", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalGroupType")]],
            ["animalGroupCode", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalGroupCode")]],
            ["animalGroupName", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalGroupName")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::HerdWeightCategory,
        :schema_type => XSD::QName.new(NsAnimalTypes, "herdWeightCategory"),
        :schema_element => [
            ["categoryCd", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "categoryCd")]],
            ["avgNoAnimals", [nil, XSD::QName.new(NsAnimal, "avgNoAnimals")]],
            ["avgWeightAnimals", [nil, XSD::QName.new(NsAnimal, "avgWeightAnimals")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::ListParticipantAnimalRequest,
        :schema_type => XSD::QName.new(NsAnimalTypes, "listParticipantAnimalRequest"),
        :schema_element => [
            ["listType", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "listType")], [0, 1]],
            ["participantAnimalRequest", "CrvApiClient::Api::Animals::ParticipantAnimalRequest[]", [1, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::ParticipantAnimalId,
        :schema_type => XSD::QName.new(NsAnimalTypes, "participantAnimalId"),
        :schema_element => [
            ["numberType", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "numberType")]],
            ["numberSubType", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "numberSubType")]],
            ["participantAnimalNr", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "participantAnimalNr")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::ParticipantAnimalRequest,
        :schema_type => XSD::QName.new(NsAnimalTypes, "participantAnimalRequest"),
        :schema_element => [
            ["numberType", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "numberType")]],
            ["numberSubType", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "numberSubType")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::PeriodRange_,
        :schema_type => XSD::QName.new(NsAnimalTypes, "periodRange"),
        :schema_element => [
            ["beginDate", [nil, XSD::QName.new(NsCommon, "beginDate")]],
            ["endDate", [nil, XSD::QName.new(NsCommon, "endDate")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::PlannedArrivalDetail,
        :schema_type => XSD::QName.new(NsAnimalTypes, "plannedArrivalDetail"),
        :schema_element => [
            ["supplyCd", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "supplyCd")]],
            ["keeper", "CrvApiClient::Api::Animals::ParticipantId"],
            ["plannedDepartureDate", [nil, XSD::QName.new(NsAnimal, "plannedDepartureDate")], [0, 1]],
            ["foodChainInfo", ["CrvApiClient::Api::Animals::BooleanType", XSD::QName.new(NsAnimal, "foodChainInfo")], [0, 1]],
            ["foodChainInfoStandard", ["CrvApiClient::Api::Animals::BooleanType", XSD::QName.new(NsAnimal, "foodChainInfoStandard")], [0, 1]],
            ["trader", "CrvApiClient::Api::Animals::ParticipantId"],
            ["loadGroup", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "loadGroup")], [0, 1]],
            ["destination", "CrvApiClient::Api::Animals::ParticipantId", [0, 1]],
            ["plannedDeliveryDateTime", [nil, XSD::QName.new(NsAnimal, "plannedDeliveryDateTime")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::Pedigree,
        :schema_type => XSD::QName.new(NsAnimalTypes, "pedigree"),
        :schema_element => [
            ["sire", "CrvApiClient::Api::Animals::Animal", [0, 1]],
            ["dam", "CrvApiClient::Api::Animals::Animal", [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::PlannedArrival,
        :schema_type => XSD::QName.new(NsAnimalTypes, "plannedArrival"),
        :schema_element => [
            ["animal", "CrvApiClient::Api::Animals::Animal[]", [0, nil]],
            ["plannedArrivalDetail", "CrvApiClient::Api::Animals::PlannedArrivalDetail"],
            ["breedFraction", "CrvApiClient::Api::Animals::BreedFraction[]", [1, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::ParticipantId,
        :schema_type => XSD::QName.new(NsParticipantTypes, "participantId"),
        :schema_element => [
            ["participantCode", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "participantCode")]],
            ["participantCodeType", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "participantCodeType")]],
            ["countryCode", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "countryCode")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::NameAddressLayout,
        :schema_type => XSD::QName.new(NsParticipantTypes, "nameAddressLayout"),
        :schema_element => [
            ["addressType", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "addressType")], [0, 1]],
            ["participantName", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "participantName")], [0, 1]],
            ["addressLine1", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "addressLine1")], [0, 1]],
            ["addressLine2", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "addressLine2")], [0, 1]],
            ["addressLine3", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "addressLine3")], [0, 1]],
            ["addressLine4", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "addressLine4")], [0, 1]],
            ["addressLine5", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "addressLine5")], [0, 1]],
            ["addressLine6", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "addressLine6")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::Address,
        :schema_type => XSD::QName.new(NsParticipantTypes, "address"),
        :schema_element => [
            ["addressType", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "addressType")]],
            ["street", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "street")]],
            ["houseNr", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "houseNr")], [0, 1]],
            ["zipCd", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "zipCd")], [0, 1]],
            ["city", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "city")]],
            ["regionCd", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "regionCd")], [0, 1]],
            ["country", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "country")], [0, 1]],
            ["countryCd", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "countryCd")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::Participant,
        :schema_type => XSD::QName.new(NsParticipantTypes, "participant"),
        :schema_element => [
            ["participant", "CrvApiClient::Api::Animals::ParticipantId"],
            ["preTitle", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "preTitle")], [0, 1]],
            ["initials", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "initials")], [0, 1]],
            ["firstname", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "firstname")], [0, 1]],
            ["prefix", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "prefix")], [0, 1]],
            ["surname", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "surname")], [0, 1]],
            ["postTitle", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "postTitle")], [0, 1]],
            ["composedName", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "composedName")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::ConnectionDataBasic,
        :schema_type => XSD::QName.new(NsParticipantTypes, "connectionDataBasic"),
        :schema_element => [
            ["emailAddress", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "emailAddress")], [0, 1]],
            ["phoneNr", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "phoneNr")], [0, 1]],
            ["mobilePhone", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "mobilePhone")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::Connection,
        :schema_type => XSD::QName.new(NsParticipantTypes, "connection"),
        :schema_element => [
            ["connectionType", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "connectionType")]],
            ["connection", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "connection")], [0, 1]],
            ["connectionUse", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "connectionUse")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::ParticipantBasic,
        :schema_type => XSD::QName.new(NsParticipantTypes, "participantBasic"),
        :schema_element => [
            ["participant", "CrvApiClient::Api::Animals::Participant"],
            ["address", "CrvApiClient::Api::Animals::Address[]", [0, nil]],
            ["connectionDataBasic", "CrvApiClient::Api::Animals::ConnectionDataBasic", [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::ParticipantComplete,
        :schema_type => XSD::QName.new(NsParticipantTypes, "participantComplete"),
        :schema_element => [
            ["participant", "CrvApiClient::Api::Animals::Participant"],
            ["address", "CrvApiClient::Api::Animals::Address[]", [0, nil]],
            ["connection", "CrvApiClient::Api::Animals::Connection[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::ActualKeeper,
        :schema_type => XSD::QName.new(NsParticipantTypes, "actualKeeper"),
        :schema_element => [
            ["participant", "CrvApiClient::Api::Animals::ParticipantId"],
            ["nameAddressLayout", "CrvApiClient::Api::Animals::NameAddressLayout"]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::BooleanType,
        :schema_type => XSD::QName.new(NsCommonTypes, "booleanType")
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::NotificationType,
        :schema_type => XSD::QName.new(NsCommonTypes, "notificationType")
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::RepresentationType,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "representationType")
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::CountryCode,
        :schema_type => XSD::QName.new(NsAnimalTypes, "countryCode")
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::KeeperType,
        :schema_type => XSD::QName.new(NsAnimalTypes, "keeperType")
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Animals::Sex,
        :schema_type => XSD::QName.new(NsAnimalTypes, "sex")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ModifyAnimalManagementRequestType,
        :schema_type => XSD::QName.new(NsAnimalMessages, "modifyAnimalManagementRequestType"),
        :schema_element => [
            ["participantId", "CrvApiClient::Api::Animals::ParticipantId"],
            ["animalManagement", "CrvApiClient::Api::Animals::AnimalManagement[]", [1, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::AddPlannedDepartureRequestType,
        :schema_type => XSD::QName.new(NsAnimalMessages, "addPlannedDepartureRequestType"),
        :schema_element => [
            ["keeper", "CrvApiClient::Api::Animals::ParticipantId"],
            ["animalSupplyChainValue", "CrvApiClient::Api::Animals::AnimalSupplyChainValue[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::AnimalSupplyChainValue,
        :schema_type => XSD::QName.new(NsAnimalMessages, "animalSupplyChainValue"),
        :schema_element => [
            ["animalSupplyId", "CrvApiClient::Api::Animals::AnimalSupplyId"],
            ["chainValue", "CrvApiClient::Api::Animals::ChainValue", [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::DeletePlannedDepartureRequestType,
        :schema_type => XSD::QName.new(NsAnimalMessages, "deletePlannedDepartureRequestType"),
        :schema_element => [
            ["keeper", "CrvApiClient::Api::Animals::ParticipantId"],
            ["animalSupplyId", "CrvApiClient::Api::Animals::AnimalSupplyId[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::AnimalSupplyPlannedDeparture,
        :schema_type => XSD::QName.new(NsAnimalMessages, "animalSupplyPlannedDeparture"),
        :schema_element => [
            ["animalSupplyId", "CrvApiClient::Api::Animals::AnimalSupplyId"],
            ["postpone", "CrvApiClient::Api::Animals::DateReason", [0, 1]],
            ["refusal", "CrvApiClient::Api::Animals::DateReason", [0, 1]],
            ["departure", "CrvApiClient::Api::Animals::DateReason", [0, 1]],
            ["chainValueStatus", "CrvApiClient::Api::Animals::ChainValueStatus", [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ChainValueStatus,
        :schema_type => XSD::QName.new(NsAnimalMessages, "chainValueStatus"),
        :schema_element => [
            ["chainValue", "CrvApiClient::Api::Animals::ChainValue"],
            ["chainStatus", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "chainStatus")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::GetAverageHerdWeightRequestType,
        :schema_type => XSD::QName.new(NsAnimalMessages, "getAverageHerdWeightRequestType"),
        :schema_element => [
            ["keeper", "CrvApiClient::Api::Animals::ParticipantId"],
            ["year", nil, [0, 1]],
            ["quarter", nil, [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::GetAverageHerdWeightResponseType,
        :schema_type => XSD::QName.new(NsAnimalMessages, "getAverageHerdWeightResponseType"),
        :schema_element => [
            ["averageHerdWeightResult", "CrvApiClient::Api::Animals::AverageHerdWeight"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ListPlannedDepartureRequestType,
        :schema_type => XSD::QName.new(NsAnimalMessages, "listPlannedDepartureRequestType"),
        :schema_element => [
            ["keeper", "CrvApiClient::Api::Animals::ParticipantId"],
            ["period", "CrvApiClient::Api::Animals::PeriodRange"],
            ["supplyType", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "supplyType")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ListPlannedDepartureResponseType,
        :schema_type => XSD::QName.new(NsAnimalMessages, "listPlannedDepartureResponseType"),
        :schema_element => [
            ["keeper", "CrvApiClient::Api::Animals::ParticipantId"],
            ["animalSupplyPlannedDeparture", "CrvApiClient::Api::Animals::AnimalSupplyPlannedDeparture[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ListFoodChainInformationRequestType,
        :schema_type => XSD::QName.new(NsAnimalMessages, "listFoodChainInformationRequestType"),
        :schema_element => [
            ["chainType", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "chainType")]],
            ["animal", "CrvApiClient::Api::Animals::AnimalId[]", [1, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ListFoodChainInformationResponseType,
        :schema_type => XSD::QName.new(NsAnimalMessages, "listFoodChainInformationResponseType"),
        :schema_element => [
            ["animalChainValue", "CrvApiClient::Api::Animals::AnimalChainValue[]", [1, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::AnimalChainValue,
        :schema_type => XSD::QName.new(NsAnimalMessages, "animalChainValue"),
        :schema_element => [
            ["animal", "CrvApiClient::Api::Animals::AnimalId"],
            ["chainValue", "CrvApiClient::Api::Animals::ChainValue", [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ListPlannedArrivalRequestType,
        :schema_type => XSD::QName.new(NsAnimalMessages, "listPlannedArrivalRequestType"),
        :schema_element => [
            ["customer", "CrvApiClient::Api::Animals::ParticipantId"],
            ["source", "CrvApiClient::Api::Animals::ParticipantId"],
            ["period", "CrvApiClient::Api::Animals::PeriodRange_"],
            ["supplyType", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "supplyType")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ListPlannedArrivalResponseType,
        :schema_type => XSD::QName.new(NsAnimalMessages, "listPlannedArrivalResponseType"),
        :schema_element => [
            ["plannedArrival", "CrvApiClient::Api::Animals::PlannedArrival[]", [0, nil]],
            ["addresses", "CrvApiClient::Api::Animals::Addresses[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ModifyPlannedArrivalRequestType,
        :schema_type => XSD::QName.new(NsAnimalMessages, "modifyPlannedArrivalRequestType"),
        :schema_element => [
            ["customer", "CrvApiClient::Api::Animals::ParticipantId"],
            ["animalArrivalDetail", "CrvApiClient::Api::Animals::AnimalArrivalDetail[]", [1, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ListHerdPedigreeRequestType,
        :schema_type => XSD::QName.new(NsAnimalMessages, "listHerdPedigreeRequestType"),
        :schema_element => [
            ["keeper", "CrvApiClient::Api::Animals::ParticipantId"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ListHerdPedigreeResponseType,
        :schema_type => XSD::QName.new(NsAnimalMessages, "listHerdPedigreeResponseType"),
        :schema_element => [
            ["keeper", "CrvApiClient::Api::Animals::ParticipantId"],
            ["animalPedigree", "CrvApiClient::Api::Animals::AnimalPedigree[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::LocalTime,
        :schema_type => XSD::QName.new(NsCommonTypes, "localTime"),
        :schema_element => [
            ["hourOfDay", "SOAP::SOAPInt"],
            ["minuteOfHour", "SOAP::SOAPInt"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::LocalDate,
        :schema_type => XSD::QName.new(NsCommonTypes, "localDate"),
        :schema_element => [
            ["dayOfMonth", "SOAP::SOAPInt"],
            ["monthOfYear", "SOAP::SOAPInt"],
            ["year", "SOAP::SOAPInt"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::PeriodRange,
        :schema_type => XSD::QName.new(NsCommonTypes, "periodRange"),
        :schema_element => [
            ["beginDate", [nil, XSD::QName.new(NsCommon, "beginDate")], [0, 1]],
            ["endDate", [nil, XSD::QName.new(NsCommon, "endDate")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ContextMessage,
        :schema_type => XSD::QName.new(NsCommonTypes, "contextMessage"),
        :schema_element => [
            ["sessionId", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "sessionId")], [0, 1]],
            ["processId", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "processId")], [0, 1]],
            ["instanceId", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "instanceId")], [0, 1]],
            ["username", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "username")], [0, 1]],
            ["userType", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "userType")], [0, 1]],
            ["password", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "password")], [0, 1]],
            ["organisation", "CrvApiClient::Api::Animals::ParticipantId", [0, 1]],
            ["provider", "CrvApiClient::Api::Animals::ParticipantId", [0, 1]],
            ["customer", "CrvApiClient::Api::Animals::ParticipantId", [0, 1]],
            ["keeper", "CrvApiClient::Api::Animals::ParticipantId", [0, 1]],
            ["animal", "CrvApiClient::Api::Animals::AnimalId", [0, 1]],
            ["processCode", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "processCode")], [0, 1]],
            ["messageSource", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "messageSource")], [0, 1]],
            ["languageCode", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "languageCode")], [0, 1]],
            ["timeZone", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "timeZone")], [0, 1]],
            ["contextMessageDetail", "CrvApiClient::Api::Animals::ContextMessageDetail[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ContextMessageDetail,
        :schema_type => XSD::QName.new(NsCommonTypes, "contextMessageDetail"),
        :schema_element => [
            ["contextCode", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "contextCode")], [0, 1]],
            ["contextValue", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "contextValue")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ServiceMessage,
        :schema_type => XSD::QName.new(NsCommonTypes, "serviceMessage"),
        :schema_element => [
            ["serviceStatus", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "serviceStatus")]],
            ["messageCode", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "messageCode")], [0, 1]],
            ["messageText", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "messageText")], [0, 1]],
            ["messageType", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "messageType")], [0, 1]],
            ["sourceType", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "sourceType")], [0, 1]],
            ["sourceCode", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "sourceCode")], [0, 1]],
            ["serviceMessageDetail", "CrvApiClient::Api::Animals::ServiceMessageDetail[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ServiceMessageDetail,
        :schema_type => XSD::QName.new(NsCommonTypes, "serviceMessageDetail"),
        :schema_element => [
            ["serviceStatus", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "serviceStatus")], [0, 1]],
            ["codeDetail", "CrvApiClient::Api::Animals::CodeDetail[]", [0, nil]],
            ["messageCode", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "messageCode")], [0, 1]],
            ["messageText", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "messageText")], [0, 1]],
            ["messageType", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "messageType")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::CodeDetail,
        :schema_type => XSD::QName.new(NsCommonTypes, "codeDetail"),
        :schema_element => [
            ["keyId", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "keyId")], [0, 1]],
            ["keyValue", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "keyValue")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::SendNotificationRequestType,
        :schema_type => XSD::QName.new(NsCommonTypes, "sendNotificationRequestType"),
        :schema_element => [
            ["notificationType", ["CrvApiClient::Api::Animals::NotificationType", XSD::QName.new(NsCommon, "notificationType")], [0, 1]],
            ["notificationMessage", "CrvApiClient::Api::Animals::NotificationMessageType[]", [0, nil]],
            ["email", "CrvApiClient::Api::Animals::EmailType[]", [0, nil]],
            ["fax", "CrvApiClient::Api::Animals::FaxType[]", [0, nil]],
            ["sms", "CrvApiClient::Api::Animals::SmsType[]", [0, nil]],
            ["voice", "CrvApiClient::Api::Animals::VoiceType[]", [0, nil]],
            ["pager", "CrvApiClient::Api::Animals::PagerType[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::NotificationMessageType,
        :schema_type => XSD::QName.new(NsCommonTypes, "notificationMessageType"),
        :schema_element => [
            ["messageCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "messageCode")], [0, 1]],
            ["languageCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "languageCode")], [0, 1]],
            ["messageParameter", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "messageParameter")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::EmailType,
        :schema_type => XSD::QName.new(NsCommonTypes, "emailType"),
        :schema_element => [
            ["mailTo", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "mailTo")], [0, 1]],
            ["mailCc", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "mailCc")], [0, 1]],
            ["mailBcc", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "mailBcc")], [0, 1]],
            ["mailReplyTo", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "mailReplyTo")], [0, 1]],
            ["subject", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "subject")], [0, 1]],
            ["textBody", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "textBody")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::FaxType,
        :schema_type => XSD::QName.new(NsCommonTypes, "faxType"),
        :schema_element => [
            ["faxNr", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "faxNr")], [0, 1]],
            ["coverPage", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "coverPage")], [0, 1]],
            ["textBody", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "textBody")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::SmsType,
        :schema_type => XSD::QName.new(NsCommonTypes, "smsType"),
        :schema_element => [
            ["fromNr", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "fromNr")], [0, 1]],
            ["telNr", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "telNr")], [0, 1]],
            ["subject", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "subject")], [0, 1]],
            ["textBody", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "textBody")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::VoiceType,
        :schema_type => XSD::QName.new(NsCommonTypes, "voiceType"),
        :schema_element => [
            ["telNr", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "telNr")], [0, 1]],
            ["textBody", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "textBody")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::PagerType,
        :schema_type => XSD::QName.new(NsCommonTypes, "pagerType"),
        :schema_element => [
            ["fromNr", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "fromNr")], [0, 1]],
            ["pagerNr", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "pagerNr")], [0, 1]],
            ["textBody", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "textBody")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::GetLabel,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "getLabel"),
        :schema_element => [
            ["componentCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "componentCode")], [0, 1]],
            ["itemName", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "itemName")], [0, 1]],
            ["itemType", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "itemType")], [0, 1]],
            ["languageCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "languageCode")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::Component,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "component"),
        :schema_element => [
            ["componentCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "componentCode")], [0, 1]],
            ["processCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "processCode")], [0, 1]],
            ["componentType", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "componentType")], [0, 1]],
            ["componentName", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "componentName")], [0, 1]],
            ["componentItem", "CrvApiClient::Api::Animals::ComponentItem[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ComponentItem,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "componentItem"),
        :schema_element => [
            ["item", "CrvApiClient::Api::Animals::Item[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::Item,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "item"),
        :schema_element => [
            ["itemName", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "itemName")], [0, 1]],
            ["moduleCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "moduleCode")], [0, 1]],
            ["itemType", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "itemType")], [0, 1]],
            ["itemLng", "CrvApiClient::Api::Animals::ItemLng[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ItemLng,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "itemLng"),
        :schema_element => [
            ["languageCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "languageCode")], [0, 1]],
            ["itemLabel", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "itemLabel")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::GetSystemMessage,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "getSystemMessage"),
        :schema_element => [
            ["messageCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "messageCode")], [0, 1]],
            ["languageCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "languageCode")], [0, 1]],
            ["messageParameter", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "messageParameter")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::SystemMessage,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "systemMessage"),
        :schema_element => [
            ["message", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "message")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ListDomain,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "listDomain"),
        :schema_element => [
            ["domain", "CrvApiClient::Api::Animals::Domain[]", [0, nil]],
            ["languageCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "languageCode")], [0, 1]],
            ["representationType", ["CrvApiClient::Api::Animals::RepresentationType", XSD::QName.new(NsDictionary, "representationType")], [0, 1]],
            ["actual", ["CrvApiClient::Api::Animals::BooleanType", XSD::QName.new(NsDictionary, "actual")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::DomainValue,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "domainValue"),
        :schema_element => [
            ["domainCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "domainCode")]],
            ["columnValue", "CrvApiClient::Api::Animals::ColumnValue[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ColumnValue,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "columnValue"),
        :schema_element => [
            ["value", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "value")], [0, 1]],
            ["representation", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "representation")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::Domain,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "domain"),
        :schema_element => [
            ["domainCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "domainCode")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::TimePeriod,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "timePeriod"),
        :schema_element => [
            ["beginDate", [nil, XSD::QName.new(NsCommon, "beginDate")], [0, 1]],
            ["beginTime", [nil, XSD::QName.new(NsCommon, "beginTime")], [0, 1]],
            ["endDate", [nil, XSD::QName.new(NsCommon, "endDate")], [0, 1]],
            ["endTime", [nil, XSD::QName.new(NsCommon, "endTime")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::IntervalId,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "intervalId"),
        :schema_element => [
            ["nr", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "nr")]],
            ["nrType", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "nrType")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::AnimalNumberCountry,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "animalNumberCountry"),
        :schema_element => [
            ["countryCd", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "countryCd")]],
            ["animalNrLength", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "animalNrLength")]],
            ["animalNrAlphanumeric", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "animalNrAlphanumeric")]],
            ["sortingOrder", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "sortingOrder")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::HourCode,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "hourCode"),
        :schema_element => [
            ["hourCd", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "hourCd")]],
            ["description", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "description")]],
            ["hourMutateAllowed", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "hourMutateAllowed")]],
            ["hourNecessary", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "hourNecessary")]],
            ["addressMutateAllowed", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "addressMutateAllowed")]],
            ["addressNecessary", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "addressNecessary")]],
            ["activityMutateAllowed", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "activityMutateAllowed")]],
            ["activityNecessary", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "activityNecessary")]],
            ["kilometresMutateAllowed", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "kilometresMutateAllowed")]],
            ["kilometresNecessary", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "kilometresNecessary")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::Parameter,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "parameter"),
        :schema_element => [
            ["parameterName", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "parameterName")]],
            ["value", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "value")]],
            ["valueDescription", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "valueDescription")]],
            ["default", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "default")]],
            ["sortingOrder", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "sortingOrder")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::AnimalId,
        :schema_type => XSD::QName.new(NsAnimalTypes, "animalId"),
        :schema_element => [
            ["animalNumber", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalNumber")]],
            ["animalNumberType", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalNumberType")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::AnimalDetailsBirth,
        :schema_type => XSD::QName.new(NsAnimalTypes, "animalDetailsBirth"),
        :schema_element => [
            ["animalId", "CrvApiClient::Api::Animals::AnimalId", [0, 1]],
            ["animalNumberShort", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalNumberShort")], [0, 1]],
            ["sex", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "sex")], [0, 1]],
            ["colourHair", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "colourHair")], [0, 1]],
            ["birthDate", [nil, XSD::QName.new(NsAnimal, "birthDate")], [0, 1]],
            ["animalName", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalName")], [0, 1]],
            ["surrogateDam", "CrvApiClient::Api::Animals::AnimalId", [0, 1]],
            ["dam", "CrvApiClient::Api::Animals::AnimalId", [0, 1]],
            ["sire", "CrvApiClient::Api::Animals::AnimalId", [0, 1]],
            ["breedComposition", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "breedComposition")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::Animal,
        :schema_type => XSD::QName.new(NsAnimalTypes, "animal"),
        :schema_element => [
            ["animalId", "CrvApiClient::Api::Animals::AnimalId"],
            ["animalNumberShort", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalNumberShort")], [0, 1]],
            ["sex", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "sex")]],
            ["colourHair", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "colourHair")], [0, 1]],
            ["birthDate", [nil, XSD::QName.new(NsAnimal, "birthDate")]],
            ["deathDate", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "deathDate")], [0, 1]],
            ["animalName", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalName")], [0, 1]],
            ["breedComposition", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "breedComposition")], [0, 1]],
            ["redFactor", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "redFactor")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::AnimalManagement,
        :schema_type => XSD::QName.new(NsAnimalTypes, "animalManagement"),
        :schema_element => [
            ["animalId", "CrvApiClient::Api::Animals::AnimalId"],
            ["animalName", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalName")], [0, 1]],
            ["farmersAnimalNr", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "farmersAnimalNr")], [0, 1]],
            ["animalGroupNr", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalGroupNr")], [0, 1]],
            ["productionPurposeDate", [nil, XSD::QName.new(NsAnimal, "productionPurposeDate")], [0, 1]],
            ["productionPurpose", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "productionPurpose")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::AnimalPedigree,
        :schema_type => XSD::QName.new(NsAnimalTypes, "animalPedigree"),
        :schema_element => [
            ["animal", "CrvApiClient::Api::Animals::AnimalId", [0, 1]],
            ["animalNrShort", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalNrShort")], [0, 1]],
            ["animalName", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalName")], [0, 1]],
            ["farmersAnimalNr", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "farmersAnimalNr")], [0, 1]],
            ["sex", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "sex")], [0, 1]],
            ["birthDate", [nil, XSD::QName.new(NsAnimal, "birthDate")], [0, 1]],
            ["colourHair", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "colourHair")], [0, 1]],
            ["pedigree", "CrvApiClient::Api::Animals::Pedigree", [0, 1]],
            ["participantAnimal", "CrvApiClient::Api::Animals::ParticipantAnimalId[]", [0, nil]],
            ["groupCode", "CrvApiClient::Api::Animals::AnimalGroup[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::AnimalSupplyId,
        :schema_type => XSD::QName.new(NsAnimalTypes, "animalSupplyId"),
        :schema_element => [
            ["animal", "CrvApiClient::Api::Animals::AnimalId"],
            ["supplyType", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "supplyType")]],
            ["supplyCd", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "supplyCd")]],
            ["plannedDepartureDate", [nil, XSD::QName.new(NsAnimal, "plannedDepartureDate")], [0, 1]],
            ["trader", "CrvApiClient::Api::Animals::ParticipantId", [0, 1]],
            ["destination", "CrvApiClient::Api::Animals::ParticipantId", [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::Addresses,
        :schema_type => XSD::QName.new(NsAnimalTypes, "addresses"),
        :schema_element => [
            ["participant", "CrvApiClient::Api::Animals::Participant[]", [0, nil]],
            ["address", "CrvApiClient::Api::Animals::Address[]", [0, nil]],
            ["trader", "CrvApiClient::Api::Animals::ParticipantId", [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::AnimalArrivalDetail,
        :schema_type => XSD::QName.new(NsAnimalTypes, "animalArrivalDetail"),
        :schema_element => [
            ["animalId", "CrvApiClient::Api::Animals::AnimalId[]", [1, nil]],
            ["plannedArrivalDetail", "CrvApiClient::Api::Animals::PlannedArrivalDetail"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::AverageHerdWeight,
        :schema_type => XSD::QName.new(NsAnimalTypes, "averageHerdWeight"),
        :schema_element => [
            ["keeper", "CrvApiClient::Api::Animals::ParticipantId"],
            ["referencePeriod", "CrvApiClient::Api::Animals::TimePeriod"],
            ["herdWeightCategoryResult", "CrvApiClient::Api::Animals::HerdWeightCategory[]", [1, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::BreedFraction,
        :schema_type => XSD::QName.new(NsAnimalTypes, "breedFraction"),
        :schema_element => [
            ["breed", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "breed")]],
            ["fraction", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "fraction")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::BullDetails,
        :schema_type => XSD::QName.new(NsAnimalTypes, "bullDetails"),
        :schema_element => [
            ["bullId", "CrvApiClient::Api::Animals::AnimalId"],
            ["aiCode", "CrvApiClient::Api::Animals::AnimalId", [0, 1]],
            ["bullName", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "bullName")], [0, 1]],
            ["bullShortName", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "bullShortName")], [0, 1]],
            ["birthDate", [nil, XSD::QName.new(NsAnimal, "birthDate")], [0, 1]],
            ["colourHair", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "colourHair")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ColourCode,
        :schema_type => XSD::QName.new(NsAnimalTypes, "colourCode"),
        :schema_element => [
            ["countryCode", "SOAP::SOAPString"],
            ["colourCode", "SOAP::SOAPString"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ChainValue,
        :schema_type => XSD::QName.new(NsAnimalTypes, "chainValue"),
        :schema_element => [
            ["chainType", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "chainType")]],
            ["chainVersion", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "chainVersion")]],
            ["chainRowValue", "CrvApiClient::Api::Animals::ChainRowValue[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ChainRowValue,
        :schema_type => XSD::QName.new(NsAnimalTypes, "chainRowValue"),
        :schema_element => [
            ["rowCd", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "rowCd")]],
            ["rowValue", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "rowValue")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::DateReason,
        :schema_type => XSD::QName.new(NsAnimalTypes, "dateReason"),
        :schema_element => [
            ["date", [nil, XSD::QName.new(NsCommon, "date")]],
            ["reason", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "reason")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::AnimalGroup,
        :schema_type => XSD::QName.new(NsAnimalTypes, "animalGroup"),
        :schema_element => [
            ["animalGroupType", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalGroupType")]],
            ["animalGroupCode", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalGroupCode")]],
            ["animalGroupName", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalGroupName")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::HerdWeightCategory,
        :schema_type => XSD::QName.new(NsAnimalTypes, "herdWeightCategory"),
        :schema_element => [
            ["categoryCd", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "categoryCd")]],
            ["avgNoAnimals", [nil, XSD::QName.new(NsAnimal, "avgNoAnimals")]],
            ["avgWeightAnimals", [nil, XSD::QName.new(NsAnimal, "avgWeightAnimals")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ListParticipantAnimalRequest,
        :schema_type => XSD::QName.new(NsAnimalTypes, "listParticipantAnimalRequest"),
        :schema_element => [
            ["listType", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "listType")], [0, 1]],
            ["participantAnimalRequest", "CrvApiClient::Api::Animals::ParticipantAnimalRequest[]", [1, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ParticipantAnimalId,
        :schema_type => XSD::QName.new(NsAnimalTypes, "participantAnimalId"),
        :schema_element => [
            ["numberType", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "numberType")]],
            ["numberSubType", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "numberSubType")]],
            ["participantAnimalNr", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "participantAnimalNr")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ParticipantAnimalRequest,
        :schema_type => XSD::QName.new(NsAnimalTypes, "participantAnimalRequest"),
        :schema_element => [
            ["numberType", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "numberType")]],
            ["numberSubType", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "numberSubType")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::PeriodRange_,
        :schema_type => XSD::QName.new(NsAnimalTypes, "periodRange"),
        :schema_element => [
            ["beginDate", [nil, XSD::QName.new(NsCommon, "beginDate")]],
            ["endDate", [nil, XSD::QName.new(NsCommon, "endDate")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::PlannedArrivalDetail,
        :schema_type => XSD::QName.new(NsAnimalTypes, "plannedArrivalDetail"),
        :schema_element => [
            ["supplyCd", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "supplyCd")]],
            ["keeper", "CrvApiClient::Api::Animals::ParticipantId"],
            ["plannedDepartureDate", [nil, XSD::QName.new(NsAnimal, "plannedDepartureDate")], [0, 1]],
            ["foodChainInfo", ["CrvApiClient::Api::Animals::BooleanType", XSD::QName.new(NsAnimal, "foodChainInfo")], [0, 1]],
            ["foodChainInfoStandard", ["CrvApiClient::Api::Animals::BooleanType", XSD::QName.new(NsAnimal, "foodChainInfoStandard")], [0, 1]],
            ["trader", "CrvApiClient::Api::Animals::ParticipantId"],
            ["loadGroup", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "loadGroup")], [0, 1]],
            ["destination", "CrvApiClient::Api::Animals::ParticipantId", [0, 1]],
            ["plannedDeliveryDateTime", [nil, XSD::QName.new(NsAnimal, "plannedDeliveryDateTime")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::Pedigree,
        :schema_type => XSD::QName.new(NsAnimalTypes, "pedigree"),
        :schema_element => [
            ["sire", "CrvApiClient::Api::Animals::Animal", [0, 1]],
            ["dam", "CrvApiClient::Api::Animals::Animal", [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::PlannedArrival,
        :schema_type => XSD::QName.new(NsAnimalTypes, "plannedArrival"),
        :schema_element => [
            ["animal", "CrvApiClient::Api::Animals::Animal[]", [0, nil]],
            ["plannedArrivalDetail", "CrvApiClient::Api::Animals::PlannedArrivalDetail"],
            ["breedFraction", "CrvApiClient::Api::Animals::BreedFraction[]", [1, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ParticipantId,
        :schema_type => XSD::QName.new(NsParticipantTypes, "participantId"),
        :schema_element => [
            ["participantCode", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "participantCode")]],
            ["participantCodeType", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "participantCodeType")]],
            ["countryCode", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "countryCode")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::NameAddressLayout,
        :schema_type => XSD::QName.new(NsParticipantTypes, "nameAddressLayout"),
        :schema_element => [
            ["addressType", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "addressType")], [0, 1]],
            ["participantName", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "participantName")], [0, 1]],
            ["addressLine1", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "addressLine1")], [0, 1]],
            ["addressLine2", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "addressLine2")], [0, 1]],
            ["addressLine3", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "addressLine3")], [0, 1]],
            ["addressLine4", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "addressLine4")], [0, 1]],
            ["addressLine5", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "addressLine5")], [0, 1]],
            ["addressLine6", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "addressLine6")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::Address,
        :schema_type => XSD::QName.new(NsParticipantTypes, "address"),
        :schema_element => [
            ["addressType", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "addressType")]],
            ["street", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "street")]],
            ["houseNr", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "houseNr")], [0, 1]],
            ["zipCd", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "zipCd")], [0, 1]],
            ["city", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "city")]],
            ["regionCd", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "regionCd")], [0, 1]],
            ["country", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "country")], [0, 1]],
            ["countryCd", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "countryCd")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::Participant,
        :schema_type => XSD::QName.new(NsParticipantTypes, "participant"),
        :schema_element => [
            ["participant", "CrvApiClient::Api::Animals::ParticipantId"],
            ["preTitle", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "preTitle")], [0, 1]],
            ["initials", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "initials")], [0, 1]],
            ["firstname", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "firstname")], [0, 1]],
            ["prefix", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "prefix")], [0, 1]],
            ["surname", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "surname")], [0, 1]],
            ["postTitle", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "postTitle")], [0, 1]],
            ["composedName", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "composedName")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ConnectionDataBasic,
        :schema_type => XSD::QName.new(NsParticipantTypes, "connectionDataBasic"),
        :schema_element => [
            ["emailAddress", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "emailAddress")], [0, 1]],
            ["phoneNr", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "phoneNr")], [0, 1]],
            ["mobilePhone", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "mobilePhone")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::Connection,
        :schema_type => XSD::QName.new(NsParticipantTypes, "connection"),
        :schema_element => [
            ["connectionType", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "connectionType")]],
            ["connection", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "connection")], [0, 1]],
            ["connectionUse", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "connectionUse")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ParticipantBasic,
        :schema_type => XSD::QName.new(NsParticipantTypes, "participantBasic"),
        :schema_element => [
            ["participant", "CrvApiClient::Api::Animals::Participant"],
            ["address", "CrvApiClient::Api::Animals::Address[]", [0, nil]],
            ["connectionDataBasic", "CrvApiClient::Api::Animals::ConnectionDataBasic", [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ParticipantComplete,
        :schema_type => XSD::QName.new(NsParticipantTypes, "participantComplete"),
        :schema_element => [
            ["participant", "CrvApiClient::Api::Animals::Participant"],
            ["address", "CrvApiClient::Api::Animals::Address[]", [0, nil]],
            ["connection", "CrvApiClient::Api::Animals::Connection[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ActualKeeper,
        :schema_type => XSD::QName.new(NsParticipantTypes, "actualKeeper"),
        :schema_element => [
            ["participant", "CrvApiClient::Api::Animals::ParticipantId"],
            ["nameAddressLayout", "CrvApiClient::Api::Animals::NameAddressLayout"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::BooleanType,
        :schema_type => XSD::QName.new(NsCommonTypes, "booleanType")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::NotificationType,
        :schema_type => XSD::QName.new(NsCommonTypes, "notificationType")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::RepresentationType,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "representationType")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::CountryCode,
        :schema_type => XSD::QName.new(NsAnimalTypes, "countryCode")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::KeeperType,
        :schema_type => XSD::QName.new(NsAnimalTypes, "keeperType")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::Sex,
        :schema_type => XSD::QName.new(NsAnimalTypes, "sex")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ModifyAnimalManagementRequest,
        :schema_name => XSD::QName.new(NsAnimalMessages, "modifyAnimalManagementRequest"),
        :schema_element => [
            ["contextMessage", "CrvApiClient::Api::Animals::ContextMessage"],
            ["requestMessage", "CrvApiClient::Api::Animals::ModifyAnimalManagementRequestType"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ModifyAnimalManagementResponse,
        :schema_name => XSD::QName.new(NsAnimalMessages, "modifyAnimalManagementResponse"),
        :schema_element => [
            ["responseMessage", "SOAP::SOAPString", [0, 1]],
            ["serviceMessage", "CrvApiClient::Api::Animals::ServiceMessage"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::AddPlannedDepartureRequest,
        :schema_name => XSD::QName.new(NsAnimalMessages, "addPlannedDepartureRequest"),
        :schema_element => [
            ["contextMessage", "CrvApiClient::Api::Animals::ContextMessage"],
            ["requestMessage", "CrvApiClient::Api::Animals::AddPlannedDepartureRequestType"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::AddPlannedDepartureResponse,
        :schema_name => XSD::QName.new(NsAnimalMessages, "addPlannedDepartureResponse"),
        :schema_element => [
            ["responseMessage", "SOAP::SOAPString", [0, 1]],
            ["serviceMessage", "CrvApiClient::Api::Animals::ServiceMessage"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::DeletePlannedDepartureRequest,
        :schema_name => XSD::QName.new(NsAnimalMessages, "deletePlannedDepartureRequest"),
        :schema_element => [
            ["contextMessage", "CrvApiClient::Api::Animals::ContextMessage"],
            ["requestMessage", "CrvApiClient::Api::Animals::DeletePlannedDepartureRequestType"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::DeletePlannedDepartureResponse,
        :schema_name => XSD::QName.new(NsAnimalMessages, "deletePlannedDepartureResponse"),
        :schema_element => [
            ["responseMessage", "SOAP::SOAPString", [0, 1]],
            ["serviceMessage", "CrvApiClient::Api::Animals::ServiceMessage"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::GetAverageHerdWeightRequest,
        :schema_name => XSD::QName.new(NsAnimalMessages, "getAverageHerdWeightRequest"),
        :schema_element => [
            ["contextMessage", "CrvApiClient::Api::Animals::ContextMessage"],
            ["requestMessage", "CrvApiClient::Api::Animals::GetAverageHerdWeightRequestType"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::GetAverageHerdWeightResponse,
        :schema_name => XSD::QName.new(NsAnimalMessages, "getAverageHerdWeightResponse"),
        :schema_element => [
            ["responseMessage", "CrvApiClient::Api::Animals::GetAverageHerdWeightResponseType", [0, 1]],
            ["serviceMessage", "CrvApiClient::Api::Animals::ServiceMessage"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ListPlannedDepartureRequest,
        :schema_name => XSD::QName.new(NsAnimalMessages, "listPlannedDepartureRequest"),
        :schema_element => [
            ["contextMessage", "CrvApiClient::Api::Animals::ContextMessage"],
            ["requestMessage", "CrvApiClient::Api::Animals::ListPlannedDepartureRequestType"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ListPlannedDepartureResponse,
        :schema_name => XSD::QName.new(NsAnimalMessages, "listPlannedDepartureResponse"),
        :schema_element => [
            ["responseMessage", "CrvApiClient::Api::Animals::ListPlannedDepartureResponseType", [0, 1]],
            ["serviceMessage", "CrvApiClient::Api::Animals::ServiceMessage"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ListFoodChainInformationRequest,
        :schema_name => XSD::QName.new(NsAnimalMessages, "listFoodChainInformationRequest"),
        :schema_element => [
            ["contextMessage", "CrvApiClient::Api::Animals::ContextMessage"],
            ["requestMessage", "CrvApiClient::Api::Animals::ListFoodChainInformationRequestType"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ListFoodChainInformationResponse,
        :schema_name => XSD::QName.new(NsAnimalMessages, "listFoodChainInformationResponse"),
        :schema_element => [
            ["responseMessage", "CrvApiClient::Api::Animals::ListFoodChainInformationResponseType", [0, 1]],
            ["serviceMessage", "CrvApiClient::Api::Animals::ServiceMessage"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ListPlannedArrivalRequest,
        :schema_name => XSD::QName.new(NsAnimalMessages, "listPlannedArrivalRequest"),
        :schema_element => [
            ["contextMessage", "CrvApiClient::Api::Animals::ContextMessage"],
            ["requestMessage", "CrvApiClient::Api::Animals::ListPlannedArrivalRequestType"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ListPlannedArrivalResponse,
        :schema_name => XSD::QName.new(NsAnimalMessages, "listPlannedArrivalResponse"),
        :schema_element => [
            ["responseMessage", "CrvApiClient::Api::Animals::ListPlannedArrivalResponseType", [0, 1]],
            ["serviceMessage", "CrvApiClient::Api::Animals::ServiceMessage"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ModifyPlannedArrivalRequest,
        :schema_name => XSD::QName.new(NsAnimalMessages, "modifyPlannedArrivalRequest"),
        :schema_element => [
            ["contextMessage", "CrvApiClient::Api::Animals::ContextMessage"],
            ["requestMessage", "CrvApiClient::Api::Animals::ModifyPlannedArrivalRequestType"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ModifyPlannedArrivalResponse,
        :schema_name => XSD::QName.new(NsAnimalMessages, "modifyPlannedArrivalResponse"),
        :schema_element => [
            ["serviceMessage", "CrvApiClient::Api::Animals::ServiceMessage"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ListHerdPedigreeRequest,
        :schema_name => XSD::QName.new(NsAnimalMessages, "listHerdPedigreeRequest"),
        :schema_element => [
            ["contextMessage", "CrvApiClient::Api::Animals::ContextMessage"],
            ["requestMessage", "CrvApiClient::Api::Animals::ListHerdPedigreeRequestType"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ListHerdPedigreeResponse,
        :schema_name => XSD::QName.new(NsAnimalMessages, "listHerdPedigreeResponse"),
        :schema_element => [
            ["responseMessage", "CrvApiClient::Api::Animals::ListHerdPedigreeResponseType", [0, 1]],
            ["serviceMessage", "CrvApiClient::Api::Animals::ServiceMessage"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ServiceMessage,
        :schema_name => XSD::QName.new(NsCommonTypes, "serviceMessage"),
        :schema_element => [
            ["serviceStatus", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "serviceStatus")]],
            ["messageCode", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "messageCode")], [0, 1]],
            ["messageText", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "messageText")], [0, 1]],
            ["messageType", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "messageType")], [0, 1]],
            ["sourceType", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "sourceType")], [0, 1]],
            ["sourceCode", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "sourceCode")], [0, 1]],
            ["serviceMessageDetail", "CrvApiClient::Api::Animals::ServiceMessageDetail[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ServiceMessageDetail,
        :schema_name => XSD::QName.new(NsCommonTypes, "serviceMessageDetail"),
        :schema_element => [
            ["serviceStatus", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "serviceStatus")], [0, 1]],
            ["codeDetail", "CrvApiClient::Api::Animals::CodeDetail[]", [0, nil]],
            ["messageCode", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "messageCode")], [0, 1]],
            ["messageText", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "messageText")], [0, 1]],
            ["messageType", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "messageType")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ContextMessage,
        :schema_name => XSD::QName.new(NsCommonTypes, "contextMessage"),
        :schema_element => [
            ["sessionId", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "sessionId")], [0, 1]],
            ["processId", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "processId")], [0, 1]],
            ["instanceId", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "instanceId")], [0, 1]],
            ["username", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "username")], [0, 1]],
            ["userType", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "userType")], [0, 1]],
            ["password", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "password")], [0, 1]],
            ["organisation", "CrvApiClient::Api::Animals::ParticipantId", [0, 1]],
            ["provider", "CrvApiClient::Api::Animals::ParticipantId", [0, 1]],
            ["customer", "CrvApiClient::Api::Animals::ParticipantId", [0, 1]],
            ["keeper", "CrvApiClient::Api::Animals::ParticipantId", [0, 1]],
            ["animal", "CrvApiClient::Api::Animals::AnimalId", [0, 1]],
            ["processCode", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "processCode")], [0, 1]],
            ["messageSource", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "messageSource")], [0, 1]],
            ["languageCode", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "languageCode")], [0, 1]],
            ["timeZone", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "timeZone")], [0, 1]],
            ["contextMessageDetail", "CrvApiClient::Api::Animals::ContextMessageDetail[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::ContextMessageDetail,
        :schema_name => XSD::QName.new(NsCommonTypes, "contextMessageDetail"),
        :schema_element => [
            ["contextCode", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "contextCode")], [0, 1]],
            ["contextValue", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "contextValue")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::BooleanType,
        :schema_name => XSD::QName.new(NsCommon, "actual")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::NotificationType,
        :schema_name => XSD::QName.new(NsCommon, "notificationType")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::BooleanType,
        :schema_name => XSD::QName.new(NsDictionary, "actual")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::RepresentationType,
        :schema_name => XSD::QName.new(NsDictionary, "representationType")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::BooleanType,
        :schema_name => XSD::QName.new(NsAnimal, "IBR")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::BooleanType,
        :schema_name => XSD::QName.new(NsAnimal, "foodChainInfo")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::BooleanType,
        :schema_name => XSD::QName.new(NsAnimal, "foodChainInfoStandard")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Animals::BooleanType,
        :schema_name => XSD::QName.new(NsAnimal, "generalTermsConditions")
    )

  end
end
