module CrvApiClient
  module Helpers
    module Attributes

      #defines an public attribute reader and a private writer
      #name: the instance variable name for which a get method has to be created
      #type: The object type.
      def attr_reader_with_type(name, type)
        define_attribute_methods(name, type)
        class_eval { private "#{name}=" }
      end

      #defines an public attribute writer and reader.
      #name: the instance variable name for which a get method has to be created
      #type: The object type.
      def attr_accessor_with_type(name, type)
        define_attribute_methods(name, type)
      end

      private
      #defines the attribute set and get methods and
      def define_attribute_methods(name, type)
        define_method(name) do
          instance_variable_get("@#{name}")
        end

        define_method("#{name}=") do |value|
          raise ArgumentError.new("Invalid Type, #{value.class.name} is not a #{type.name} ") unless (value.is_a?(type) || value.nil?)
          instance_variable_set("@#{name}", value)
        end
      end
    end
  end
end