module CrvApiClient
  module Helpers
    module Endpoint

      private
      ##
      # Calculates api endpoint path based on class who includes this module
      # it adds the string '::Api' before the last '::' match.
      # Regex splits the class name and modules by the last '::' match
      # \1 is the string before the last '::' match
      # \2 contains the last :: match
      # \3 contains the string after the '::' match.
      # Returns a string
      # example::
      # class CrvApiClient::Animals returns CrvApiClient::Api::Animals
      # class CrvApiClient::Base::Before::Animals returns CrvApiClient::Base::Before::Api::Animals
      ##
      def class_api_endpoint
        self.class.name.gsub(/(.*)(::)(.*)/, '\1\2Api\2\3\2')
      end

      ##
      # Returns the Api Participant Id of the included class.
      ##
      def endpoint_participant_id
        Object.const_get(class_api_endpoint << "ParticipantId")
      end

      ##
      # Returns the Api ContextMessageDetail of the included class.
      ##
      def endpoint_context_message_detail
        Object.const_get(class_api_endpoint << "ContextMessageDetail")
      end

      def endpoint_context_message
        Object.const_get(class_api_endpoint << "ContextMessage")
      end

      def endpoint_animal_id
        Object.const_get(class_api_endpoint << "AnimalId")
      end

    end
  end
end