module CrvApiClient::Api::Reproduction

  module RsReproductionMappingRegistry
    EncodedRegistry = ::SOAP::Mapping::EncodedRegistry.new
    LiteralRegistry = ::SOAP::Mapping::LiteralRegistry.new
    NsAnimal = "http://ws.crvholding.com/animal/"
    NsAnimalTypes = "http://ws.crvholding.com/animalTypes/"
    NsBreeding = "http://ws.crvholding.com/breeding/"
    NsBreedingTypes = "http://ws.crvholding.com/breedingTypes/"
    NsC_1 = "ICARAggregateBusinessInformationEntity:1"
    NsC_10 = "urn:it:icar:ade:codelist:GenderCode:1.0"
    NsC_10_0 = "urn:it:icar:ade:codelist:LivestockLocationIdentifierCode:1.0"
    NsC_10_1 = "urn:it:icar:ade:codelist:LivestockLocationTypeCode:1.0"
    NsC_10_10 = "urn:it:icar:ade:codelist:QuarterCode:1.0"
    NsC_10_11 = "urn:it:icar:ade:codelist:ManufacturerCode:1.0"
    NsC_10_2 = "urn:it:icar:ade:codelist:MilkingTypeCode:1.0"
    NsC_10_3 = "urn:it:icar:ade:codelist:LabelCode:1.0"
    NsC_10_4 = "urn:it:icar:ade:codelist:ValidSampleFillingIndicatorCode:1.0"
    NsC_10_5 = "urn:it:icar:ade:codelist:BottleIdentifierCode:1.0"
    NsC_10_6 = "urn:it:icar:ade:codelist:RequestProcessingStatusCode:1.0"
    NsC_10_7 = "urn:it:icar:ade:codelist:ErrorSeverityCode:1.0"
    NsC_10_8 = "urn:it:icar:ade:codelist:SpecieCode:1.0"
    NsC_10_9 = "urn:it:icar:ade:codelist:MilkCharacteristicCode:1.0"
    NsC_13 = "urn:un:unece:uncefact:data:standard:UnqualifiedDataType:13"
    NsC_1_0 = "ADEType:1"
    NsC_20120831 = "urn:un:unece:uncefact:codelist:standard:5:ISO42173A:2012-08-31"
    NsC_20130103 = "urn:un:unece:uncefact:codelist:standard:IANA:MIMEMediaType:2013-01-03"
    NsC_20130108 = "urn:un:unece:uncefact:codelist:standard:IANA:CharacterSetCode:2013-01-08"
    NsC_40106 = "urn:un:unece:uncefact:codelist:standard:6:0133:40106"
    NsC_8 = "urn:un:unece:uncefact:codelist:standard:6:Recommendation20:8"
    NsCommon = "http://ws.crvholding.com/common/"
    NsCommonTypes = "http://ws.crvholding.com/commonTypes/"
    NsD12A = "urn:un:unece:uncefact:codelist:standard:6:3055:D12A"
    NsDictionary = "http://ws.crvholding.com/dictionary/"
    NsDictionaryTypes = "http://ws.crvholding.com/dictionaryTypes/"
    NsLogistics = "http://ws.crvholding.com/logistics/"
    NsLogisticsTypes = "http://ws.crvholding.com/logisticsTypes/"
    NsParticipant = "http://ws.crvholding.com/participant/"
    NsParticipantTypes = "http://ws.crvholding.com/participantTypes/"
    NsProduct = "http://ws.crvholding.com/product/"
    NsProductTypes = "http://ws.crvholding.com/productTypes/"
    NsReproduction = "http://ws.crvholding.com/reproduction/"
    NsReproductionMessages = "http://ws.crvholding.com/reproductionMessages/"
    NsReproductionTypes = "http://ws.crvholding.com/reproductionTypes/"
    NsSecondEdition2006VI13 = "urn:un:unece:uncefact:identifierlist:standard:5:ISO316612A:SecondEdition2006VI-13"

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ListTopGestationCalvingRequestType,
        :schema_type => XSD::QName.new(NsReproductionMessages, "listTopGestationCalvingRequestType"),
        :schema_element => [
            ["topGestationBreeding", "CrvApiClient::Api::Reproduction::TopGestationBreeding[]", [1, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::TopGestationBreeding,
        :schema_type => XSD::QName.new(NsReproductionMessages, "topGestationBreeding"),
        :schema_element => [
            ["cow", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["reproductionType", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "reproductionType")]],
            ["reproductionDate", [nil, XSD::QName.new(NsReproduction, "reproductionDate")]],
            ["calvingDateExp", [nil, XSD::QName.new(NsReproduction, "calvingDateExp")]],
            ["keeper", "CrvApiClient::Api::Reproduction::ParticipantId"],
            ["sire", "CrvApiClient::Api::Reproduction::AnimalId"],
            ["dam", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["breedCalculation", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "breedCalculation")]],
            ["breedingIndex", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "breedingIndex")]],
            ["contractType", "CrvApiClient::Api::Reproduction::ContractType[]", [0, nil]],
            ["countryCd", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "countryCd")], [0, 1]],
            ["workArea", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "workArea")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ContractType,
        :schema_type => XSD::QName.new(NsReproductionMessages, "contractType"),
        :schema_element => [
            ["contractType", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "contractType")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ListTopGestationCalvingResponseType,
        :schema_type => XSD::QName.new(NsReproductionMessages, "listTopGestationCalvingResponseType"),
        :schema_element => [
            ["topGestation", "CrvApiClient::Api::Reproduction::TopGestation[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::TopGestation,
        :schema_type => XSD::QName.new(NsReproductionMessages, "topGestation"),
        :schema_element => [
            ["topGestationBreeding", "CrvApiClient::Api::Reproduction::TopGestationBreeding"],
            ["gestationCalving", "CrvApiClient::Api::Reproduction::GestationCalving"]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::GestationCalving,
        :schema_type => XSD::QName.new(NsReproductionMessages, "gestationCalving"),
        :schema_element => [
            ["cow", "CrvApiClient::Api::Reproduction::AnimalId"],
            ["cowKeeper", "CrvApiClient::Api::Reproduction::ActualKeeper", [0, 1]],
            ["gestationDetails", "CrvApiClient::Api::Reproduction::LgcGestation", [0, 1]],
            ["calvingAndCalves", "CrvApiClient::Api::Reproduction::LgcCalving[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::LgcGestation,
        :schema_type => XSD::QName.new(NsReproductionMessages, "lgcGestation"),
        :schema_element => [
            ["gestation", "CrvApiClient::Api::Reproduction::Gestation"],
            ["gestationReproduction", "CrvApiClient::Api::Reproduction::GestationReproduction"],
            ["gestationPedigree", "CrvApiClient::Api::Reproduction::Pedigree[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::LgcCalving,
        :schema_type => XSD::QName.new(NsReproductionMessages, "lgcCalving"),
        :schema_element => [
            ["calving", "CrvApiClient::Api::Reproduction::Calving"],
            ["calf", "CrvApiClient::Api::Reproduction::LgcCalf[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::LgcCalf,
        :schema_type => XSD::QName.new(NsReproductionMessages, "lgcCalf"),
        :schema_element => [
            ["animal", "CrvApiClient::Api::Reproduction::Animal"],
            ["calfKeeper", "CrvApiClient::Api::Reproduction::ActualKeeper", [0, 1]],
            ["animalPedigree", "CrvApiClient::Api::Reproduction::Pedigree"]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ListFertilizationRequestType,
        :schema_type => XSD::QName.new(NsReproductionMessages, "listFertilizationRequestType"),
        :schema_element => [
            ["animal", "CrvApiClient::Api::Reproduction::AnimalId[]", [1, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ListFertilizationResponseType,
        :schema_type => XSD::QName.new(NsReproductionMessages, "listFertilizationResponseType"),
        :schema_element => [
            ["animal", "CrvApiClient::Api::Reproduction::FertilizationRA[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::FertilizationRA,
        :schema_type => XSD::QName.new(NsReproductionMessages, "fertilizationRA"),
        :schema_element => [
            ["animal", "CrvApiClient::Api::Reproduction::AnimalId"],
            ["reproductionStatus", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "reproductionStatus")]],
            ["fertilization", "CrvApiClient::Api::Reproduction::GestationReproduction[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ListAnimalReproductionRequestType,
        :schema_type => XSD::QName.new(NsReproductionMessages, "listAnimalReproductionRequestType"),
        :schema_element => [
            ["keeper", "CrvApiClient::Api::Reproduction::ParticipantId"],
            ["listParticipantAnimalRequest", "CrvApiClient::Api::Reproduction::ListParticipantAnimalRequest", [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ListAnimalReproductionResponseType,
        :schema_type => XSD::QName.new(NsReproductionMessages, "listAnimalReproductionResponseType"),
        :schema_element => [
            ["keeper", "CrvApiClient::Api::Reproduction::ParticipantId"],
            ["animalReproduction", "CrvApiClient::Api::Reproduction::AnimalReproduction[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AddAnimalReproductionIndicationRequestType,
        :schema_type => XSD::QName.new(NsReproductionMessages, "addAnimalReproductionIndicationRequestType"),
        :schema_element => [
            ["keeper", "CrvApiClient::Api::Reproduction::ParticipantId"],
            ["animalReproductionIndication", "CrvApiClient::Api::Reproduction::AnimalReproductionIndication[]", [1, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalExaminations,
        :schema_type => XSD::QName.new(NsReproductionMessages, "animalExaminations"),
        :schema_element => [
            ["nrOfExaminations", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "nrOfExaminations")]],
            ["minOfExaminations", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "minOfExaminations")]],
            ["animalExamination", "CrvApiClient::Api::Reproduction::AnimalExamination[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Echograms,
        :schema_type => XSD::QName.new(NsReproductionMessages, "echograms"),
        :schema_element => [
            ["nrOfEchograms", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "nrOfEchograms")]],
            ["minOfEchograms", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "minOfEchograms")]],
            ["animalExamination", "CrvApiClient::Api::Reproduction::AnimalExamination[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::PregnancyChecks,
        :schema_type => XSD::QName.new(NsReproductionMessages, "pregnancyChecks"),
        :schema_element => [
            ["nrOfPregnancyChecks", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "nrOfPregnancyChecks")]],
            ["minOfPregnancyChecks", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "minOfPregnancyChecks")]],
            ["animalExamination", "CrvApiClient::Api::Reproduction::AnimalExamination[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::InheatChecks,
        :schema_type => XSD::QName.new(NsReproductionMessages, "inheatChecks"),
        :schema_element => [
            ["nrOfInheatChecks", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "nrOfInheatChecks")]],
            ["minOfInheatChecks", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "minOfInheatChecks")]],
            ["animalExamination", "CrvApiClient::Api::Reproduction::AnimalExamination[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ProductDelivery,
        :schema_type => XSD::QName.new(NsReproductionMessages, "productDelivery"),
        :schema_element => [
            ["registrationTime", [nil, XSD::QName.new(NsReproduction, "registrationTime")]],
            ["productAmount", "CrvApiClient::Api::Reproduction::ProductAmount"]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::CowNotServed,
        :schema_type => XSD::QName.new(NsReproductionMessages, "cowNotServed"),
        :schema_element => [
            ["cow", "CrvApiClient::Api::Reproduction::AnimalId"],
            ["cowScanned", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "cowScanned")]],
            ["bullCd", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "bullCd")]],
            ["bullCdScanned", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "bullCdScanned")]],
            ["chargeNr", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "chargeNr")]],
            ["chargeNrScanned", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "chargeNrScanned")]],
            ["bull", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["semenType", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "semenType")]],
            ["ownStock", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "ownStock")]],
            ["semenChargeCd", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "semenChargeCd")]],
            ["refuseCd", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "refuseCd")]],
            ["registrationTime", [nil, XSD::QName.new(NsReproduction, "registrationTime")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::BrokenStraw,
        :schema_type => XSD::QName.new(NsReproductionMessages, "brokenStraw"),
        :schema_element => [
            ["bullCd", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "bullCd")]],
            ["bullCdScanned", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "bullCdScanned")]],
            ["chargeNr", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "chargeNr")]],
            ["chargeNrScanned", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "chargeNrScanned")]],
            ["bull", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["semenType", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "semenType")]],
            ["ownStock", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "ownStock")]],
            ["semenChargeCd", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "semenChargeCd")]],
            ["registrationTime", [nil, XSD::QName.new(NsReproduction, "registrationTime")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Support,
        :schema_type => XSD::QName.new(NsReproductionMessages, "support"),
        :schema_element => [
            ["supportCd", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "supportCd")]],
            ["nrOfMinutes", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "nrOfMinutes")]],
            ["registrationTime", [nil, XSD::QName.new(NsReproduction, "registrationTime")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::SiteVisit,
        :schema_type => XSD::QName.new(NsReproductionMessages, "siteVisit"),
        :schema_element => [
            ["siteVisitSerialNr", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "siteVisitSerialNr")]],
            ["site", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "site")]],
            ["siteScanned", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "siteScanned")]],
            ["orderNr", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "orderNr")]],
            ["statusVisit", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "statusVisit")]],
            ["registrationCompletedTime", [nil, XSD::QName.new(NsReproduction, "registrationCompletedTime")]],
            ["deliveryCheckCd", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "deliveryCheckCd")]],
            ["insemination", "CrvApiClient::Api::Reproduction::Insemination[]", [0, nil]],
            ["cowNotServed", "CrvApiClient::Api::Reproduction::CowNotServed[]", [0, nil]],
            ["brokenStraw", "CrvApiClient::Api::Reproduction::BrokenStraw[]", [0, nil]],
            ["productDelivery", "CrvApiClient::Api::Reproduction::ProductDelivery[]", [0, nil]],
            ["support", "CrvApiClient::Api::Reproduction::Support[]", [0, nil]],
            ["inheatChecks", "CrvApiClient::Api::Reproduction::InheatChecks", [0, 1]],
            ["pregnancyChecks", "CrvApiClient::Api::Reproduction::PregnancyChecks", [0, 1]],
            ["echograms", "CrvApiClient::Api::Reproduction::Echograms", [0, 1]],
            ["animalExaminations", "CrvApiClient::Api::Reproduction::AnimalExaminations", [0, 1]],
            ["transplantation", "CrvApiClient::Api::Reproduction::Transplantation[]", [0, nil]],
            ["flushing", "CrvApiClient::Api::Reproduction::Flushing[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AddAiEtDeliveryRequestType,
        :schema_type => XSD::QName.new(NsReproductionMessages, "addAiEtDeliveryRequestType"),
        :schema_element => [
            ["employee", "CrvApiClient::Api::Reproduction::ParticipantId"],
            ["round", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "round")]],
            ["deliveryDate", [nil, XSD::QName.new(NsReproduction, "deliveryDate")]],
            ["siteVisit", "CrvApiClient::Api::Reproduction::SiteVisit[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AddPreferredBullRequestType,
        :schema_type => XSD::QName.new(NsReproductionMessages, "addPreferredBullRequestType"),
        :schema_element => [
            ["keeper", "CrvApiClient::Api::Reproduction::ParticipantId"],
            ["preferredBull", "CrvApiClient::Api::Reproduction::AnimalId[]", [1, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::DeletePreferredBullRequestType,
        :schema_type => XSD::QName.new(NsReproductionMessages, "deletePreferredBullRequestType"),
        :schema_element => [
            ["keeper", "CrvApiClient::Api::Reproduction::ParticipantId"],
            ["preferredBull", "CrvApiClient::Api::Reproduction::AnimalId[]", [1, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ListPreferredBullRequestType,
        :schema_type => XSD::QName.new(NsReproductionMessages, "listPreferredBullRequestType"),
        :schema_element => [
            ["keeper", "CrvApiClient::Api::Reproduction::ParticipantId"]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ListPreferredBullResponseType,
        :schema_type => XSD::QName.new(NsReproductionMessages, "listPreferredBullResponseType"),
        :schema_element => [
            ["keeper", "CrvApiClient::Api::Reproduction::ParticipantId"],
            ["preferredBullDetails", "CrvApiClient::Api::Reproduction::BullDetails[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ListReproductionLastParityRequestType,
        :schema_type => XSD::QName.new(NsReproductionMessages, "listReproductionLastParityRequestType"),
        :schema_element => [
            ["keeper", "CrvApiClient::Api::Reproduction::ParticipantId"],
            ["participantAnimalRequest", "CrvApiClient::Api::Reproduction::ListParticipantAnimalRequest", [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ListReproductionLastParityResponseType,
        :schema_type => XSD::QName.new(NsReproductionMessages, "listReproductionLastParityResponseType"),
        :schema_element => [
            ["keeper", "CrvApiClient::Api::Reproduction::ParticipantId"],
            ["listReproductionLastParity", "CrvApiClient::Api::Reproduction::AnimalReproductionLastParity[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ListAnimalIndicationRequestType,
        :schema_type => XSD::QName.new(NsReproductionMessages, "listAnimalIndicationRequestType"),
        :schema_element => [
            ["keeper", "CrvApiClient::Api::Reproduction::ParticipantId"],
            ["indication", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "indication")], [0, 1]],
            ["indicationCertainty", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "indicationCertainty")], [0, 1]],
            ["active", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "active")], [0, 1]],
            ["period", "CrvApiClient::Api::Reproduction::PeriodRange", [0, 1]],
            ["animal", "CrvApiClient::Api::Reproduction::AnimalId[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ListAnimalIndicationResponseType,
        :schema_type => XSD::QName.new(NsReproductionMessages, "listAnimalIndicationResponseType"),
        :schema_element => [
            ["keeper", "CrvApiClient::Api::Reproduction::ParticipantId"],
            ["indication", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "indication")], [0, 1]],
            ["indicationCertainty", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "indicationCertainty")], [0, 1]],
            ["active", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "active")], [0, 1]],
            ["period", "CrvApiClient::Api::Reproduction::PeriodRange", [0, 1]],
            ["animalReproductionIndication", "CrvApiClient::Api::Reproduction::AnimalReproductionIndication[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ModifyAnimalIndicationRequestType,
        :schema_type => XSD::QName.new(NsReproductionMessages, "modifyAnimalIndicationRequestType"),
        :schema_element => [
            ["keeper", "CrvApiClient::Api::Reproduction::ParticipantId"],
            ["animal", "CrvApiClient::Api::Reproduction::AnimalId"],
            ["indication", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "indication")]],
            ["indicationDateTime", nil],
            ["indicationCertaintyOld", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "indicationCertaintyOld")]],
            ["indicationCertaintyNew", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "indicationCertaintyNew")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::LocalTime,
        :schema_type => XSD::QName.new(NsCommonTypes, "localTime"),
        :schema_element => [
            ["hourOfDay", "SOAP::SOAPInt"],
            ["minuteOfHour", "SOAP::SOAPInt"]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::LocalDate,
        :schema_type => XSD::QName.new(NsCommonTypes, "localDate"),
        :schema_element => [
            ["dayOfMonth", "SOAP::SOAPInt"],
            ["monthOfYear", "SOAP::SOAPInt"],
            ["year", "SOAP::SOAPInt"]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::PeriodRange,
        :schema_type => XSD::QName.new(NsCommonTypes, "periodRange"),
        :schema_element => [
            ["beginDate", [nil, XSD::QName.new(NsCommon, "beginDate")], [0, 1]],
            ["endDate", [nil, XSD::QName.new(NsCommon, "endDate")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ContextMessage,
        :schema_type => XSD::QName.new(NsCommonTypes, "contextMessage"),
        :schema_element => [
            ["sessionId", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "sessionId")], [0, 1]],
            ["processId", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "processId")], [0, 1]],
            ["instanceId", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "instanceId")], [0, 1]],
            ["username", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "username")], [0, 1]],
            ["userType", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "userType")], [0, 1]],
            ["password", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "password")], [0, 1]],
            ["organisation", "CrvApiClient::Api::Reproduction::ParticipantId", [0, 1]],
            ["provider", "CrvApiClient::Api::Reproduction::ParticipantId", [0, 1]],
            ["customer", "CrvApiClient::Api::Reproduction::ParticipantId", [0, 1]],
            ["keeper", "CrvApiClient::Api::Reproduction::ParticipantId", [0, 1]],
            ["animal", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["processCode", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "processCode")], [0, 1]],
            ["messageSource", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "messageSource")], [0, 1]],
            ["languageCode", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "languageCode")], [0, 1]],
            ["timeZone", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "timeZone")], [0, 1]],
            ["contextMessageDetail", "CrvApiClient::Api::Reproduction::ContextMessageDetail[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ContextMessageDetail,
        :schema_type => XSD::QName.new(NsCommonTypes, "contextMessageDetail"),
        :schema_element => [
            ["contextCode", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "contextCode")], [0, 1]],
            ["contextValue", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "contextValue")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ServiceMessage,
        :schema_type => XSD::QName.new(NsCommonTypes, "serviceMessage"),
        :schema_element => [
            ["serviceStatus", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "serviceStatus")]],
            ["messageCode", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "messageCode")], [0, 1]],
            ["messageText", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "messageText")], [0, 1]],
            ["messageType", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "messageType")], [0, 1]],
            ["sourceType", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "sourceType")], [0, 1]],
            ["sourceCode", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "sourceCode")], [0, 1]],
            ["serviceMessageDetail", "CrvApiClient::Api::Reproduction::ServiceMessageDetail[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ServiceMessageDetail,
        :schema_type => XSD::QName.new(NsCommonTypes, "serviceMessageDetail"),
        :schema_element => [
            ["serviceStatus", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "serviceStatus")], [0, 1]],
            ["codeDetail", "CrvApiClient::Api::Reproduction::CodeDetail[]", [0, nil]],
            ["messageCode", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "messageCode")], [0, 1]],
            ["messageText", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "messageText")], [0, 1]],
            ["messageType", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "messageType")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::CodeDetail,
        :schema_type => XSD::QName.new(NsCommonTypes, "codeDetail"),
        :schema_element => [
            ["keyId", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "keyId")], [0, 1]],
            ["keyValue", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "keyValue")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::SendNotificationRequestType,
        :schema_type => XSD::QName.new(NsCommonTypes, "sendNotificationRequestType"),
        :schema_element => [
            ["notificationType", ["CrvApiClient::Api::Reproduction::NotificationType", XSD::QName.new(NsCommon, "notificationType")], [0, 1]],
            ["notificationMessage", "CrvApiClient::Api::Reproduction::NotificationMessageType[]", [0, nil]],
            ["email", "CrvApiClient::Api::Reproduction::EmailType[]", [0, nil]],
            ["fax", "CrvApiClient::Api::Reproduction::FaxType[]", [0, nil]],
            ["sms", "CrvApiClient::Api::Reproduction::SmsType[]", [0, nil]],
            ["voice", "CrvApiClient::Api::Reproduction::VoiceType[]", [0, nil]],
            ["pager", "CrvApiClient::Api::Reproduction::PagerType[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::NotificationMessageType,
        :schema_type => XSD::QName.new(NsCommonTypes, "notificationMessageType"),
        :schema_element => [
            ["messageCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "messageCode")], [0, 1]],
            ["languageCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "languageCode")], [0, 1]],
            ["messageParameter", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "messageParameter")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::EmailType,
        :schema_type => XSD::QName.new(NsCommonTypes, "emailType"),
        :schema_element => [
            ["mailTo", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "mailTo")], [0, 1]],
            ["mailCc", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "mailCc")], [0, 1]],
            ["mailBcc", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "mailBcc")], [0, 1]],
            ["mailReplyTo", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "mailReplyTo")], [0, 1]],
            ["subject", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "subject")], [0, 1]],
            ["textBody", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "textBody")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::FaxType,
        :schema_type => XSD::QName.new(NsCommonTypes, "faxType"),
        :schema_element => [
            ["faxNr", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "faxNr")], [0, 1]],
            ["coverPage", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "coverPage")], [0, 1]],
            ["textBody", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "textBody")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::SmsType,
        :schema_type => XSD::QName.new(NsCommonTypes, "smsType"),
        :schema_element => [
            ["fromNr", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "fromNr")], [0, 1]],
            ["telNr", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "telNr")], [0, 1]],
            ["subject", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "subject")], [0, 1]],
            ["textBody", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "textBody")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::VoiceType,
        :schema_type => XSD::QName.new(NsCommonTypes, "voiceType"),
        :schema_element => [
            ["telNr", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "telNr")], [0, 1]],
            ["textBody", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "textBody")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::PagerType,
        :schema_type => XSD::QName.new(NsCommonTypes, "pagerType"),
        :schema_element => [
            ["fromNr", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "fromNr")], [0, 1]],
            ["pagerNr", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "pagerNr")], [0, 1]],
            ["textBody", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "textBody")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::GetLabel,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "getLabel"),
        :schema_element => [
            ["componentCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "componentCode")], [0, 1]],
            ["itemName", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "itemName")], [0, 1]],
            ["itemType", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "itemType")], [0, 1]],
            ["languageCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "languageCode")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Component,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "component"),
        :schema_element => [
            ["componentCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "componentCode")], [0, 1]],
            ["processCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "processCode")], [0, 1]],
            ["componentType", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "componentType")], [0, 1]],
            ["componentName", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "componentName")], [0, 1]],
            ["componentItem", "CrvApiClient::Api::Reproduction::ComponentItem[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ComponentItem,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "componentItem"),
        :schema_element => [
            ["item", "CrvApiClient::Api::Reproduction::Item[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Item,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "item"),
        :schema_element => [
            ["itemName", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "itemName")], [0, 1]],
            ["moduleCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "moduleCode")], [0, 1]],
            ["itemType", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "itemType")], [0, 1]],
            ["itemLng", "CrvApiClient::Api::Reproduction::ItemLng[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ItemLng,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "itemLng"),
        :schema_element => [
            ["languageCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "languageCode")], [0, 1]],
            ["itemLabel", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "itemLabel")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::GetSystemMessage,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "getSystemMessage"),
        :schema_element => [
            ["messageCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "messageCode")], [0, 1]],
            ["languageCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "languageCode")], [0, 1]],
            ["messageParameter", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "messageParameter")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::SystemMessage,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "systemMessage"),
        :schema_element => [
            ["message", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "message")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ListDomain,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "listDomain"),
        :schema_element => [
            ["domain", "CrvApiClient::Api::Reproduction::Domain[]", [0, nil]],
            ["languageCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "languageCode")], [0, 1]],
            ["representationType", ["CrvApiClient::Api::Reproduction::RepresentationType", XSD::QName.new(NsDictionary, "representationType")], [0, 1]],
            ["actual", ["CrvApiClient::Api::Reproduction::BooleanType", XSD::QName.new(NsDictionary, "actual")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::DomainValue,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "domainValue"),
        :schema_element => [
            ["domainCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "domainCode")]],
            ["columnValue", "CrvApiClient::Api::Reproduction::ColumnValue[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ColumnValue,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "columnValue"),
        :schema_element => [
            ["value", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "value")], [0, 1]],
            ["representation", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "representation")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Domain,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "domain"),
        :schema_element => [
            ["domainCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "domainCode")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::TimePeriod,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "timePeriod"),
        :schema_element => [
            ["beginDate", [nil, XSD::QName.new(NsCommon, "beginDate")], [0, 1]],
            ["beginTime", [nil, XSD::QName.new(NsCommon, "beginTime")], [0, 1]],
            ["endDate", [nil, XSD::QName.new(NsCommon, "endDate")], [0, 1]],
            ["endTime", [nil, XSD::QName.new(NsCommon, "endTime")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::IntervalId,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "intervalId"),
        :schema_element => [
            ["nr", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "nr")]],
            ["nrType", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "nrType")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalNumberCountry,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "animalNumberCountry"),
        :schema_element => [
            ["countryCd", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "countryCd")]],
            ["animalNrLength", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "animalNrLength")]],
            ["animalNrAlphanumeric", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "animalNrAlphanumeric")]],
            ["sortingOrder", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "sortingOrder")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::HourCode,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "hourCode"),
        :schema_element => [
            ["hourCd", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "hourCd")]],
            ["description", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "description")]],
            ["hourMutateAllowed", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "hourMutateAllowed")]],
            ["hourNecessary", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "hourNecessary")]],
            ["addressMutateAllowed", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "addressMutateAllowed")]],
            ["addressNecessary", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "addressNecessary")]],
            ["activityMutateAllowed", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "activityMutateAllowed")]],
            ["activityNecessary", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "activityNecessary")]],
            ["kilometresMutateAllowed", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "kilometresMutateAllowed")]],
            ["kilometresNecessary", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "kilometresNecessary")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Parameter,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "parameter"),
        :schema_element => [
            ["parameterName", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "parameterName")]],
            ["value", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "value")]],
            ["valueDescription", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "valueDescription")]],
            ["default", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "default")]],
            ["sortingOrder", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "sortingOrder")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Setting,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "setting"),
        :schema_element => [
            ["settingName", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "settingName")]],
            ["settingValue", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "settingValue")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ParticipantId,
        :schema_type => XSD::QName.new(NsParticipantTypes, "participantId"),
        :schema_element => [
            ["participantCode", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "participantCode")]],
            ["participantCodeType", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "participantCodeType")]],
            ["countryCode", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "countryCode")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::NameAddressLayout,
        :schema_type => XSD::QName.new(NsParticipantTypes, "nameAddressLayout"),
        :schema_element => [
            ["addressType", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "addressType")], [0, 1]],
            ["participantName", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "participantName")], [0, 1]],
            ["addressLine1", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "addressLine1")], [0, 1]],
            ["addressLine2", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "addressLine2")], [0, 1]],
            ["addressLine3", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "addressLine3")], [0, 1]],
            ["addressLine4", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "addressLine4")], [0, 1]],
            ["addressLine5", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "addressLine5")], [0, 1]],
            ["addressLine6", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "addressLine6")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Address,
        :schema_type => XSD::QName.new(NsParticipantTypes, "address"),
        :schema_element => [
            ["addressType", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "addressType")]],
            ["street", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "street")]],
            ["houseNr", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "houseNr")], [0, 1]],
            ["zipCd", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "zipCd")], [0, 1]],
            ["city", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "city")]],
            ["regionCd", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "regionCd")], [0, 1]],
            ["country", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "country")], [0, 1]],
            ["countryCd", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "countryCd")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Participant,
        :schema_type => XSD::QName.new(NsParticipantTypes, "participant"),
        :schema_element => [
            ["participant", "CrvApiClient::Api::Reproduction::ParticipantId"],
            ["preTitle", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "preTitle")], [0, 1]],
            ["initials", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "initials")], [0, 1]],
            ["firstname", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "firstname")], [0, 1]],
            ["prefix", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "prefix")], [0, 1]],
            ["surname", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "surname")], [0, 1]],
            ["postTitle", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "postTitle")], [0, 1]],
            ["composedName", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "composedName")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ConnectionDataBasic,
        :schema_type => XSD::QName.new(NsParticipantTypes, "connectionDataBasic"),
        :schema_element => [
            ["emailAddress", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "emailAddress")], [0, 1]],
            ["phoneNr", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "phoneNr")], [0, 1]],
            ["mobilePhone", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "mobilePhone")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Connection,
        :schema_type => XSD::QName.new(NsParticipantTypes, "connection"),
        :schema_element => [
            ["connectionType", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "connectionType")]],
            ["connection", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "connection")], [0, 1]],
            ["connectionUse", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "connectionUse")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ParticipantBasic,
        :schema_type => XSD::QName.new(NsParticipantTypes, "participantBasic"),
        :schema_element => [
            ["participant", "CrvApiClient::Api::Reproduction::Participant"],
            ["address", "CrvApiClient::Api::Reproduction::Address[]", [0, nil]],
            ["connectionDataBasic", "CrvApiClient::Api::Reproduction::ConnectionDataBasic", [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ParticipantComplete,
        :schema_type => XSD::QName.new(NsParticipantTypes, "participantComplete"),
        :schema_element => [
            ["participant", "CrvApiClient::Api::Reproduction::Participant"],
            ["address", "CrvApiClient::Api::Reproduction::Address[]", [0, nil]],
            ["connection", "CrvApiClient::Api::Reproduction::Connection[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ActualKeeper,
        :schema_type => XSD::QName.new(NsParticipantTypes, "actualKeeper"),
        :schema_element => [
            ["participant", "CrvApiClient::Api::Reproduction::ParticipantId"],
            ["nameAddressLayout", "CrvApiClient::Api::Reproduction::NameAddressLayout"]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalId,
        :schema_type => XSD::QName.new(NsAnimalTypes, "animalId"),
        :schema_element => [
            ["animalNumber", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalNumber")]],
            ["animalNumberType", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalNumberType")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalDetailsBirth,
        :schema_type => XSD::QName.new(NsAnimalTypes, "animalDetailsBirth"),
        :schema_element => [
            ["animalId", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["animalNumberShort", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalNumberShort")], [0, 1]],
            ["sex", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "sex")], [0, 1]],
            ["colourHair", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "colourHair")], [0, 1]],
            ["birthDate", [nil, XSD::QName.new(NsAnimal, "birthDate")], [0, 1]],
            ["animalName", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalName")], [0, 1]],
            ["surrogateDam", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["dam", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["sire", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["breedComposition", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "breedComposition")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Animal,
        :schema_type => XSD::QName.new(NsAnimalTypes, "animal"),
        :schema_element => [
            ["animalId", "CrvApiClient::Api::Reproduction::AnimalId"],
            ["animalNumberShort", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalNumberShort")], [0, 1]],
            ["sex", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "sex")]],
            ["colourHair", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "colourHair")], [0, 1]],
            ["birthDate", [nil, XSD::QName.new(NsAnimal, "birthDate")]],
            ["deathDate", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "deathDate")], [0, 1]],
            ["animalName", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalName")], [0, 1]],
            ["breedComposition", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "breedComposition")], [0, 1]],
            ["redFactor", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "redFactor")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalManagement,
        :schema_type => XSD::QName.new(NsAnimalTypes, "animalManagement"),
        :schema_element => [
            ["animalId", "CrvApiClient::Api::Reproduction::AnimalId"],
            ["animalName", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalName")], [0, 1]],
            ["farmersAnimalNr", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "farmersAnimalNr")], [0, 1]],
            ["animalGroupNr", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalGroupNr")], [0, 1]],
            ["productionPurposeDate", [nil, XSD::QName.new(NsAnimal, "productionPurposeDate")], [0, 1]],
            ["productionPurpose", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "productionPurpose")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalPedigree,
        :schema_type => XSD::QName.new(NsAnimalTypes, "animalPedigree"),
        :schema_element => [
            ["animal", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["animalNrShort", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalNrShort")], [0, 1]],
            ["animalName", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalName")], [0, 1]],
            ["farmersAnimalNr", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "farmersAnimalNr")], [0, 1]],
            ["sex", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "sex")], [0, 1]],
            ["birthDate", [nil, XSD::QName.new(NsAnimal, "birthDate")], [0, 1]],
            ["colourHair", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "colourHair")], [0, 1]],
            ["pedigree", "CrvApiClient::Api::Reproduction::Pedigree", [0, 1]],
            ["participantAnimal", "CrvApiClient::Api::Reproduction::ParticipantAnimalId[]", [0, nil]],
            ["groupCode", "CrvApiClient::Api::Reproduction::AnimalGroup[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalSupplyId,
        :schema_type => XSD::QName.new(NsAnimalTypes, "animalSupplyId"),
        :schema_element => [
            ["animal", "CrvApiClient::Api::Reproduction::AnimalId"],
            ["supplyType", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "supplyType")]],
            ["supplyCd", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "supplyCd")]],
            ["plannedDepartureDate", [nil, XSD::QName.new(NsAnimal, "plannedDepartureDate")], [0, 1]],
            ["trader", "CrvApiClient::Api::Reproduction::ParticipantId", [0, 1]],
            ["destination", "CrvApiClient::Api::Reproduction::ParticipantId", [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Addresses,
        :schema_type => XSD::QName.new(NsAnimalTypes, "addresses"),
        :schema_element => [
            ["participant", "CrvApiClient::Api::Reproduction::Participant[]", [0, nil]],
            ["address", "CrvApiClient::Api::Reproduction::Address[]", [0, nil]],
            ["trader", "CrvApiClient::Api::Reproduction::ParticipantId", [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalArrivalDetail,
        :schema_type => XSD::QName.new(NsAnimalTypes, "animalArrivalDetail"),
        :schema_element => [
            ["animalId", "CrvApiClient::Api::Reproduction::AnimalId[]", [1, nil]],
            ["plannedArrivalDetail", "CrvApiClient::Api::Reproduction::PlannedArrivalDetail"]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AverageHerdWeight,
        :schema_type => XSD::QName.new(NsAnimalTypes, "averageHerdWeight"),
        :schema_element => [
            ["keeper", "CrvApiClient::Api::Reproduction::ParticipantId"],
            ["referencePeriod", "CrvApiClient::Api::Reproduction::TimePeriod"],
            ["herdWeightCategoryResult", "CrvApiClient::Api::Reproduction::HerdWeightCategory[]", [1, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::BreedFraction,
        :schema_type => XSD::QName.new(NsAnimalTypes, "breedFraction"),
        :schema_element => [
            ["breed", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "breed")]],
            ["fraction", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "fraction")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::BullDetails,
        :schema_type => XSD::QName.new(NsAnimalTypes, "bullDetails"),
        :schema_element => [
            ["bullId", "CrvApiClient::Api::Reproduction::AnimalId"],
            ["aiCode", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["bullName", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "bullName")], [0, 1]],
            ["bullShortName", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "bullShortName")], [0, 1]],
            ["birthDate", [nil, XSD::QName.new(NsAnimal, "birthDate")], [0, 1]],
            ["colourHair", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "colourHair")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ColourCode,
        :schema_type => XSD::QName.new(NsAnimalTypes, "colourCode"),
        :schema_element => [
            ["countryCode", "SOAP::SOAPString"],
            ["colourCode", "SOAP::SOAPString"]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ChainValue,
        :schema_type => XSD::QName.new(NsAnimalTypes, "chainValue"),
        :schema_element => [
            ["chainType", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "chainType")]],
            ["chainVersion", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "chainVersion")]],
            ["chainRowValue", "CrvApiClient::Api::Reproduction::ChainRowValue[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ChainRowValue,
        :schema_type => XSD::QName.new(NsAnimalTypes, "chainRowValue"),
        :schema_element => [
            ["rowCd", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "rowCd")]],
            ["rowValue", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "rowValue")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::DateReason,
        :schema_type => XSD::QName.new(NsAnimalTypes, "dateReason"),
        :schema_element => [
            ["date", [nil, XSD::QName.new(NsCommon, "date")]],
            ["reason", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "reason")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalGroup,
        :schema_type => XSD::QName.new(NsAnimalTypes, "animalGroup"),
        :schema_element => [
            ["animalGroupType", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalGroupType")]],
            ["animalGroupCode", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalGroupCode")]],
            ["animalGroupName", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalGroupName")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::HerdWeightCategory,
        :schema_type => XSD::QName.new(NsAnimalTypes, "herdWeightCategory"),
        :schema_element => [
            ["categoryCd", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "categoryCd")]],
            ["avgNoAnimals", [nil, XSD::QName.new(NsAnimal, "avgNoAnimals")]],
            ["avgWeightAnimals", [nil, XSD::QName.new(NsAnimal, "avgWeightAnimals")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ListParticipantAnimalRequest,
        :schema_type => XSD::QName.new(NsAnimalTypes, "listParticipantAnimalRequest"),
        :schema_element => [
            ["listType", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "listType")], [0, 1]],
            ["participantAnimalRequest", "CrvApiClient::Api::Reproduction::ParticipantAnimalRequest[]", [1, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ParticipantAnimalId,
        :schema_type => XSD::QName.new(NsAnimalTypes, "participantAnimalId"),
        :schema_element => [
            ["numberType", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "numberType")]],
            ["numberSubType", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "numberSubType")]],
            ["participantAnimalNr", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "participantAnimalNr")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ParticipantAnimalRequest,
        :schema_type => XSD::QName.new(NsAnimalTypes, "participantAnimalRequest"),
        :schema_element => [
            ["numberType", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "numberType")]],
            ["numberSubType", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "numberSubType")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::PeriodRange_,
        :schema_type => XSD::QName.new(NsAnimalTypes, "periodRange"),
        :schema_element => [
            ["beginDate", [nil, XSD::QName.new(NsCommon, "beginDate")]],
            ["endDate", [nil, XSD::QName.new(NsCommon, "endDate")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::PlannedArrivalDetail,
        :schema_type => XSD::QName.new(NsAnimalTypes, "plannedArrivalDetail"),
        :schema_element => [
            ["supplyCd", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "supplyCd")]],
            ["keeper", "CrvApiClient::Api::Reproduction::ParticipantId"],
            ["plannedDepartureDate", [nil, XSD::QName.new(NsAnimal, "plannedDepartureDate")], [0, 1]],
            ["foodChainInfo", ["CrvApiClient::Api::Reproduction::BooleanType", XSD::QName.new(NsAnimal, "foodChainInfo")], [0, 1]],
            ["foodChainInfoStandard", ["CrvApiClient::Api::Reproduction::BooleanType", XSD::QName.new(NsAnimal, "foodChainInfoStandard")], [0, 1]],
            ["trader", "CrvApiClient::Api::Reproduction::ParticipantId"],
            ["loadGroup", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "loadGroup")], [0, 1]],
            ["destination", "CrvApiClient::Api::Reproduction::ParticipantId", [0, 1]],
            ["plannedDeliveryDateTime", [nil, XSD::QName.new(NsAnimal, "plannedDeliveryDateTime")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Pedigree,
        :schema_type => XSD::QName.new(NsAnimalTypes, "pedigree"),
        :schema_element => [
            ["sire", "CrvApiClient::Api::Reproduction::Animal", [0, 1]],
            ["dam", "CrvApiClient::Api::Reproduction::Animal", [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::PlannedArrival,
        :schema_type => XSD::QName.new(NsAnimalTypes, "plannedArrival"),
        :schema_element => [
            ["animal", "CrvApiClient::Api::Reproduction::Animal[]", [0, nil]],
            ["plannedArrivalDetail", "CrvApiClient::Api::Reproduction::PlannedArrivalDetail"],
            ["breedFraction", "CrvApiClient::Api::Reproduction::BreedFraction[]", [1, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::SemenAmount,
        :schema_type => XSD::QName.new(NsLogisticsTypes, "semenAmount"),
        :schema_element => [
            ["bullCd", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "bullCd")]],
            ["semenType", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "semenType")]],
            ["amount", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "amount")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::DistributionRound,
        :schema_type => XSD::QName.new(NsLogisticsTypes, "distributionRound"),
        :schema_element => [
            ["employee", "CrvApiClient::Api::Reproduction::ParticipantId_"],
            ["deliveryDate", [nil, XSD::QName.new(NsLogistics, "deliveryDate")]],
            ["round", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "round")], [0, 1]],
            ["district", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "district")], [0, 1]],
            ["routeCd", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "routeCd")], [0, 1]],
            ["licensePlate", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "licensePlate")], [0, 1]],
            ["startKilometres", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "startKilometres")], [0, 1]],
            ["endKilometres", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "endKilometres")], [0, 1]],
            ["kilometres", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "kilometres")], [0, 1]],
            ["mainDepot", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "mainDepot")], [0, 1]],
            ["privateDepot", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "privateDepot")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::OrderConfirmation,
        :schema_type => XSD::QName.new(NsLogisticsTypes, "orderConfirmation"),
        :schema_element => [
            ["orderNr", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "orderNr")]],
            ["orderLineNr", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "orderLineNr")]],
            ["amount", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "amount")]],
            ["registrationTime", [nil, XSD::QName.new(NsLogistics, "registrationTime")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::SemenRemoval,
        :schema_type => XSD::QName.new(NsLogisticsTypes, "semenRemoval"),
        :schema_element => [
            ["depot", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "depot")]],
            ["removalReasonCd", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "removalReasonCd")]],
            ["registrationTime", [nil, XSD::QName.new(NsLogistics, "registrationTime")]],
            ["semenRemoved", "CrvApiClient::Api::Reproduction::SemenAmount"]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::SemenTransfer,
        :schema_type => XSD::QName.new(NsLogisticsTypes, "semenTransfer"),
        :schema_element => [
            ["depotFrom", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "depotFrom")]],
            ["depotTo", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "depotTo")]],
            ["registrationTime", [nil, XSD::QName.new(NsLogistics, "registrationTime")]],
            ["semenTransfered", "CrvApiClient::Api::Reproduction::SemenAmount[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::TimeRegistration,
        :schema_type => XSD::QName.new(NsLogisticsTypes, "timeRegistration"),
        :schema_element => [
            ["hourCd", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "hourCd")]],
            ["nrOfAddresses", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "nrOfAddresses")]],
            ["nrOfActivities", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "nrOfActivities")]],
            ["minutes", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "minutes")]],
            ["kilometres", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "kilometres")]],
            ["registrationTime", [nil, XSD::QName.new(NsLogistics, "registrationTime")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Announcement,
        :schema_type => XSD::QName.new(NsLogisticsTypes, "announcement"),
        :schema_element => [
            ["announcementText", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "announcementText")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Depot,
        :schema_type => XSD::QName.new(NsLogisticsTypes, "depot"),
        :schema_element => [
            ["depot", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "depot")]],
            ["depotName", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "depotName")]],
            ["city", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "city")]],
            ["semenStock", "CrvApiClient::Api::Reproduction::SemenAmount[]", [0, nil]],
            ["semenOrder", "CrvApiClient::Api::Reproduction::SemenOrder[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::EmployeeOnRoute,
        :schema_type => XSD::QName.new(NsLogisticsTypes, "employeeOnRoute"),
        :schema_element => [
            ["employee", "CrvApiClient::Api::Reproduction::ParticipantId"],
            ["employeeName", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "employeeName")]],
            ["routeCd", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "routeCd")]],
            ["nrOfAddresses", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "nrOfAddresses")]],
            ["nrOfActivities", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "nrOfActivities")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::SemenOrder,
        :schema_type => XSD::QName.new(NsLogisticsTypes, "semenOrder"),
        :schema_element => [
            ["site", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "site")]],
            ["orderNr", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "orderNr")]],
            ["orderLineNr", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "orderLineNr")]],
            ["deliveryDate", [nil, XSD::QName.new(NsLogistics, "deliveryDate")]],
            ["semenOrdered", "CrvApiClient::Api::Reproduction::SemenAmount"]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::EmbryoCollection,
        :schema_type => XSD::QName.new(NsLogisticsTypes, "embryoCollection"),
        :schema_element => [
            ["embryoCollectionNr", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "embryoCollectionNr")]],
            ["sire", "CrvApiClient::Api::Reproduction::AnimalId"],
            ["sireName", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "sireName")], [0, 1]],
            ["dam", "CrvApiClient::Api::Reproduction::AnimalId"],
            ["damName", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "damName")], [0, 1]],
            ["semenType", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "semenType")]],
            ["embryoCollectionDate", [nil, XSD::QName.new(NsLogistics, "embryoCollectionDate")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ParticipantId_,
        :schema_type => XSD::QName.new(NsLogisticsTypes, "participantId"),
        :schema_element => [
            ["participantCode", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "participantCode")]],
            ["participantCodeType", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "participantCodeType")], [0, 1]],
            ["countryCode", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "countryCode")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalIndication,
        :schema_type => XSD::QName.new(NsReproductionTypes, "animalIndication"),
        :schema_element => [
            ["animal", "CrvApiClient::Api::Reproduction::AnimalId"],
            ["indicationType", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "indicationType")]],
            ["indication", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "indication")]],
            ["indicationDateTime", [nil, XSD::QName.new(NsReproduction, "indicationDateTime")]],
            ["indicationExpirationDateTime", [nil, XSD::QName.new(NsReproduction, "indicationExpirationDateTime")], [0, 1]],
            ["indicationCertainty", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "indicationCertainty")]],
            ["indicatorCode", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "indicatorCode")]],
            ["indicatorCodeType", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "indicatorCodeType")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Calving,
        :schema_type => XSD::QName.new(NsReproductionTypes, "calving"),
        :schema_element => [
            ["calvingDate", [nil, XSD::QName.new(NsReproduction, "calvingDate")]],
            ["parity", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "parity")], [0, 1]],
            ["gestationLength", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "gestationLength")], [0, 1]],
            ["calvingEaseScore", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "calvingEaseScore")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Gestation,
        :schema_type => XSD::QName.new(NsReproductionTypes, "gestation"),
        :schema_element => [
            ["reproductionDate", [nil, XSD::QName.new(NsReproduction, "reproductionDate")]],
            ["calvingDateExp", [nil, XSD::QName.new(NsReproduction, "calvingDateExp")]],
            ["gestationStatus", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "gestationStatus")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::GestationReproduction,
        :schema_type => XSD::QName.new(NsReproductionTypes, "gestationReproduction"),
        :schema_element => [
            ["reproductionType", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "reproductionType")]],
            ["reproductionDate", [nil, XSD::QName.new(NsReproduction, "reproductionDate")]],
            ["endDateRWB", [nil, XSD::QName.new(NsReproduction, "endDateRWB")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalReproduction,
        :schema_type => XSD::QName.new(NsReproductionTypes, "animalReproduction"),
        :schema_element => [
            ["animal", "CrvApiClient::Api::Reproduction::AnimalId"],
            ["animalNrShort", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalNrShort")]],
            ["animalName", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalName")], [0, 1]],
            ["farmersAnimalNr", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "farmersAnimalNr")], [0, 1]],
            ["sex", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "sex")]],
            ["birthDate", [nil, XSD::QName.new(NsAnimal, "birthDate")], [0, 1]],
            ["colourHair", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "colourHair")], [0, 1]],
            ["dam", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["sire", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["sireName", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "sireName")], [0, 1]],
            ["lastCalvingDate", [nil, XSD::QName.new(NsReproduction, "lastCalvingDate")], [0, 1]],
            ["lastInseminationDate", [nil, XSD::QName.new(NsReproduction, "lastInseminationDate")], [0, 1]],
            ["serviceSire", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["serviceSireName", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "serviceSireName")], [0, 1]],
            ["lastDryDate", [nil, XSD::QName.new(NsReproduction, "lastDryDate")], [0, 1]],
            ["expectedCalvingDate", [nil, XSD::QName.new(NsReproduction, "expectedCalvingDate")], [0, 1]],
            ["reproductionStatus", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "reproductionStatus")]],
            ["lastInHeatDate", [nil, XSD::QName.new(NsReproduction, "lastInHeatDate")], [0, 1]],
            ["participantAnimal", "CrvApiClient::Api::Reproduction::ParticipantAnimalId[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalReproductionLastParity,
        :schema_type => XSD::QName.new(NsReproductionTypes, "animalReproductionLastParity"),
        :schema_element => [
            ["animal", "CrvApiClient::Api::Reproduction::AnimalId"],
            ["animalNrShort", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalNrShort")]],
            ["animalName", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalName")], [0, 1]],
            ["farmersAnimalNr", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "farmersAnimalNr")], [0, 1]],
            ["calving", "CrvApiClient::Api::Reproduction::Calving", [0, 1]],
            ["lastInseminationDate", [nil, XSD::QName.new(NsReproduction, "lastInseminationDate")], [0, 1]],
            ["serviceSire", "CrvApiClient::Api::Reproduction::AnimalId[]", [0, nil]],
            ["serviceSireName", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "serviceSireName")], [0, 1]],
            ["serviceSireSemenType", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "serviceSireSemenType")], [0, 1]],
            ["dryDate", [nil, XSD::QName.new(NsReproduction, "dryDate")], [0, 1]],
            ["expectedCalvingDate", [nil, XSD::QName.new(NsReproduction, "expectedCalvingDate")], [0, 1]],
            ["reproductionStatus", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "reproductionStatus")]],
            ["lastInHeatDate", [nil, XSD::QName.new(NsReproduction, "lastInHeatDate")], [0, 1]],
            ["participantAnimal", "CrvApiClient::Api::Reproduction::ParticipantAnimalId[]", [0, nil]],
            ["nrOfInseminations", [nil, XSD::QName.new(NsReproduction, "nrOfInseminations")], [0, 1]],
            ["lastPregnancyCheckDate", [nil, XSD::QName.new(NsReproduction, "lastPregnancyCheckDate")], [0, 1]],
            ["pregnancyCheckResult", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "pregnancyCheckResult")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalReproductionIndication,
        :schema_type => XSD::QName.new(NsReproductionTypes, "animalReproductionIndication"),
        :schema_element => [
            ["animal", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["participantAnimal", "CrvApiClient::Api::Reproduction::ParticipantAnimalId", [0, 1]],
            ["indication", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "indication")]],
            ["indicationDateTime", [nil, XSD::QName.new(NsReproduction, "indicationDateTime")], [0, 1]],
            ["indicationExpirationDateTime", [nil, XSD::QName.new(NsReproduction, "indicationExpirationDateTime")], [0, 1]],
            ["indicationCertainty", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "indicationCertainty")], [0, 1]],
            ["indicator", "CrvApiClient::Api::Reproduction::ParticipantId", [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::InseminationForFlushing,
        :schema_type => XSD::QName.new(NsReproductionTypes, "inseminationForFlushing"),
        :schema_element => [
            ["serialNr", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "serialNr")], [0, 1]],
            ["inseminationDate", [nil, XSD::QName.new(NsReproduction, "inseminationDate")]],
            ["bull", "CrvApiClient::Api::Reproduction::AnimalId"],
            ["bullCd", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "bullCd")], [0, 1]],
            ["semenType", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "semenType")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalExamination,
        :schema_type => XSD::QName.new(NsReproductionTypes, "animalExamination"),
        :schema_element => [
            ["cow", "CrvApiClient::Api::Reproduction::AnimalId"],
            ["cowScanned", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "cowScanned")]],
            ["examinationCd", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "examinationCd")]],
            ["examinationResult", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "examinationResult")], [0, 1]],
            ["registrationTime", [nil, XSD::QName.new(NsReproduction, "registrationTime")]],
            ["productAmount", "CrvApiClient::Api::Reproduction::ProductAmount[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::EmbryoFrozen,
        :schema_type => XSD::QName.new(NsReproductionTypes, "embryoFrozen"),
        :schema_element => [
            ["embryoSerialNr", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "embryoSerialNr")]],
            ["trypsineBatchNr", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "trypsineBatchNr")]],
            ["mediumBatchNr", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "mediumBatchNr")]],
            ["containerNr", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "containerNr")]],
            ["canisterNr", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "canisterNr")]],
            ["qualityCd", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "qualityCd")]],
            ["stageCd", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "stageCd")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Flushing,
        :schema_type => XSD::QName.new(NsReproductionTypes, "flushing"),
        :schema_element => [
            ["dam", "CrvApiClient::Api::Reproduction::AnimalId"],
            ["embryoCollectionNr", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "embryoCollectionNr")]],
            ["flushingSolutionBatchNr", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "flushingSolutionBatchNr")]],
            ["holdingSolutionBatchNr", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "holdingSolutionBatchNr")]],
            ["numberOfOocyte", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "numberOfOocyte")], [0, 1]],
            ["numberOfEmbryo", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "numberOfEmbryo")], [0, 1]],
            ["numberOfEmbryoFrozen", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "numberOfEmbryoFrozen")], [0, 1]],
            ["debtor", "CrvApiClient::Api::Reproduction::ParticipantId_", [0, 1]],
            ["registrationTime", [nil, XSD::QName.new(NsReproduction, "registrationTime")]],
            ["inseminationForFlushing", "CrvApiClient::Api::Reproduction::InseminationForFlushing[]", [0, nil]],
            ["embryoFrozen", "CrvApiClient::Api::Reproduction::EmbryoFrozen[]", [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Insemination,
        :schema_type => XSD::QName.new(NsReproductionTypes, "insemination"),
        :schema_element => [
            ["cow", "CrvApiClient::Api::Reproduction::AnimalId"],
            ["cowScanned", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "cowScanned")]],
            ["bullCd", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "bullCd")]],
            ["bullCdScanned", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "bullCdScanned")]],
            ["chargeNr", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "chargeNr")]],
            ["chargeNrScanned", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "chargeNrScanned")]],
            ["bull", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["semenType", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "semenType")]],
            ["ownStock", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "ownStock")]],
            ["semenChargeCd", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "semenChargeCd")]],
            ["fertilityScore", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "fertilityScore")], [0, 1]],
            ["examinationCd", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "examinationCd")], [0, 1]],
            ["inseminationForFlushing", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "inseminationForFlushing")]],
            ["registrationTime", [nil, XSD::QName.new(NsReproduction, "registrationTime")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Indications,
        :schema_type => XSD::QName.new(NsReproductionTypes, "indications"),
        :schema_element => [
            ["indication", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "indication")]],
            ["indicationDateTime", nil],
            ["indicationCertaintyOld", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "indicationCertaintyOld")]],
            ["indicationCertaintyNew", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "indicationCertaintyNew")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Transplantation,
        :schema_type => XSD::QName.new(NsReproductionTypes, "transplantation"),
        :schema_element => [
            ["cow", "CrvApiClient::Api::Reproduction::AnimalId"],
            ["cowScanned", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "cowScanned")]],
            ["recipientRejected", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "recipientRejected")]],
            ["embryoCollectionNr", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "embryoCollectionNr")], [0, 1]],
            ["embryoSerialNr", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "embryoSerialNr")], [0, 1]],
            ["chargeEmbryo", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "chargeEmbryo")], [0, 1]],
            ["sire", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["bullCdSire", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "bullCdSire")], [0, 1]],
            ["dam", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["embryoCollectionDate", [nil, XSD::QName.new(NsReproduction, "embryoCollectionDate")], [0, 1]],
            ["debtor", "CrvApiClient::Api::Reproduction::ParticipantId_", [0, 1]],
            ["registrationTime", [nil, XSD::QName.new(NsReproduction, "registrationTime")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ProductDescription,
        :schema_type => XSD::QName.new(NsProductTypes, "productDescription"),
        :schema_element => [
            ["productCd", ["SOAP::SOAPString", XSD::QName.new(NsProduct, "productCd")]],
            ["description", ["SOAP::SOAPString", XSD::QName.new(NsProduct, "description")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::BullDetails_,
        :schema_type => XSD::QName.new(NsProductTypes, "bullDetails"),
        :schema_element => [
            ["bullCd", ["SOAP::SOAPString", XSD::QName.new(NsProduct, "bullCd")]],
            ["bullName", ["SOAP::SOAPString", XSD::QName.new(NsProduct, "bullName")]],
            ["bull", "CrvApiClient::Api::Reproduction::AnimalId"],
            ["sireName", ["SOAP::SOAPString", XSD::QName.new(NsProduct, "sireName")]],
            ["damSireName", ["SOAP::SOAPString", XSD::QName.new(NsProduct, "damSireName")]],
            ["colourHair", ["SOAP::SOAPString", XSD::QName.new(NsProduct, "colourHair")]],
            ["breedFactor1", ["SOAP::SOAPString", XSD::QName.new(NsProduct, "breedFactor1")], [0, 1]],
            ["breedFactor2", ["SOAP::SOAPString", XSD::QName.new(NsProduct, "breedFactor2")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ProductAmount,
        :schema_type => XSD::QName.new(NsProductTypes, "productAmount"),
        :schema_element => [
            ["productCd", ["SOAP::SOAPString", XSD::QName.new(NsProduct, "productCd")]],
            ["batchNr", ["SOAP::SOAPString", XSD::QName.new(NsProduct, "batchNr")], [0, 1]],
            ["amount", ["SOAP::SOAPString", XSD::QName.new(NsProduct, "amount")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalOffer,
        :schema_type => XSD::QName.new(NsBreedingTypes, "animalOffer"),
        :schema_element => [
            ["animalOfferType", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "animalOfferType")], [0, 1]],
            ["animalId", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["owner", "CrvApiClient::Api::Reproduction::ParticipantId", [0, 1]],
            ["keeper", "CrvApiClient::Api::Reproduction::ParticipantId", [0, 1]],
            ["agreement", ["CrvApiClient::Api::Reproduction::BooleanType", XSD::QName.new(NsBreeding, "agreement")], [0, 1]],
            ["ibrFree", ["CrvApiClient::Api::Reproduction::BooleanType", XSD::QName.new(NsBreeding, "ibrFree")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalBullAdvice,
        :schema_type => XSD::QName.new(NsBreedingTypes, "animalBullAdvice"),
        :schema_element => [
            ["animalId", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["recommendedBull", "CrvApiClient::Api::Reproduction::RecommendedBull[]", [0, 3]],
            ["missingAdvice", "CrvApiClient::Api::Reproduction::MissingAdvice[]", [0, 3]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalDetailsBreeding,
        :schema_type => XSD::QName.new(NsBreedingTypes, "animalDetailsBreeding"),
        :schema_element => [
            ["animalId", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["animalName", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalName")], [0, 1]],
            ["breedCalculation", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "breedCalculation")], [0, 1]],
            ["contractNumber", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "contractNumber")], [0, 1]],
            ["embryoNumber", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "embryoNumber")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalOfferAnalysisRequest,
        :schema_type => XSD::QName.new(NsBreedingTypes, "animalOfferAnalysisRequest"),
        :schema_element => [
            ["requestDate", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "requestDate")], [0, 1]],
            ["requestTime", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "requestTime")], [0, 1]],
            ["analysisType", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "analysisType")], [0, 1]],
            ["analysisName", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "analysisName")], [0, 1]],
            ["requested", ["CrvApiClient::Api::Reproduction::BooleanType", XSD::QName.new(NsBreeding, "requested")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalOfferAnalysis,
        :schema_type => XSD::QName.new(NsBreedingTypes, "animalOfferAnalysis"),
        :schema_element => [
            ["analysisType", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "analysisType")], [0, 1]],
            ["analysisName", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "analysisName")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnalysisRequest,
        :schema_type => XSD::QName.new(NsBreedingTypes, "analysisRequest"),
        :schema_element => [
            ["analysisType", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "analysisType")], [0, 1]],
            ["requested", ["CrvApiClient::Api::Reproduction::BooleanType", XSD::QName.new(NsBreeding, "requested")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalOfferStatus,
        :schema_type => XSD::QName.new(NsBreedingTypes, "animalOfferStatus"),
        :schema_element => [
            ["statusDate", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "statusDate")], [0, 1]],
            ["statusTime", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "statusTime")], [0, 1]],
            ["registrant", "CrvApiClient::Api::Reproduction::ParticipantId", [0, 1]],
            ["registrantName", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "registrantName")], [0, 1]],
            ["processCode", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "processCode")], [0, 1]],
            ["processName", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "processName")], [0, 1]],
            ["statusType", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "statusType")], [0, 1]],
            ["statusDescription", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "statusDescription")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::MissingAdvice,
        :schema_type => XSD::QName.new(NsBreedingTypes, "missingAdvice"),
        :schema_element => [
            ["ranking", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "ranking")]],
            ["missingAdviceType", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "missingAdviceType")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::RecommendedBull,
        :schema_type => XSD::QName.new(NsBreedingTypes, "recommendedBull"),
        :schema_element => [
            ["ranking", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "ranking")]],
            ["name", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "name")], [0, 1]],
            ["aiCode", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["semenType", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "semenType")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::GetHerdListRequestType,
        :schema_type => XSD::QName.new(NsC_1, "GetHerdListRequestType"),
        :schema_element => [
            ["messageHeader", ["CrvApiClient::Api::Reproduction::ADEExchangedDocumentType", XSD::QName.new(NsC_1, "MessageHeader")]],
            ["standardRequest", ["CrvApiClient::Api::Reproduction::StandardRequestType", XSD::QName.new(NsC_1, "StandardRequest")]],
            ["specificRequestGetHerdList", ["CrvApiClient::Api::Reproduction::SpecificRequestGetHerdListType", XSD::QName.new(NsC_1, "SpecificRequestGetHerdList")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::GetHerdListResponseType,
        :schema_type => XSD::QName.new(NsC_1, "GetHerdListResponseType"),
        :schema_element => [
            ["messageHeader", ["CrvApiClient::Api::Reproduction::ADEExchangedDocumentType", XSD::QName.new(NsC_1, "MessageHeader")]],
            ["standardResponse", ["CrvApiClient::Api::Reproduction::StandardResponseType", XSD::QName.new(NsC_1, "StandardResponse")]],
            ["specificResponseGetHerdList", ["CrvApiClient::Api::Reproduction::SpecificResponseGetHerdListType", XSD::QName.new(NsC_1, "SpecificResponseGetHerdList")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::UpdateAnimalRequestType,
        :schema_type => XSD::QName.new(NsC_1, "UpdateAnimalRequestType"),
        :schema_element => [
            ["messageHeader", ["CrvApiClient::Api::Reproduction::ADEExchangedDocumentType", XSD::QName.new(NsC_1, "MessageHeader")]],
            ["standardRequest", ["CrvApiClient::Api::Reproduction::StandardRequestType", XSD::QName.new(NsC_1, "StandardRequest")]],
            ["specificRequestAnimal", ["CrvApiClient::Api::Reproduction::SpecificRequestAnimalType", XSD::QName.new(NsC_1, "SpecificRequestAnimal")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::UpdateAnimalResponseType,
        :schema_type => XSD::QName.new(NsC_1, "UpdateAnimalResponseType"),
        :schema_element => [
            ["messageHeader", ["CrvApiClient::Api::Reproduction::ADEExchangedDocumentType", XSD::QName.new(NsC_1, "MessageHeader")]],
            ["standardResponse", ["CrvApiClient::Api::Reproduction::StandardResponseType", XSD::QName.new(NsC_1, "StandardResponse")]],
            ["specificResponse", ["CrvApiClient::Api::Reproduction::SpecificResponseType", XSD::QName.new(NsC_1, "SpecificResponse")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::UpdateDeviceRequestType,
        :schema_type => XSD::QName.new(NsC_1, "UpdateDeviceRequestType"),
        :schema_element => [
            ["messageHeader", ["CrvApiClient::Api::Reproduction::ADEExchangedDocumentType", XSD::QName.new(NsC_1, "MessageHeader")]],
            ["standardRequest", ["CrvApiClient::Api::Reproduction::StandardRequestType", XSD::QName.new(NsC_1, "StandardRequest")]],
            ["specificRequestDevice", ["CrvApiClient::Api::Reproduction::SpecificRequestDeviceType", XSD::QName.new(NsC_1, "SpecificRequestDevice")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::UpdateDeviceResponseType,
        :schema_type => XSD::QName.new(NsC_1, "UpdateDeviceResponseType"),
        :schema_element => [
            ["messageHeader", ["CrvApiClient::Api::Reproduction::ADEExchangedDocumentType", XSD::QName.new(NsC_1, "MessageHeader")]],
            ["standardResponse", ["CrvApiClient::Api::Reproduction::StandardResponseType", XSD::QName.new(NsC_1, "StandardResponse")]],
            ["specificResponse", ["CrvApiClient::Api::Reproduction::SpecificResponseType", XSD::QName.new(NsC_1, "SpecificResponse")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::UpdateLivestockLocationRequestType,
        :schema_type => XSD::QName.new(NsC_1, "UpdateLivestockLocationRequestType"),
        :schema_element => [
            ["messageHeader", ["CrvApiClient::Api::Reproduction::ADEExchangedDocumentType", XSD::QName.new(NsC_1, "MessageHeader")]],
            ["standardRequest", ["CrvApiClient::Api::Reproduction::StandardRequestType", XSD::QName.new(NsC_1, "StandardRequest")]],
            ["specificRequestLivestockLocation", ["CrvApiClient::Api::Reproduction::SpecificRequestLivestockLocationType", XSD::QName.new(NsC_1, "SpecificRequestLivestockLocation")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::UpdateLivestockLocationResponseType,
        :schema_type => XSD::QName.new(NsC_1, "UpdateLivestockLocationResponseType"),
        :schema_element => [
            ["messageHeader", ["CrvApiClient::Api::Reproduction::ADEExchangedDocumentType", XSD::QName.new(NsC_1, "MessageHeader")]],
            ["standardResponse", ["CrvApiClient::Api::Reproduction::StandardResponseType", XSD::QName.new(NsC_1, "StandardResponse")]],
            ["specificResponse", ["CrvApiClient::Api::Reproduction::SpecificResponseType", XSD::QName.new(NsC_1, "SpecificResponse")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::UpdateMilkingResultRequestType,
        :schema_type => XSD::QName.new(NsC_1, "UpdateMilkingResultRequestType"),
        :schema_element => [
            ["messageHeader", ["CrvApiClient::Api::Reproduction::ADEExchangedDocumentType", XSD::QName.new(NsC_1, "MessageHeader")]],
            ["standardRequest", ["CrvApiClient::Api::Reproduction::StandardRequestType", XSD::QName.new(NsC_1, "StandardRequest")]],
            ["specificRequestMilingResult", ["CrvApiClient::Api::Reproduction::SpecificRequestMilkingResultType", XSD::QName.new(NsC_1, "SpecificRequestMilingResult")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::UpdateMilkingResultResponseType,
        :schema_type => XSD::QName.new(NsC_1, "UpdateMilkingResultResponseType"),
        :schema_element => [
            ["messageHeader", ["CrvApiClient::Api::Reproduction::ADEExchangedDocumentType", XSD::QName.new(NsC_1, "MessageHeader")]],
            ["standardResponse", ["CrvApiClient::Api::Reproduction::StandardResponseType", XSD::QName.new(NsC_1, "StandardResponse")]],
            ["specificResponse", ["CrvApiClient::Api::Reproduction::SpecificResponseType", XSD::QName.new(NsC_1, "SpecificResponse")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ADEExchangedDocumentType,
        :schema_type => XSD::QName.new(NsC_1, "ADEExchangedDocumentType"),
        :schema_element => [
            ["identifier", ["CrvApiClient::Api::Reproduction::IDType", XSD::QName.new(NsC_1, "Identifier")]],
            ["issueing", [nil, XSD::QName.new(NsC_1, "Issueing")]],
            ["version", [nil, XSD::QName.new(NsC_1, "Version")]],
            ["type", ["CrvApiClient::Api::Reproduction::CodeType", XSD::QName.new(NsC_1, "Type")]],
            ["language", ["CrvApiClient::Api::Reproduction::CodeType", XSD::QName.new(NsC_1, "Language")], [0, 1]],
            ["senderParty", ["CrvApiClient::Api::Reproduction::ADEPartyType", XSD::QName.new(NsC_1, "SenderParty")]],
            ["recipientParty", ["CrvApiClient::Api::Reproduction::ADEPartyType", XSD::QName.new(NsC_1, "RecipientParty")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ADEPartyType,
        :schema_type => XSD::QName.new(NsC_1, "ADEPartyType"),
        :schema_element => [
            ["name", ["CrvApiClient::Api::Reproduction::NameType", XSD::QName.new(NsC_1, "Name")], [0, 1]],
            ["iD", ["CrvApiClient::Api::Reproduction::IDType", XSD::QName.new(NsC_1, "ID")]],
            ["country", ["CrvApiClient::Api::Reproduction::ISOTwoletterCountryCodeIdentifierContentType", XSD::QName.new(NsC_1, "Country")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::SpecificRequestGetHerdListType,
        :schema_type => XSD::QName.new(NsC_1, "SpecificRequestGetHerdListType"),
        :schema_element => [
            ["dataToBeCompressed", [nil, XSD::QName.new(NsC_1, "DataToBeCompressed")]],
            ["specificRequestDetail", ["CrvApiClient::Api::Reproduction::SpecificRequestGetHerdListType::SpecificRequestDetail", XSD::QName.new(NsC_1, "SpecificRequestDetail")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::SpecificRequestGetHerdListType::SpecificRequestDetail,
        :schema_name => XSD::QName.new(NsC_1, "SpecificRequestDetail"),
        :is_anonymous => true,
        :schema_qualified => true,
        :schema_element => [:choice,
                            ["ticketRequest", ["CrvApiClient::Api::Reproduction::TicketRequestType", XSD::QName.new(NsC_1, "TicketRequest")]],
                            ["herdListRequest", ["CrvApiClient::Api::Reproduction::HerdListRequestType", XSD::QName.new(NsC_1, "HerdListRequest")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::SpecificResponseGetHerdListType,
        :schema_type => XSD::QName.new(NsC_1, "SpecificResponseGetHerdListType"),
        :schema_element => [:choice,
                            ["ticketResponse", ["CrvApiClient::Api::Reproduction::TicketResponseType", XSD::QName.new(NsC_1, "TicketResponse")]],
                            ["herdListMessage", ["CrvApiClient::Api::Reproduction::HerdListMessageType", XSD::QName.new(NsC_1, "HerdListMessage")]],
                            ["getHerdListResponseZipMessage", ["CrvApiClient::Api::Reproduction::ZipMessageType", XSD::QName.new(NsC_1, "GetHerdListResponseZipMessage")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::SpecificRequestAnimalType,
        :schema_type => XSD::QName.new(NsC_1, "SpecificRequestAnimalType"),
        :schema_element => [:choice,
                            ["ticketRequest", ["CrvApiClient::Api::Reproduction::TicketRequestType", XSD::QName.new(NsC_1, "TicketRequest")]],
                            ["animalListMessage", ["CrvApiClient::Api::Reproduction::AnimalListMessageType", XSD::QName.new(NsC_1, "AnimalListMessage")]],
                            ["updateAnimalRequestZipMessage", ["CrvApiClient::Api::Reproduction::ZipMessageType", XSD::QName.new(NsC_1, "UpdateAnimalRequestZipMessage")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::SpecificRequestDeviceType,
        :schema_type => XSD::QName.new(NsC_1, "SpecificRequestDeviceType"),
        :schema_element => [:choice,
                            ["ticketRequest", ["CrvApiClient::Api::Reproduction::TicketRequestType", XSD::QName.new(NsC_1, "TicketRequest")]],
                            ["deviceListMessage", ["CrvApiClient::Api::Reproduction::DeviceListMessageType", XSD::QName.new(NsC_1, "DeviceListMessage")]],
                            ["updateDeviceRequestZipMessage", ["CrvApiClient::Api::Reproduction::ZipMessageType", XSD::QName.new(NsC_1, "UpdateDeviceRequestZipMessage")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::SpecificRequestLivestockLocationType,
        :schema_type => XSD::QName.new(NsC_1, "SpecificRequestLivestockLocationType"),
        :schema_element => [:choice,
                            ["ticketRequest", ["CrvApiClient::Api::Reproduction::TicketRequestType", XSD::QName.new(NsC_1, "TicketRequest")]],
                            ["livestockLocation", ["CrvApiClient::Api::Reproduction::LivestockLocationType", XSD::QName.new(NsC_1, "LivestockLocation")]],
                            ["updateLivestockLocationrequestZipMessage", ["CrvApiClient::Api::Reproduction::ZipMessageType", XSD::QName.new(NsC_1, "UpdateLivestockLocationrequestZipMessage")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::SpecificRequestMilkingResultType,
        :schema_type => XSD::QName.new(NsC_1, "SpecificRequestMilkingResultType"),
        :schema_element => [:choice,
                            ["ticketRequest", ["CrvApiClient::Api::Reproduction::TicketRequestType", XSD::QName.new(NsC_1, "TicketRequest")]],
                            ["milkingResult", ["CrvApiClient::Api::Reproduction::MilkingResultType", XSD::QName.new(NsC_1, "MilkingResult")]],
                            ["updateMilkingResultRequestZipMessage", ["CrvApiClient::Api::Reproduction::ZipMessageType", XSD::QName.new(NsC_1, "UpdateMilkingResultRequestZipMessage")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::StandardRequestType,
        :schema_type => XSD::QName.new(NsC_1, "StandardRequestType"),
        :schema_element => [:choice,
                            ["authenticationToken", ["CrvApiClient::Api::Reproduction::TextType", XSD::QName.new(NsC_1, "AuthenticationToken")]],
                            ["authentificationLogin", ["CrvApiClient::Api::Reproduction::StandardRequestType::AuthentificationLogin", XSD::QName.new(NsC_1, "AuthentificationLogin")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::StandardRequestType::AuthentificationLogin,
        :schema_name => XSD::QName.new(NsC_1, "AuthentificationLogin"),
        :is_anonymous => true,
        :schema_qualified => true,
        :schema_element => [
            ["userName", ["CrvApiClient::Api::Reproduction::TextType", XSD::QName.new(NsC_1, "UserName")]],
            ["password", ["CrvApiClient::Api::Reproduction::TextType", XSD::QName.new(NsC_1, "Password")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ZipMessageType,
        :schema_type => XSD::QName.new(NsC_1, "ZipMessageType"),
        :schema_element => [
            ["zIPMessage", ["CrvApiClient::Api::Reproduction::BinaryObjectType", XSD::QName.new(NsC_1, "ZIPMessage")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::TicketResponseType,
        :schema_type => XSD::QName.new(NsC_1, "TicketResponseType"),
        :schema_element => [
            ["ticketID", ["CrvApiClient::Api::Reproduction::IDType", XSD::QName.new(NsC_1, "TicketID")]],
            ["notBefore", [nil, XSD::QName.new(NsC_1, "NotBefore")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::TicketRequestType,
        :schema_type => XSD::QName.new(NsC_1, "TicketRequestType"),
        :schema_element => [
            ["ticketID", ["CrvApiClient::Api::Reproduction::IDType", XSD::QName.new(NsC_1, "TicketID")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::HerdListRequestType,
        :schema_type => XSD::QName.new(NsC_1, "HerdListRequestType"),
        :schema_element => [
            ["gender", ["CrvApiClient::Api::Reproduction::GenderCodeType", XSD::QName.new(NsC_1, "Gender")], [0, 1]],
            ["periode", ["CrvApiClient::Api::Reproduction::MeasureType", XSD::QName.new(NsC_1, "Periode")], [0, 1]],
            ["location", ["CrvApiClient::Api::Reproduction::IDType", XSD::QName.new(NsC_1, "Location")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalListMessageType,
        :schema_type => XSD::QName.new(NsC_1, "AnimalListMessageType"),
        :schema_element => [
            ["animalDetail", ["CrvApiClient::Api::Reproduction::AnimalListMessageType::AnimalDetail[]", XSD::QName.new(NsC_1, "AnimalDetail")], [1, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalListMessageType::AnimalDetail,
        :schema_name => XSD::QName.new(NsC_1, "AnimalDetail"),
        :is_anonymous => true,
        :schema_qualified => true,
        :schema_element => [
            ["animalCoreDataSet", ["CrvApiClient::Api::Reproduction::AnimalCoreDataSetType", XSD::QName.new(NsC_1, "AnimalCoreDataSet")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::DeviceListMessageType,
        :schema_type => XSD::QName.new(NsC_1, "DeviceListMessageType"),
        :schema_element => [
            ["device", ["CrvApiClient::Api::Reproduction::DeviceType[]", XSD::QName.new(NsC_1, "Device")], [1, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::DeviceType,
        :schema_type => XSD::QName.new(NsC_1, "DeviceType"),
        :schema_element => [
            ["identifier", ["CrvApiClient::Api::Reproduction::IDType", XSD::QName.new(NsC_1, "Identifier")]],
            ["manufacturer", ["CrvApiClient::Api::Reproduction::ManufacturerCodeType", XSD::QName.new(NsC_1, "Manufacturer")], [0, 1]],
            ["softwareVersion", ["CrvApiClient::Api::Reproduction::TextType", XSD::QName.new(NsC_1, "SoftwareVersion")], [0, 1]],
            ["hardwareVersion", ["CrvApiClient::Api::Reproduction::TextType", XSD::QName.new(NsC_1, "HardwareVersion")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalCoreDataSetType,
        :schema_type => XSD::QName.new(NsC_1, "AnimalCoreDataSetType"),
        :schema_element => [
            ["identifier", ["CrvApiClient::Api::Reproduction::IDType", XSD::QName.new(NsC_1, "Identifier")]],
            ["alternativeIdentity", ["CrvApiClient::Api::Reproduction::AnimalIdentityType[]", XSD::QName.new(NsC_1, "AlternativeIdentity")], [0, nil]],
            ["specie", ["CrvApiClient::Api::Reproduction::SpecieCodeType", XSD::QName.new(NsC_1, "Specie")], [0, 1]],
            ["gender", ["CrvApiClient::Api::Reproduction::GenderCodeType", XSD::QName.new(NsC_1, "Gender")], [0, 1]],
            ["birth", [nil, XSD::QName.new(NsC_1, "Birth")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalExtendedDataSetType,
        :schema_type => XSD::QName.new(NsC_1, "AnimalExtendedDataSetType"),
        :schema_element => [
            ["lastLocalization", [nil, XSD::QName.new(NsC_1, "LastLocalization")], [0, 1]],
            ["lastParturition", [nil, XSD::QName.new(NsC_1, "LastParturition")], [0, 1]],
            ["lastInsemination", [nil, XSD::QName.new(NsC_1, "LastInsemination")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalIdentityType,
        :schema_type => XSD::QName.new(NsC_1, "AnimalIdentityType"),
        :schema_element => [
            ["identifier", ["CrvApiClient::Api::Reproduction::IDType", XSD::QName.new(NsC_1, "Identifier")]],
            ["label", ["CrvApiClient::Api::Reproduction::LabelCodeType", XSD::QName.new(NsC_1, "Label")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalMilkingResultType,
        :schema_type => XSD::QName.new(NsC_1, "AnimalMilkingResultType"),
        :schema_element => [
            ["animalIdentity", ["CrvApiClient::Api::Reproduction::AnimalIdentityType", XSD::QName.new(NsC_1, "AnimalIdentity")]],
            ["location", ["CrvApiClient::Api::Reproduction::IDType", XSD::QName.new(NsC_1, "Location")]],
            ["milkingStartingTime", [nil, XSD::QName.new(NsC_1, "MilkingStartingTime")]],
            ["milkingDuration", ["CrvApiClient::Api::Reproduction::MeasureType", XSD::QName.new(NsC_1, "MilkingDuration")], [0, 1]],
            ["milkingVisitDuration", ["CrvApiClient::Api::Reproduction::MeasureType", XSD::QName.new(NsC_1, "MilkingVisitDuration")], [0, 1]],
            ["milkingType", ["CrvApiClient::Api::Reproduction::MilkingTypeCodeType", XSD::QName.new(NsC_1, "MilkingType")], [0, 1]],
            ["milkingMilkWeight", ["CrvApiClient::Api::Reproduction::MeasureType", XSD::QName.new(NsC_1, "MilkingMilkWeight")], [0, 1]],
            ["milkingSucces", [nil, XSD::QName.new(NsC_1, "MilkingSucces")]],
            ["milkingParlourUnit", ["CrvApiClient::Api::Reproduction::TextType", XSD::QName.new(NsC_1, "MilkingParlourUnit")], [0, 1]],
            ["milkingBoxNumber", ["CrvApiClient::Api::Reproduction::TextType", XSD::QName.new(NsC_1, "MilkingBoxNumber")], [0, 1]],
            ["characteristics", ["CrvApiClient::Api::Reproduction::MilkCharacteristicsType[]", XSD::QName.new(NsC_1, "Characteristics")], [0, nil]],
            ["quarterMilking", ["CrvApiClient::Api::Reproduction::QuarterMilkingType[]", XSD::QName.new(NsC_1, "QuarterMilking")], [0, 4]],
            ["animalMilkingSample", ["CrvApiClient::Api::Reproduction::AnimalMilkingSampleType", XSD::QName.new(NsC_1, "AnimalMilkingSample")], [0, 1]],
            ["milkingDeviceID", ["CrvApiClient::Api::Reproduction::IDType", XSD::QName.new(NsC_1, "MilkingDeviceID")], [0, 1]],
            ["measureDeviceID", ["CrvApiClient::Api::Reproduction::IDType", XSD::QName.new(NsC_1, "MeasureDeviceID")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalMilkingSampleType,
        :schema_type => XSD::QName.new(NsC_1, "AnimalMilkingSampleType"),
        :schema_element => [
            ["bottleIdentifierType", ["CrvApiClient::Api::Reproduction::BottleIdentifierCodeType", XSD::QName.new(NsC_1, "BottleIdentifierType")], [0, 1]],
            ["rackNumber", ["CrvApiClient::Api::Reproduction::IDType", XSD::QName.new(NsC_1, "RackNumber")]],
            ["bottlePosition", ["CrvApiClient::Api::Reproduction::IDType", XSD::QName.new(NsC_1, "BottlePosition")], [0, 1]],
            ["bottleIdentifier", ["CrvApiClient::Api::Reproduction::IDType", XSD::QName.new(NsC_1, "BottleIdentifier")], [0, 1]],
            ["validSampleFillingIndicator", ["CrvApiClient::Api::Reproduction::ValidSampleFillingIndicatorCodeType", XSD::QName.new(NsC_1, "ValidSampleFillingIndicator")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ErrorType,
        :schema_type => XSD::QName.new(NsC_1, "ErrorType"),
        :schema_element => [
            ["errorID", ["CrvApiClient::Api::Reproduction::TextType", XSD::QName.new(NsC_1, "ErrorID")]],
            ["errorSeverity", ["CrvApiClient::Api::Reproduction::ErrorSeverityCodeType", XSD::QName.new(NsC_1, "ErrorSeverity")], [0, 1]],
            ["errorDescription", ["CrvApiClient::Api::Reproduction::TextType", XSD::QName.new(NsC_1, "ErrorDescription")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::HerdListMessageType,
        :schema_type => XSD::QName.new(NsC_1, "HerdListMessageType"),
        :schema_element => [
            ["location", ["CrvApiClient::Api::Reproduction::LivestockLocationType", XSD::QName.new(NsC_1, "Location")]],
            ["herdListAnimalDescription", ["CrvApiClient::Api::Reproduction::HerdListLineType[]", XSD::QName.new(NsC_1, "HerdListAnimalDescription")], [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::LivestockLocationType,
        :schema_type => XSD::QName.new(NsC_1, "LivestockLocationType"),
        :schema_element => [
            ["identifier", ["CrvApiClient::Api::Reproduction::IDType", XSD::QName.new(NsC_1, "Identifier")]],
            ["identifierType", ["CrvApiClient::Api::Reproduction::LivestockLocationIdentifierCodeType", XSD::QName.new(NsC_1, "IdentifierType")]],
            ["name", ["CrvApiClient::Api::Reproduction::NameType", XSD::QName.new(NsC_1, "Name")]],
            ["country", ["CrvApiClient::Api::Reproduction::ISOTwoletterCountryCodeIdentifierContentType", XSD::QName.new(NsC_1, "Country")]],
            ["type", ["CrvApiClient::Api::Reproduction::LivestockLocationTypeCodeType", XSD::QName.new(NsC_1, "Type")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::MilkingLocationType,
        :schema_type => XSD::QName.new(NsC_1, "MilkingLocationType"),
        :schema_element => [
            ["identification", ["CrvApiClient::Api::Reproduction::IDType", XSD::QName.new(NsC_1, "Identification")]],
            ["name", ["CrvApiClient::Api::Reproduction::NameType", XSD::QName.new(NsC_1, "Name")]],
            ["country", ["CrvApiClient::Api::Reproduction::ISOTwoletterCountryCodeIdentifierContentType", XSD::QName.new(NsC_1, "Country")]],
            ["type", ["CrvApiClient::Api::Reproduction::CodeType", XSD::QName.new(NsC_1, "Type")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::MilkingResultType,
        :schema_type => XSD::QName.new(NsC_1, "MilkingResultType"),
        :schema_element => [
            ["animalMilkingResult", ["CrvApiClient::Api::Reproduction::AnimalMilkingResultType[]", XSD::QName.new(NsC_1, "AnimalMilkingResult")], [1, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::HerdListLineType,
        :schema_type => XSD::QName.new(NsC_1, "HerdListLineType"),
        :schema_element => [
            ["animalCoreDataSet", ["CrvApiClient::Api::Reproduction::AnimalCoreDataSetType", XSD::QName.new(NsC_1, "AnimalCoreDataSet")]],
            ["animalExtendedDataSet", ["CrvApiClient::Api::Reproduction::AnimalExtendedDataSetType", XSD::QName.new(NsC_1, "AnimalExtendedDataSet")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::MilkCharacteristicsType,
        :schema_type => XSD::QName.new(NsC_1, "MilkCharacteristicsType"),
        :schema_element => [
            ["milkCharacteristicCode", ["CrvApiClient::Api::Reproduction::MilkCharacteristicCodeType", XSD::QName.new(NsC_1, "MilkCharacteristicCode")]],
            ["milkCharacteristicValue", ["CrvApiClient::Api::Reproduction::MeasureType", XSD::QName.new(NsC_1, "MilkCharacteristicValue")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::QuarterMilkingType,
        :schema_type => XSD::QName.new(NsC_1, "QuarterMilkingType"),
        :schema_element => [
            ["quarterID", ["CrvApiClient::Api::Reproduction::QuarterCodeType", XSD::QName.new(NsC_1, "QuarterID")]],
            ["quarterMilkingDuration", ["CrvApiClient::Api::Reproduction::MeasureType", XSD::QName.new(NsC_1, "QuarterMilkingDuration")], [0, 1]],
            ["quarterMilkingWeight", ["CrvApiClient::Api::Reproduction::MeasureType", XSD::QName.new(NsC_1, "QuarterMilkingWeight")], [0, 1]],
            ["quarterCharacteristics", ["CrvApiClient::Api::Reproduction::MilkCharacteristicsType[]", XSD::QName.new(NsC_1, "QuarterCharacteristics")], [0, nil]],
            ["quarterSampling", ["CrvApiClient::Api::Reproduction::AnimalMilkingSampleType", XSD::QName.new(NsC_1, "QuarterSampling")], [0, 1]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::SpecificResponseType,
        :schema_type => XSD::QName.new(NsC_1, "SpecificResponseType"),
        :schema_element => [
            ["requestProcessingTicket", ["CrvApiClient::Api::Reproduction::TicketResponseType", XSD::QName.new(NsC_1, "RequestProcessingTicket")]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::StandardResponseType,
        :schema_type => XSD::QName.new(NsC_1, "StandardResponseType"),
        :schema_element => [
            ["requestProcessingStatus", ["CrvApiClient::Api::Reproduction::RequestProcessingStatusCodeType", XSD::QName.new(NsC_1, "RequestProcessingStatus")]],
            ["requestID", ["CrvApiClient::Api::Reproduction::IDType", XSD::QName.new(NsC_1, "RequestID")]],
            ["requestProcessingError", ["CrvApiClient::Api::Reproduction::ErrorType[]", XSD::QName.new(NsC_1, "RequestProcessingError")], [0, nil]]
        ]
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AmountType,
        :schema_type => XSD::QName.new(NsC_13, "AmountType"),
        :schema_attribute => {
            XSD::QName.new(nil, "currencyID") => "SOAP::SOAPToken"
        }
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::BinaryObjectType,
        :schema_type => XSD::QName.new(NsC_13, "BinaryObjectType"),
        :schema_attribute => {
            XSD::QName.new(nil, "format") => "SOAP::SOAPString",
            XSD::QName.new(nil, "mimeCode") => "SOAP::SOAPToken",
            XSD::QName.new(nil, "encodingCode") => "SOAP::SOAPToken",
            XSD::QName.new(nil, "characterSetCode") => "SOAP::SOAPToken",
            XSD::QName.new(nil, "uri") => "SOAP::SOAPAnyURI",
            XSD::QName.new(nil, "filename") => "SOAP::SOAPString"
        }
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::GraphicType,
        :schema_type => XSD::QName.new(NsC_13, "GraphicType"),
        :schema_attribute => {
            XSD::QName.new(nil, "format") => "SOAP::SOAPString",
            XSD::QName.new(nil, "mimeCode") => "SOAP::SOAPToken",
            XSD::QName.new(nil, "encodingCode") => "SOAP::SOAPToken",
            XSD::QName.new(nil, "uri") => "SOAP::SOAPAnyURI",
            XSD::QName.new(nil, "filename") => "SOAP::SOAPString"
        }
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::PictureType,
        :schema_type => XSD::QName.new(NsC_13, "PictureType"),
        :schema_attribute => {
            XSD::QName.new(nil, "format") => "SOAP::SOAPString",
            XSD::QName.new(nil, "mimeCode") => "SOAP::SOAPToken",
            XSD::QName.new(nil, "encodingCode") => "SOAP::SOAPToken",
            XSD::QName.new(nil, "uri") => "SOAP::SOAPAnyURI",
            XSD::QName.new(nil, "filename") => "SOAP::SOAPString"
        }
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::SoundType,
        :schema_type => XSD::QName.new(NsC_13, "SoundType"),
        :schema_attribute => {
            XSD::QName.new(nil, "format") => "SOAP::SOAPString",
            XSD::QName.new(nil, "mimeCode") => "SOAP::SOAPToken",
            XSD::QName.new(nil, "encodingCode") => "SOAP::SOAPToken",
            XSD::QName.new(nil, "uri") => "SOAP::SOAPAnyURI",
            XSD::QName.new(nil, "filename") => "SOAP::SOAPString"
        }
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::VideoType,
        :schema_type => XSD::QName.new(NsC_13, "VideoType"),
        :schema_attribute => {
            XSD::QName.new(nil, "format") => "SOAP::SOAPString",
            XSD::QName.new(nil, "mimeCode") => "SOAP::SOAPToken",
            XSD::QName.new(nil, "encodingCode") => "SOAP::SOAPToken",
            XSD::QName.new(nil, "uri") => "SOAP::SOAPAnyURI",
            XSD::QName.new(nil, "filename") => "SOAP::SOAPString"
        }
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::CodeType,
        :schema_type => XSD::QName.new(NsC_13, "CodeType"),
        :schema_attribute => {
            XSD::QName.new(nil, "listID") => "SOAP::SOAPToken",
            XSD::QName.new(nil, "listAgencyID") => "SOAP::SOAPToken",
            XSD::QName.new(nil, "listAgencyName") => "SOAP::SOAPString",
            XSD::QName.new(nil, "listName") => "SOAP::SOAPString",
            XSD::QName.new(nil, "listVersionID") => "SOAP::SOAPToken",
            XSD::QName.new(nil, "name") => "SOAP::SOAPString",
            XSD::QName.new(nil, "languageID") => "SOAP::SOAPLanguage",
            XSD::QName.new(nil, "listURI") => "SOAP::SOAPAnyURI",
            XSD::QName.new(nil, "listSchemeURI") => "SOAP::SOAPAnyURI"
        }
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::IDType,
        :schema_type => XSD::QName.new(NsC_13, "IDType"),
        :schema_attribute => {
            XSD::QName.new(nil, "schemeID") => "SOAP::SOAPToken",
            XSD::QName.new(nil, "schemeName") => "SOAP::SOAPString",
            XSD::QName.new(nil, "schemeAgencyID") => "SOAP::SOAPToken",
            XSD::QName.new(nil, "schemeAgencyName") => "SOAP::SOAPString",
            XSD::QName.new(nil, "schemeVersionID") => "SOAP::SOAPToken",
            XSD::QName.new(nil, "schemeDataURI") => "SOAP::SOAPAnyURI",
            XSD::QName.new(nil, "schemeURI") => "SOAP::SOAPAnyURI"
        }
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::MeasureType,
        :schema_type => XSD::QName.new(NsC_13, "MeasureType"),
        :schema_attribute => {
            XSD::QName.new(nil, "unitCode") => "SOAP::SOAPToken"
        }
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::QuantityType,
        :schema_type => XSD::QName.new(NsC_13, "QuantityType"),
        :schema_attribute => {
            XSD::QName.new(nil, "unitCode") => "SOAP::SOAPToken"
        }
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::TextType,
        :schema_type => XSD::QName.new(NsC_13, "TextType"),
        :schema_attribute => {
            XSD::QName.new(nil, "languageID") => "SOAP::SOAPLanguage"
        }
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::NameType,
        :schema_type => XSD::QName.new(NsC_13, "NameType"),
        :schema_attribute => {
            XSD::QName.new(nil, "languageID") => "SOAP::SOAPLanguage"
        }
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::BooleanType,
        :schema_type => XSD::QName.new(NsCommonTypes, "booleanType")
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::NotificationType,
        :schema_type => XSD::QName.new(NsCommonTypes, "notificationType")
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::RepresentationType,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "representationType")
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::CountryCode,
        :schema_type => XSD::QName.new(NsAnimalTypes, "countryCode")
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::KeeperType,
        :schema_type => XSD::QName.new(NsAnimalTypes, "keeperType")
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Sex,
        :schema_type => XSD::QName.new(NsAnimalTypes, "sex")
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::MIMEMediaTypeContentType,
        :schema_type => XSD::QName.new(NsC_20130103, "MIMEMediaTypeContentType")
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::MeasurementUnitCommonCodeContentType,
        :schema_type => XSD::QName.new(NsC_8, "MeasurementUnitCommonCodeContentType")
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::CharacterSetCodeContentType,
        :schema_type => XSD::QName.new(NsC_20130108, "CharacterSetCodeContentType")
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ISO3AlphaCurrencyCodeContentType,
        :schema_type => XSD::QName.new(NsC_20120831, "ISO3AlphaCurrencyCodeContentType")
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::CharacterSetEncodingCodeContentType,
        :schema_type => XSD::QName.new(NsC_40106, "CharacterSetEncodingCodeContentType")
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AgencyIdentificationCodeContentType,
        :schema_type => XSD::QName.new(NsD12A, "AgencyIdentificationCodeContentType")
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ISOTwoletterCountryCodeIdentifierContentType,
        :schema_type => XSD::QName.new(NsSecondEdition2006VI13, "ISOTwoletterCountryCodeIdentifierContentType")
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::GenderCodeType,
        :schema_type => XSD::QName.new(NsC_10, "GenderCodeType")
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::LivestockLocationIdentifierCodeType,
        :schema_type => XSD::QName.new(NsC_10_0, "LivestockLocationIdentifierCodeType")
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::LivestockLocationTypeCodeType,
        :schema_type => XSD::QName.new(NsC_10_1, "LivestockLocationTypeCodeType")
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::MilkingTypeCodeType,
        :schema_type => XSD::QName.new(NsC_10_2, "MilkingTypeCodeType")
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::LabelCodeType,
        :schema_type => XSD::QName.new(NsC_10_3, "LabelCodeType")
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ValidSampleFillingIndicatorCodeType,
        :schema_type => XSD::QName.new(NsC_10_4, "ValidSampleFillingIndicatorCodeType")
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::BottleIdentifierCodeType,
        :schema_type => XSD::QName.new(NsC_10_5, "BottleIdentifierCodeType")
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::RequestProcessingStatusCodeType,
        :schema_type => XSD::QName.new(NsC_10_6, "RequestProcessingStatusCodeType")
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ErrorSeverityCodeType,
        :schema_type => XSD::QName.new(NsC_10_7, "ErrorSeverityCodeType")
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::SpecieCodeType,
        :schema_type => XSD::QName.new(NsC_10_8, "SpecieCodeType")
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::MilkCharacteristicCodeType,
        :schema_type => XSD::QName.new(NsC_10_9, "MilkCharacteristicCodeType")
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::QuarterCodeType,
        :schema_type => XSD::QName.new(NsC_10_10, "QuarterCodeType")
    )

    EncodedRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ManufacturerCodeType,
        :schema_type => XSD::QName.new(NsC_10_11, "ManufacturerCodeType")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ListTopGestationCalvingRequestType,
        :schema_type => XSD::QName.new(NsReproductionMessages, "listTopGestationCalvingRequestType"),
        :schema_element => [
            ["topGestationBreeding", "CrvApiClient::Api::Reproduction::TopGestationBreeding[]", [1, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::TopGestationBreeding,
        :schema_type => XSD::QName.new(NsReproductionMessages, "topGestationBreeding"),
        :schema_element => [
            ["cow", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["reproductionType", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "reproductionType")]],
            ["reproductionDate", [nil, XSD::QName.new(NsReproduction, "reproductionDate")]],
            ["calvingDateExp", [nil, XSD::QName.new(NsReproduction, "calvingDateExp")]],
            ["keeper", "CrvApiClient::Api::Reproduction::ParticipantId"],
            ["sire", "CrvApiClient::Api::Reproduction::AnimalId"],
            ["dam", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["breedCalculation", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "breedCalculation")]],
            ["breedingIndex", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "breedingIndex")]],
            ["contractType", "CrvApiClient::Api::Reproduction::ContractType[]", [0, nil]],
            ["countryCd", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "countryCd")], [0, 1]],
            ["workArea", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "workArea")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ContractType,
        :schema_type => XSD::QName.new(NsReproductionMessages, "contractType"),
        :schema_element => [
            ["contractType", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "contractType")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ListTopGestationCalvingResponseType,
        :schema_type => XSD::QName.new(NsReproductionMessages, "listTopGestationCalvingResponseType"),
        :schema_element => [
            ["topGestation", "CrvApiClient::Api::Reproduction::TopGestation[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::TopGestation,
        :schema_type => XSD::QName.new(NsReproductionMessages, "topGestation"),
        :schema_element => [
            ["topGestationBreeding", "CrvApiClient::Api::Reproduction::TopGestationBreeding"],
            ["gestationCalving", "CrvApiClient::Api::Reproduction::GestationCalving"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::GestationCalving,
        :schema_type => XSD::QName.new(NsReproductionMessages, "gestationCalving"),
        :schema_element => [
            ["cow", "CrvApiClient::Api::Reproduction::AnimalId"],
            ["cowKeeper", "CrvApiClient::Api::Reproduction::ActualKeeper", [0, 1]],
            ["gestationDetails", "CrvApiClient::Api::Reproduction::LgcGestation", [0, 1]],
            ["calvingAndCalves", "CrvApiClient::Api::Reproduction::LgcCalving[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::LgcGestation,
        :schema_type => XSD::QName.new(NsReproductionMessages, "lgcGestation"),
        :schema_element => [
            ["gestation", "CrvApiClient::Api::Reproduction::Gestation"],
            ["gestationReproduction", "CrvApiClient::Api::Reproduction::GestationReproduction"],
            ["gestationPedigree", "CrvApiClient::Api::Reproduction::Pedigree[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::LgcCalving,
        :schema_type => XSD::QName.new(NsReproductionMessages, "lgcCalving"),
        :schema_element => [
            ["calving", "CrvApiClient::Api::Reproduction::Calving"],
            ["calf", "CrvApiClient::Api::Reproduction::LgcCalf[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::LgcCalf,
        :schema_type => XSD::QName.new(NsReproductionMessages, "lgcCalf"),
        :schema_element => [
            ["animal", "CrvApiClient::Api::Reproduction::Animal"],
            ["calfKeeper", "CrvApiClient::Api::Reproduction::ActualKeeper", [0, 1]],
            ["animalPedigree", "CrvApiClient::Api::Reproduction::Pedigree"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ListFertilizationRequestType,
        :schema_type => XSD::QName.new(NsReproductionMessages, "listFertilizationRequestType"),
        :schema_element => [
            ["animal", "CrvApiClient::Api::Reproduction::AnimalId[]", [1, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ListFertilizationResponseType,
        :schema_type => XSD::QName.new(NsReproductionMessages, "listFertilizationResponseType"),
        :schema_element => [
            ["animal", "CrvApiClient::Api::Reproduction::FertilizationRA[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::FertilizationRA,
        :schema_type => XSD::QName.new(NsReproductionMessages, "fertilizationRA"),
        :schema_element => [
            ["animal", "CrvApiClient::Api::Reproduction::AnimalId"],
            ["reproductionStatus", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "reproductionStatus")]],
            ["fertilization", "CrvApiClient::Api::Reproduction::GestationReproduction[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ListAnimalReproductionRequestType,
        :schema_type => XSD::QName.new(NsReproductionMessages, "listAnimalReproductionRequestType"),
        :schema_element => [
            ["keeper", "CrvApiClient::Api::Reproduction::ParticipantId"],
            ["listParticipantAnimalRequest", "CrvApiClient::Api::Reproduction::ListParticipantAnimalRequest", [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ListAnimalReproductionResponseType,
        :schema_type => XSD::QName.new(NsReproductionMessages, "listAnimalReproductionResponseType"),
        :schema_element => [
            ["keeper", "CrvApiClient::Api::Reproduction::ParticipantId"],
            ["animalReproduction", "CrvApiClient::Api::Reproduction::AnimalReproduction[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AddAnimalReproductionIndicationRequestType,
        :schema_type => XSD::QName.new(NsReproductionMessages, "addAnimalReproductionIndicationRequestType"),
        :schema_element => [
            ["keeper", "CrvApiClient::Api::Reproduction::ParticipantId"],
            ["animalReproductionIndication", "CrvApiClient::Api::Reproduction::AnimalReproductionIndication[]", [1, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalExaminations,
        :schema_type => XSD::QName.new(NsReproductionMessages, "animalExaminations"),
        :schema_element => [
            ["nrOfExaminations", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "nrOfExaminations")]],
            ["minOfExaminations", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "minOfExaminations")]],
            ["animalExamination", "CrvApiClient::Api::Reproduction::AnimalExamination[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Echograms,
        :schema_type => XSD::QName.new(NsReproductionMessages, "echograms"),
        :schema_element => [
            ["nrOfEchograms", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "nrOfEchograms")]],
            ["minOfEchograms", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "minOfEchograms")]],
            ["animalExamination", "CrvApiClient::Api::Reproduction::AnimalExamination[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::PregnancyChecks,
        :schema_type => XSD::QName.new(NsReproductionMessages, "pregnancyChecks"),
        :schema_element => [
            ["nrOfPregnancyChecks", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "nrOfPregnancyChecks")]],
            ["minOfPregnancyChecks", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "minOfPregnancyChecks")]],
            ["animalExamination", "CrvApiClient::Api::Reproduction::AnimalExamination[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::InheatChecks,
        :schema_type => XSD::QName.new(NsReproductionMessages, "inheatChecks"),
        :schema_element => [
            ["nrOfInheatChecks", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "nrOfInheatChecks")]],
            ["minOfInheatChecks", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "minOfInheatChecks")]],
            ["animalExamination", "CrvApiClient::Api::Reproduction::AnimalExamination[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ProductDelivery,
        :schema_type => XSD::QName.new(NsReproductionMessages, "productDelivery"),
        :schema_element => [
            ["registrationTime", [nil, XSD::QName.new(NsReproduction, "registrationTime")]],
            ["productAmount", "CrvApiClient::Api::Reproduction::ProductAmount"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::CowNotServed,
        :schema_type => XSD::QName.new(NsReproductionMessages, "cowNotServed"),
        :schema_element => [
            ["cow", "CrvApiClient::Api::Reproduction::AnimalId"],
            ["cowScanned", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "cowScanned")]],
            ["bullCd", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "bullCd")]],
            ["bullCdScanned", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "bullCdScanned")]],
            ["chargeNr", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "chargeNr")]],
            ["chargeNrScanned", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "chargeNrScanned")]],
            ["bull", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["semenType", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "semenType")]],
            ["ownStock", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "ownStock")]],
            ["semenChargeCd", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "semenChargeCd")]],
            ["refuseCd", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "refuseCd")]],
            ["registrationTime", [nil, XSD::QName.new(NsReproduction, "registrationTime")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::BrokenStraw,
        :schema_type => XSD::QName.new(NsReproductionMessages, "brokenStraw"),
        :schema_element => [
            ["bullCd", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "bullCd")]],
            ["bullCdScanned", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "bullCdScanned")]],
            ["chargeNr", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "chargeNr")]],
            ["chargeNrScanned", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "chargeNrScanned")]],
            ["bull", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["semenType", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "semenType")]],
            ["ownStock", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "ownStock")]],
            ["semenChargeCd", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "semenChargeCd")]],
            ["registrationTime", [nil, XSD::QName.new(NsReproduction, "registrationTime")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Support,
        :schema_type => XSD::QName.new(NsReproductionMessages, "support"),
        :schema_element => [
            ["supportCd", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "supportCd")]],
            ["nrOfMinutes", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "nrOfMinutes")]],
            ["registrationTime", [nil, XSD::QName.new(NsReproduction, "registrationTime")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::SiteVisit,
        :schema_type => XSD::QName.new(NsReproductionMessages, "siteVisit"),
        :schema_element => [
            ["siteVisitSerialNr", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "siteVisitSerialNr")]],
            ["site", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "site")]],
            ["siteScanned", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "siteScanned")]],
            ["orderNr", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "orderNr")]],
            ["statusVisit", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "statusVisit")]],
            ["registrationCompletedTime", [nil, XSD::QName.new(NsReproduction, "registrationCompletedTime")]],
            ["deliveryCheckCd", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "deliveryCheckCd")]],
            ["insemination", "CrvApiClient::Api::Reproduction::Insemination[]", [0, nil]],
            ["cowNotServed", "CrvApiClient::Api::Reproduction::CowNotServed[]", [0, nil]],
            ["brokenStraw", "CrvApiClient::Api::Reproduction::BrokenStraw[]", [0, nil]],
            ["productDelivery", "CrvApiClient::Api::Reproduction::ProductDelivery[]", [0, nil]],
            ["support", "CrvApiClient::Api::Reproduction::Support[]", [0, nil]],
            ["inheatChecks", "CrvApiClient::Api::Reproduction::InheatChecks", [0, 1]],
            ["pregnancyChecks", "CrvApiClient::Api::Reproduction::PregnancyChecks", [0, 1]],
            ["echograms", "CrvApiClient::Api::Reproduction::Echograms", [0, 1]],
            ["animalExaminations", "CrvApiClient::Api::Reproduction::AnimalExaminations", [0, 1]],
            ["transplantation", "CrvApiClient::Api::Reproduction::Transplantation[]", [0, nil]],
            ["flushing", "CrvApiClient::Api::Reproduction::Flushing[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AddAiEtDeliveryRequestType,
        :schema_type => XSD::QName.new(NsReproductionMessages, "addAiEtDeliveryRequestType"),
        :schema_element => [
            ["employee", "CrvApiClient::Api::Reproduction::ParticipantId"],
            ["round", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "round")]],
            ["deliveryDate", [nil, XSD::QName.new(NsReproduction, "deliveryDate")]],
            ["siteVisit", "CrvApiClient::Api::Reproduction::SiteVisit[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AddPreferredBullRequestType,
        :schema_type => XSD::QName.new(NsReproductionMessages, "addPreferredBullRequestType"),
        :schema_element => [
            ["keeper", "CrvApiClient::Api::Reproduction::ParticipantId"],
            ["preferredBull", "CrvApiClient::Api::Reproduction::AnimalId[]", [1, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::DeletePreferredBullRequestType,
        :schema_type => XSD::QName.new(NsReproductionMessages, "deletePreferredBullRequestType"),
        :schema_element => [
            ["keeper", "CrvApiClient::Api::Reproduction::ParticipantId"],
            ["preferredBull", "CrvApiClient::Api::Reproduction::AnimalId[]", [1, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ListPreferredBullRequestType,
        :schema_type => XSD::QName.new(NsReproductionMessages, "listPreferredBullRequestType"),
        :schema_element => [
            ["keeper", "CrvApiClient::Api::Reproduction::ParticipantId"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ListPreferredBullResponseType,
        :schema_type => XSD::QName.new(NsReproductionMessages, "listPreferredBullResponseType"),
        :schema_element => [
            ["keeper", "CrvApiClient::Api::Reproduction::ParticipantId"],
            ["preferredBullDetails", "CrvApiClient::Api::Reproduction::BullDetails[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ListReproductionLastParityRequestType,
        :schema_type => XSD::QName.new(NsReproductionMessages, "listReproductionLastParityRequestType"),
        :schema_element => [
            ["keeper", "CrvApiClient::Api::Reproduction::ParticipantId"],
            ["participantAnimalRequest", "CrvApiClient::Api::Reproduction::ListParticipantAnimalRequest", [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ListReproductionLastParityResponseType,
        :schema_type => XSD::QName.new(NsReproductionMessages, "listReproductionLastParityResponseType"),
        :schema_element => [
            ["keeper", "CrvApiClient::Api::Reproduction::ParticipantId"],
            ["listReproductionLastParity", "CrvApiClient::Api::Reproduction::AnimalReproductionLastParity[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ListAnimalIndicationRequestType,
        :schema_type => XSD::QName.new(NsReproductionMessages, "listAnimalIndicationRequestType"),
        :schema_element => [
            ["keeper", "CrvApiClient::Api::Reproduction::ParticipantId"],
            ["indication", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "indication")], [0, 1]],
            ["indicationCertainty", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "indicationCertainty")], [0, 1]],
            ["active", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "active")], [0, 1]],
            ["period", "CrvApiClient::Api::Reproduction::PeriodRange", [0, 1]],
            ["animal", "CrvApiClient::Api::Reproduction::AnimalId[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ListAnimalIndicationResponseType,
        :schema_type => XSD::QName.new(NsReproductionMessages, "listAnimalIndicationResponseType"),
        :schema_element => [
            ["keeper", "CrvApiClient::Api::Reproduction::ParticipantId"],
            ["indication", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "indication")], [0, 1]],
            ["indicationCertainty", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "indicationCertainty")], [0, 1]],
            ["active", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "active")], [0, 1]],
            ["period", "CrvApiClient::Api::Reproduction::PeriodRange", [0, 1]],
            ["animalReproductionIndication", "CrvApiClient::Api::Reproduction::AnimalReproductionIndication[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ModifyAnimalIndicationRequestType,
        :schema_type => XSD::QName.new(NsReproductionMessages, "modifyAnimalIndicationRequestType"),
        :schema_element => [
            ["keeper", "CrvApiClient::Api::Reproduction::ParticipantId"],
            ["animal", "CrvApiClient::Api::Reproduction::AnimalId"],
            ["indication", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "indication")]],
            ["indicationDateTime", nil],
            ["indicationCertaintyOld", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "indicationCertaintyOld")]],
            ["indicationCertaintyNew", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "indicationCertaintyNew")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::LocalTime,
        :schema_type => XSD::QName.new(NsCommonTypes, "localTime"),
        :schema_element => [
            ["hourOfDay", "SOAP::SOAPInt"],
            ["minuteOfHour", "SOAP::SOAPInt"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::LocalDate,
        :schema_type => XSD::QName.new(NsCommonTypes, "localDate"),
        :schema_element => [
            ["dayOfMonth", "SOAP::SOAPInt"],
            ["monthOfYear", "SOAP::SOAPInt"],
            ["year", "SOAP::SOAPInt"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::PeriodRange,
        :schema_type => XSD::QName.new(NsCommonTypes, "periodRange"),
        :schema_element => [
            ["beginDate", [nil, XSD::QName.new(NsCommon, "beginDate")], [0, 1]],
            ["endDate", [nil, XSD::QName.new(NsCommon, "endDate")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ContextMessage,
        :schema_type => XSD::QName.new(NsCommonTypes, "contextMessage"),
        :schema_element => [
            ["sessionId", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "sessionId")], [0, 1]],
            ["processId", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "processId")], [0, 1]],
            ["instanceId", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "instanceId")], [0, 1]],
            ["username", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "username")], [0, 1]],
            ["userType", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "userType")], [0, 1]],
            ["password", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "password")], [0, 1]],
            ["organisation", "CrvApiClient::Api::Reproduction::ParticipantId", [0, 1]],
            ["provider", "CrvApiClient::Api::Reproduction::ParticipantId", [0, 1]],
            ["customer", "CrvApiClient::Api::Reproduction::ParticipantId", [0, 1]],
            ["keeper", "CrvApiClient::Api::Reproduction::ParticipantId", [0, 1]],
            ["animal", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["processCode", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "processCode")], [0, 1]],
            ["messageSource", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "messageSource")], [0, 1]],
            ["languageCode", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "languageCode")], [0, 1]],
            ["timeZone", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "timeZone")], [0, 1]],
            ["contextMessageDetail", "CrvApiClient::Api::Reproduction::ContextMessageDetail[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ContextMessageDetail,
        :schema_type => XSD::QName.new(NsCommonTypes, "contextMessageDetail"),
        :schema_element => [
            ["contextCode", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "contextCode")], [0, 1]],
            ["contextValue", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "contextValue")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ServiceMessage,
        :schema_type => XSD::QName.new(NsCommonTypes, "serviceMessage"),
        :schema_element => [
            ["serviceStatus", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "serviceStatus")]],
            ["messageCode", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "messageCode")], [0, 1]],
            ["messageText", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "messageText")], [0, 1]],
            ["messageType", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "messageType")], [0, 1]],
            ["sourceType", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "sourceType")], [0, 1]],
            ["sourceCode", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "sourceCode")], [0, 1]],
            ["serviceMessageDetail", "CrvApiClient::Api::Reproduction::ServiceMessageDetail[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ServiceMessageDetail,
        :schema_type => XSD::QName.new(NsCommonTypes, "serviceMessageDetail"),
        :schema_element => [
            ["serviceStatus", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "serviceStatus")], [0, 1]],
            ["codeDetail", "CrvApiClient::Api::Reproduction::CodeDetail[]", [0, nil]],
            ["messageCode", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "messageCode")], [0, 1]],
            ["messageText", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "messageText")], [0, 1]],
            ["messageType", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "messageType")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::CodeDetail,
        :schema_type => XSD::QName.new(NsCommonTypes, "codeDetail"),
        :schema_element => [
            ["keyId", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "keyId")], [0, 1]],
            ["keyValue", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "keyValue")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::SendNotificationRequestType,
        :schema_type => XSD::QName.new(NsCommonTypes, "sendNotificationRequestType"),
        :schema_element => [
            ["notificationType", ["CrvApiClient::Api::Reproduction::NotificationType", XSD::QName.new(NsCommon, "notificationType")], [0, 1]],
            ["notificationMessage", "CrvApiClient::Api::Reproduction::NotificationMessageType[]", [0, nil]],
            ["email", "CrvApiClient::Api::Reproduction::EmailType[]", [0, nil]],
            ["fax", "CrvApiClient::Api::Reproduction::FaxType[]", [0, nil]],
            ["sms", "CrvApiClient::Api::Reproduction::SmsType[]", [0, nil]],
            ["voice", "CrvApiClient::Api::Reproduction::VoiceType[]", [0, nil]],
            ["pager", "CrvApiClient::Api::Reproduction::PagerType[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::NotificationMessageType,
        :schema_type => XSD::QName.new(NsCommonTypes, "notificationMessageType"),
        :schema_element => [
            ["messageCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "messageCode")], [0, 1]],
            ["languageCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "languageCode")], [0, 1]],
            ["messageParameter", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "messageParameter")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::EmailType,
        :schema_type => XSD::QName.new(NsCommonTypes, "emailType"),
        :schema_element => [
            ["mailTo", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "mailTo")], [0, 1]],
            ["mailCc", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "mailCc")], [0, 1]],
            ["mailBcc", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "mailBcc")], [0, 1]],
            ["mailReplyTo", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "mailReplyTo")], [0, 1]],
            ["subject", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "subject")], [0, 1]],
            ["textBody", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "textBody")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::FaxType,
        :schema_type => XSD::QName.new(NsCommonTypes, "faxType"),
        :schema_element => [
            ["faxNr", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "faxNr")], [0, 1]],
            ["coverPage", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "coverPage")], [0, 1]],
            ["textBody", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "textBody")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::SmsType,
        :schema_type => XSD::QName.new(NsCommonTypes, "smsType"),
        :schema_element => [
            ["fromNr", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "fromNr")], [0, 1]],
            ["telNr", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "telNr")], [0, 1]],
            ["subject", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "subject")], [0, 1]],
            ["textBody", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "textBody")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::VoiceType,
        :schema_type => XSD::QName.new(NsCommonTypes, "voiceType"),
        :schema_element => [
            ["telNr", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "telNr")], [0, 1]],
            ["textBody", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "textBody")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::PagerType,
        :schema_type => XSD::QName.new(NsCommonTypes, "pagerType"),
        :schema_element => [
            ["fromNr", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "fromNr")], [0, 1]],
            ["pagerNr", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "pagerNr")], [0, 1]],
            ["textBody", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "textBody")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::GetLabel,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "getLabel"),
        :schema_element => [
            ["componentCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "componentCode")], [0, 1]],
            ["itemName", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "itemName")], [0, 1]],
            ["itemType", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "itemType")], [0, 1]],
            ["languageCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "languageCode")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Component,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "component"),
        :schema_element => [
            ["componentCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "componentCode")], [0, 1]],
            ["processCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "processCode")], [0, 1]],
            ["componentType", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "componentType")], [0, 1]],
            ["componentName", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "componentName")], [0, 1]],
            ["componentItem", "CrvApiClient::Api::Reproduction::ComponentItem[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ComponentItem,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "componentItem"),
        :schema_element => [
            ["item", "CrvApiClient::Api::Reproduction::Item[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Item,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "item"),
        :schema_element => [
            ["itemName", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "itemName")], [0, 1]],
            ["moduleCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "moduleCode")], [0, 1]],
            ["itemType", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "itemType")], [0, 1]],
            ["itemLng", "CrvApiClient::Api::Reproduction::ItemLng[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ItemLng,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "itemLng"),
        :schema_element => [
            ["languageCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "languageCode")], [0, 1]],
            ["itemLabel", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "itemLabel")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::GetSystemMessage,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "getSystemMessage"),
        :schema_element => [
            ["messageCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "messageCode")], [0, 1]],
            ["languageCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "languageCode")], [0, 1]],
            ["messageParameter", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "messageParameter")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::SystemMessage,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "systemMessage"),
        :schema_element => [
            ["message", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "message")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ListDomain,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "listDomain"),
        :schema_element => [
            ["domain", "CrvApiClient::Api::Reproduction::Domain[]", [0, nil]],
            ["languageCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "languageCode")], [0, 1]],
            ["representationType", ["CrvApiClient::Api::Reproduction::RepresentationType", XSD::QName.new(NsDictionary, "representationType")], [0, 1]],
            ["actual", ["CrvApiClient::Api::Reproduction::BooleanType", XSD::QName.new(NsDictionary, "actual")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::DomainValue,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "domainValue"),
        :schema_element => [
            ["domainCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "domainCode")]],
            ["columnValue", "CrvApiClient::Api::Reproduction::ColumnValue[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ColumnValue,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "columnValue"),
        :schema_element => [
            ["value", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "value")], [0, 1]],
            ["representation", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "representation")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Domain,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "domain"),
        :schema_element => [
            ["domainCode", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "domainCode")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::TimePeriod,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "timePeriod"),
        :schema_element => [
            ["beginDate", [nil, XSD::QName.new(NsCommon, "beginDate")], [0, 1]],
            ["beginTime", [nil, XSD::QName.new(NsCommon, "beginTime")], [0, 1]],
            ["endDate", [nil, XSD::QName.new(NsCommon, "endDate")], [0, 1]],
            ["endTime", [nil, XSD::QName.new(NsCommon, "endTime")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::IntervalId,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "intervalId"),
        :schema_element => [
            ["nr", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "nr")]],
            ["nrType", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "nrType")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalNumberCountry,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "animalNumberCountry"),
        :schema_element => [
            ["countryCd", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "countryCd")]],
            ["animalNrLength", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "animalNrLength")]],
            ["animalNrAlphanumeric", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "animalNrAlphanumeric")]],
            ["sortingOrder", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "sortingOrder")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::HourCode,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "hourCode"),
        :schema_element => [
            ["hourCd", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "hourCd")]],
            ["description", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "description")]],
            ["hourMutateAllowed", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "hourMutateAllowed")]],
            ["hourNecessary", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "hourNecessary")]],
            ["addressMutateAllowed", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "addressMutateAllowed")]],
            ["addressNecessary", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "addressNecessary")]],
            ["activityMutateAllowed", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "activityMutateAllowed")]],
            ["activityNecessary", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "activityNecessary")]],
            ["kilometresMutateAllowed", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "kilometresMutateAllowed")]],
            ["kilometresNecessary", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "kilometresNecessary")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Parameter,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "parameter"),
        :schema_element => [
            ["parameterName", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "parameterName")]],
            ["value", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "value")]],
            ["valueDescription", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "valueDescription")]],
            ["default", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "default")]],
            ["sortingOrder", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "sortingOrder")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Setting,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "setting"),
        :schema_element => [
            ["settingName", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "settingName")]],
            ["settingValue", ["SOAP::SOAPString", XSD::QName.new(NsDictionary, "settingValue")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ParticipantId,
        :schema_type => XSD::QName.new(NsParticipantTypes, "participantId"),
        :schema_element => [
            ["participantCode", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "participantCode")]],
            ["participantCodeType", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "participantCodeType")]],
            ["countryCode", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "countryCode")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::NameAddressLayout,
        :schema_type => XSD::QName.new(NsParticipantTypes, "nameAddressLayout"),
        :schema_element => [
            ["addressType", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "addressType")], [0, 1]],
            ["participantName", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "participantName")], [0, 1]],
            ["addressLine1", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "addressLine1")], [0, 1]],
            ["addressLine2", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "addressLine2")], [0, 1]],
            ["addressLine3", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "addressLine3")], [0, 1]],
            ["addressLine4", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "addressLine4")], [0, 1]],
            ["addressLine5", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "addressLine5")], [0, 1]],
            ["addressLine6", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "addressLine6")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Address,
        :schema_type => XSD::QName.new(NsParticipantTypes, "address"),
        :schema_element => [
            ["addressType", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "addressType")]],
            ["street", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "street")]],
            ["houseNr", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "houseNr")], [0, 1]],
            ["zipCd", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "zipCd")], [0, 1]],
            ["city", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "city")]],
            ["regionCd", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "regionCd")], [0, 1]],
            ["country", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "country")], [0, 1]],
            ["countryCd", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "countryCd")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Participant,
        :schema_type => XSD::QName.new(NsParticipantTypes, "participant"),
        :schema_element => [
            ["participant", "CrvApiClient::Api::Reproduction::ParticipantId"],
            ["preTitle", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "preTitle")], [0, 1]],
            ["initials", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "initials")], [0, 1]],
            ["firstname", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "firstname")], [0, 1]],
            ["prefix", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "prefix")], [0, 1]],
            ["surname", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "surname")], [0, 1]],
            ["postTitle", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "postTitle")], [0, 1]],
            ["composedName", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "composedName")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ConnectionDataBasic,
        :schema_type => XSD::QName.new(NsParticipantTypes, "connectionDataBasic"),
        :schema_element => [
            ["emailAddress", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "emailAddress")], [0, 1]],
            ["phoneNr", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "phoneNr")], [0, 1]],
            ["mobilePhone", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "mobilePhone")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Connection,
        :schema_type => XSD::QName.new(NsParticipantTypes, "connection"),
        :schema_element => [
            ["connectionType", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "connectionType")]],
            ["connection", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "connection")], [0, 1]],
            ["connectionUse", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "connectionUse")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ParticipantBasic,
        :schema_type => XSD::QName.new(NsParticipantTypes, "participantBasic"),
        :schema_element => [
            ["participant", "CrvApiClient::Api::Reproduction::Participant"],
            ["address", "CrvApiClient::Api::Reproduction::Address[]", [0, nil]],
            ["connectionDataBasic", "CrvApiClient::Api::Reproduction::ConnectionDataBasic", [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ParticipantComplete,
        :schema_type => XSD::QName.new(NsParticipantTypes, "participantComplete"),
        :schema_element => [
            ["participant", "CrvApiClient::Api::Reproduction::Participant"],
            ["address", "CrvApiClient::Api::Reproduction::Address[]", [0, nil]],
            ["connection", "CrvApiClient::Api::Reproduction::Connection[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ActualKeeper,
        :schema_type => XSD::QName.new(NsParticipantTypes, "actualKeeper"),
        :schema_element => [
            ["participant", "CrvApiClient::Api::Reproduction::ParticipantId"],
            ["nameAddressLayout", "CrvApiClient::Api::Reproduction::NameAddressLayout"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalId,
        :schema_type => XSD::QName.new(NsAnimalTypes, "animalId"),
        :schema_element => [
            ["animalNumber", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalNumber")]],
            ["animalNumberType", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalNumberType")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalDetailsBirth,
        :schema_type => XSD::QName.new(NsAnimalTypes, "animalDetailsBirth"),
        :schema_element => [
            ["animalId", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["animalNumberShort", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalNumberShort")], [0, 1]],
            ["sex", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "sex")], [0, 1]],
            ["colourHair", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "colourHair")], [0, 1]],
            ["birthDate", [nil, XSD::QName.new(NsAnimal, "birthDate")], [0, 1]],
            ["animalName", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalName")], [0, 1]],
            ["surrogateDam", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["dam", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["sire", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["breedComposition", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "breedComposition")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Animal,
        :schema_type => XSD::QName.new(NsAnimalTypes, "animal"),
        :schema_element => [
            ["animalId", "CrvApiClient::Api::Reproduction::AnimalId"],
            ["animalNumberShort", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalNumberShort")], [0, 1]],
            ["sex", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "sex")]],
            ["colourHair", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "colourHair")], [0, 1]],
            ["birthDate", [nil, XSD::QName.new(NsAnimal, "birthDate")]],
            ["deathDate", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "deathDate")], [0, 1]],
            ["animalName", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalName")], [0, 1]],
            ["breedComposition", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "breedComposition")], [0, 1]],
            ["redFactor", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "redFactor")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalManagement,
        :schema_type => XSD::QName.new(NsAnimalTypes, "animalManagement"),
        :schema_element => [
            ["animalId", "CrvApiClient::Api::Reproduction::AnimalId"],
            ["animalName", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalName")], [0, 1]],
            ["farmersAnimalNr", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "farmersAnimalNr")], [0, 1]],
            ["animalGroupNr", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalGroupNr")], [0, 1]],
            ["productionPurposeDate", [nil, XSD::QName.new(NsAnimal, "productionPurposeDate")], [0, 1]],
            ["productionPurpose", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "productionPurpose")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalPedigree,
        :schema_type => XSD::QName.new(NsAnimalTypes, "animalPedigree"),
        :schema_element => [
            ["animal", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["animalNrShort", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalNrShort")], [0, 1]],
            ["animalName", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalName")], [0, 1]],
            ["farmersAnimalNr", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "farmersAnimalNr")], [0, 1]],
            ["sex", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "sex")], [0, 1]],
            ["birthDate", [nil, XSD::QName.new(NsAnimal, "birthDate")], [0, 1]],
            ["colourHair", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "colourHair")], [0, 1]],
            ["pedigree", "CrvApiClient::Api::Reproduction::Pedigree", [0, 1]],
            ["participantAnimal", "CrvApiClient::Api::Reproduction::ParticipantAnimalId[]", [0, nil]],
            ["groupCode", "CrvApiClient::Api::Reproduction::AnimalGroup[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalSupplyId,
        :schema_type => XSD::QName.new(NsAnimalTypes, "animalSupplyId"),
        :schema_element => [
            ["animal", "CrvApiClient::Api::Reproduction::AnimalId"],
            ["supplyType", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "supplyType")]],
            ["supplyCd", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "supplyCd")]],
            ["plannedDepartureDate", [nil, XSD::QName.new(NsAnimal, "plannedDepartureDate")], [0, 1]],
            ["trader", "CrvApiClient::Api::Reproduction::ParticipantId", [0, 1]],
            ["destination", "CrvApiClient::Api::Reproduction::ParticipantId", [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Addresses,
        :schema_type => XSD::QName.new(NsAnimalTypes, "addresses"),
        :schema_element => [
            ["participant", "CrvApiClient::Api::Reproduction::Participant[]", [0, nil]],
            ["address", "CrvApiClient::Api::Reproduction::Address[]", [0, nil]],
            ["trader", "CrvApiClient::Api::Reproduction::ParticipantId", [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalArrivalDetail,
        :schema_type => XSD::QName.new(NsAnimalTypes, "animalArrivalDetail"),
        :schema_element => [
            ["animalId", "CrvApiClient::Api::Reproduction::AnimalId[]", [1, nil]],
            ["plannedArrivalDetail", "CrvApiClient::Api::Reproduction::PlannedArrivalDetail"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AverageHerdWeight,
        :schema_type => XSD::QName.new(NsAnimalTypes, "averageHerdWeight"),
        :schema_element => [
            ["keeper", "CrvApiClient::Api::Reproduction::ParticipantId"],
            ["referencePeriod", "CrvApiClient::Api::Reproduction::TimePeriod"],
            ["herdWeightCategoryResult", "CrvApiClient::Api::Reproduction::HerdWeightCategory[]", [1, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::BreedFraction,
        :schema_type => XSD::QName.new(NsAnimalTypes, "breedFraction"),
        :schema_element => [
            ["breed", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "breed")]],
            ["fraction", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "fraction")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::BullDetails,
        :schema_type => XSD::QName.new(NsAnimalTypes, "bullDetails"),
        :schema_element => [
            ["bullId", "CrvApiClient::Api::Reproduction::AnimalId"],
            ["aiCode", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["bullName", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "bullName")], [0, 1]],
            ["bullShortName", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "bullShortName")], [0, 1]],
            ["birthDate", [nil, XSD::QName.new(NsAnimal, "birthDate")], [0, 1]],
            ["colourHair", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "colourHair")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ColourCode,
        :schema_type => XSD::QName.new(NsAnimalTypes, "colourCode"),
        :schema_element => [
            ["countryCode", "SOAP::SOAPString"],
            ["colourCode", "SOAP::SOAPString"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ChainValue,
        :schema_type => XSD::QName.new(NsAnimalTypes, "chainValue"),
        :schema_element => [
            ["chainType", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "chainType")]],
            ["chainVersion", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "chainVersion")]],
            ["chainRowValue", "CrvApiClient::Api::Reproduction::ChainRowValue[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ChainRowValue,
        :schema_type => XSD::QName.new(NsAnimalTypes, "chainRowValue"),
        :schema_element => [
            ["rowCd", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "rowCd")]],
            ["rowValue", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "rowValue")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::DateReason,
        :schema_type => XSD::QName.new(NsAnimalTypes, "dateReason"),
        :schema_element => [
            ["date", [nil, XSD::QName.new(NsCommon, "date")]],
            ["reason", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "reason")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalGroup,
        :schema_type => XSD::QName.new(NsAnimalTypes, "animalGroup"),
        :schema_element => [
            ["animalGroupType", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalGroupType")]],
            ["animalGroupCode", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalGroupCode")]],
            ["animalGroupName", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalGroupName")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::HerdWeightCategory,
        :schema_type => XSD::QName.new(NsAnimalTypes, "herdWeightCategory"),
        :schema_element => [
            ["categoryCd", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "categoryCd")]],
            ["avgNoAnimals", [nil, XSD::QName.new(NsAnimal, "avgNoAnimals")]],
            ["avgWeightAnimals", [nil, XSD::QName.new(NsAnimal, "avgWeightAnimals")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ListParticipantAnimalRequest,
        :schema_type => XSD::QName.new(NsAnimalTypes, "listParticipantAnimalRequest"),
        :schema_element => [
            ["listType", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "listType")], [0, 1]],
            ["participantAnimalRequest", "CrvApiClient::Api::Reproduction::ParticipantAnimalRequest[]", [1, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ParticipantAnimalId,
        :schema_type => XSD::QName.new(NsAnimalTypes, "participantAnimalId"),
        :schema_element => [
            ["numberType", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "numberType")]],
            ["numberSubType", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "numberSubType")]],
            ["participantAnimalNr", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "participantAnimalNr")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ParticipantAnimalRequest,
        :schema_type => XSD::QName.new(NsAnimalTypes, "participantAnimalRequest"),
        :schema_element => [
            ["numberType", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "numberType")]],
            ["numberSubType", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "numberSubType")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::PeriodRange_,
        :schema_type => XSD::QName.new(NsAnimalTypes, "periodRange"),
        :schema_element => [
            ["beginDate", [nil, XSD::QName.new(NsCommon, "beginDate")]],
            ["endDate", [nil, XSD::QName.new(NsCommon, "endDate")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::PlannedArrivalDetail,
        :schema_type => XSD::QName.new(NsAnimalTypes, "plannedArrivalDetail"),
        :schema_element => [
            ["supplyCd", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "supplyCd")]],
            ["keeper", "CrvApiClient::Api::Reproduction::ParticipantId"],
            ["plannedDepartureDate", [nil, XSD::QName.new(NsAnimal, "plannedDepartureDate")], [0, 1]],
            ["foodChainInfo", ["CrvApiClient::Api::Reproduction::BooleanType", XSD::QName.new(NsAnimal, "foodChainInfo")], [0, 1]],
            ["foodChainInfoStandard", ["CrvApiClient::Api::Reproduction::BooleanType", XSD::QName.new(NsAnimal, "foodChainInfoStandard")], [0, 1]],
            ["trader", "CrvApiClient::Api::Reproduction::ParticipantId"],
            ["loadGroup", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "loadGroup")], [0, 1]],
            ["destination", "CrvApiClient::Api::Reproduction::ParticipantId", [0, 1]],
            ["plannedDeliveryDateTime", [nil, XSD::QName.new(NsAnimal, "plannedDeliveryDateTime")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Pedigree,
        :schema_type => XSD::QName.new(NsAnimalTypes, "pedigree"),
        :schema_element => [
            ["sire", "CrvApiClient::Api::Reproduction::Animal", [0, 1]],
            ["dam", "CrvApiClient::Api::Reproduction::Animal", [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::PlannedArrival,
        :schema_type => XSD::QName.new(NsAnimalTypes, "plannedArrival"),
        :schema_element => [
            ["animal", "CrvApiClient::Api::Reproduction::Animal[]", [0, nil]],
            ["plannedArrivalDetail", "CrvApiClient::Api::Reproduction::PlannedArrivalDetail"],
            ["breedFraction", "CrvApiClient::Api::Reproduction::BreedFraction[]", [1, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::SemenAmount,
        :schema_type => XSD::QName.new(NsLogisticsTypes, "semenAmount"),
        :schema_element => [
            ["bullCd", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "bullCd")]],
            ["semenType", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "semenType")]],
            ["amount", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "amount")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::DistributionRound,
        :schema_type => XSD::QName.new(NsLogisticsTypes, "distributionRound"),
        :schema_element => [
            ["employee", "CrvApiClient::Api::Reproduction::ParticipantId_"],
            ["deliveryDate", [nil, XSD::QName.new(NsLogistics, "deliveryDate")]],
            ["round", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "round")], [0, 1]],
            ["district", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "district")], [0, 1]],
            ["routeCd", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "routeCd")], [0, 1]],
            ["licensePlate", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "licensePlate")], [0, 1]],
            ["startKilometres", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "startKilometres")], [0, 1]],
            ["endKilometres", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "endKilometres")], [0, 1]],
            ["kilometres", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "kilometres")], [0, 1]],
            ["mainDepot", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "mainDepot")], [0, 1]],
            ["privateDepot", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "privateDepot")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::OrderConfirmation,
        :schema_type => XSD::QName.new(NsLogisticsTypes, "orderConfirmation"),
        :schema_element => [
            ["orderNr", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "orderNr")]],
            ["orderLineNr", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "orderLineNr")]],
            ["amount", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "amount")]],
            ["registrationTime", [nil, XSD::QName.new(NsLogistics, "registrationTime")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::SemenRemoval,
        :schema_type => XSD::QName.new(NsLogisticsTypes, "semenRemoval"),
        :schema_element => [
            ["depot", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "depot")]],
            ["removalReasonCd", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "removalReasonCd")]],
            ["registrationTime", [nil, XSD::QName.new(NsLogistics, "registrationTime")]],
            ["semenRemoved", "CrvApiClient::Api::Reproduction::SemenAmount"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::SemenTransfer,
        :schema_type => XSD::QName.new(NsLogisticsTypes, "semenTransfer"),
        :schema_element => [
            ["depotFrom", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "depotFrom")]],
            ["depotTo", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "depotTo")]],
            ["registrationTime", [nil, XSD::QName.new(NsLogistics, "registrationTime")]],
            ["semenTransfered", "CrvApiClient::Api::Reproduction::SemenAmount[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::TimeRegistration,
        :schema_type => XSD::QName.new(NsLogisticsTypes, "timeRegistration"),
        :schema_element => [
            ["hourCd", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "hourCd")]],
            ["nrOfAddresses", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "nrOfAddresses")]],
            ["nrOfActivities", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "nrOfActivities")]],
            ["minutes", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "minutes")]],
            ["kilometres", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "kilometres")]],
            ["registrationTime", [nil, XSD::QName.new(NsLogistics, "registrationTime")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Announcement,
        :schema_type => XSD::QName.new(NsLogisticsTypes, "announcement"),
        :schema_element => [
            ["announcementText", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "announcementText")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Depot,
        :schema_type => XSD::QName.new(NsLogisticsTypes, "depot"),
        :schema_element => [
            ["depot", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "depot")]],
            ["depotName", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "depotName")]],
            ["city", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "city")]],
            ["semenStock", "CrvApiClient::Api::Reproduction::SemenAmount[]", [0, nil]],
            ["semenOrder", "CrvApiClient::Api::Reproduction::SemenOrder[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::EmployeeOnRoute,
        :schema_type => XSD::QName.new(NsLogisticsTypes, "employeeOnRoute"),
        :schema_element => [
            ["employee", "CrvApiClient::Api::Reproduction::ParticipantId"],
            ["employeeName", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "employeeName")]],
            ["routeCd", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "routeCd")]],
            ["nrOfAddresses", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "nrOfAddresses")]],
            ["nrOfActivities", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "nrOfActivities")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::SemenOrder,
        :schema_type => XSD::QName.new(NsLogisticsTypes, "semenOrder"),
        :schema_element => [
            ["site", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "site")]],
            ["orderNr", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "orderNr")]],
            ["orderLineNr", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "orderLineNr")]],
            ["deliveryDate", [nil, XSD::QName.new(NsLogistics, "deliveryDate")]],
            ["semenOrdered", "CrvApiClient::Api::Reproduction::SemenAmount"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::EmbryoCollection,
        :schema_type => XSD::QName.new(NsLogisticsTypes, "embryoCollection"),
        :schema_element => [
            ["embryoCollectionNr", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "embryoCollectionNr")]],
            ["sire", "CrvApiClient::Api::Reproduction::AnimalId"],
            ["sireName", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "sireName")], [0, 1]],
            ["dam", "CrvApiClient::Api::Reproduction::AnimalId"],
            ["damName", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "damName")], [0, 1]],
            ["semenType", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "semenType")]],
            ["embryoCollectionDate", [nil, XSD::QName.new(NsLogistics, "embryoCollectionDate")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ParticipantId_,
        :schema_type => XSD::QName.new(NsLogisticsTypes, "participantId"),
        :schema_element => [
            ["participantCode", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "participantCode")]],
            ["participantCodeType", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "participantCodeType")], [0, 1]],
            ["countryCode", ["SOAP::SOAPString", XSD::QName.new(NsLogistics, "countryCode")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalIndication,
        :schema_type => XSD::QName.new(NsReproductionTypes, "animalIndication"),
        :schema_element => [
            ["animal", "CrvApiClient::Api::Reproduction::AnimalId"],
            ["indicationType", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "indicationType")]],
            ["indication", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "indication")]],
            ["indicationDateTime", [nil, XSD::QName.new(NsReproduction, "indicationDateTime")]],
            ["indicationExpirationDateTime", [nil, XSD::QName.new(NsReproduction, "indicationExpirationDateTime")], [0, 1]],
            ["indicationCertainty", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "indicationCertainty")]],
            ["indicatorCode", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "indicatorCode")]],
            ["indicatorCodeType", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "indicatorCodeType")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Calving,
        :schema_type => XSD::QName.new(NsReproductionTypes, "calving"),
        :schema_element => [
            ["calvingDate", [nil, XSD::QName.new(NsReproduction, "calvingDate")]],
            ["parity", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "parity")], [0, 1]],
            ["gestationLength", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "gestationLength")], [0, 1]],
            ["calvingEaseScore", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "calvingEaseScore")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Gestation,
        :schema_type => XSD::QName.new(NsReproductionTypes, "gestation"),
        :schema_element => [
            ["reproductionDate", [nil, XSD::QName.new(NsReproduction, "reproductionDate")]],
            ["calvingDateExp", [nil, XSD::QName.new(NsReproduction, "calvingDateExp")]],
            ["gestationStatus", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "gestationStatus")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::GestationReproduction,
        :schema_type => XSD::QName.new(NsReproductionTypes, "gestationReproduction"),
        :schema_element => [
            ["reproductionType", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "reproductionType")]],
            ["reproductionDate", [nil, XSD::QName.new(NsReproduction, "reproductionDate")]],
            ["endDateRWB", [nil, XSD::QName.new(NsReproduction, "endDateRWB")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalReproduction,
        :schema_type => XSD::QName.new(NsReproductionTypes, "animalReproduction"),
        :schema_element => [
            ["animal", "CrvApiClient::Api::Reproduction::AnimalId"],
            ["animalNrShort", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalNrShort")]],
            ["animalName", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalName")], [0, 1]],
            ["farmersAnimalNr", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "farmersAnimalNr")], [0, 1]],
            ["sex", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "sex")]],
            ["birthDate", [nil, XSD::QName.new(NsAnimal, "birthDate")], [0, 1]],
            ["colourHair", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "colourHair")], [0, 1]],
            ["dam", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["sire", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["sireName", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "sireName")], [0, 1]],
            ["lastCalvingDate", [nil, XSD::QName.new(NsReproduction, "lastCalvingDate")], [0, 1]],
            ["lastInseminationDate", [nil, XSD::QName.new(NsReproduction, "lastInseminationDate")], [0, 1]],
            ["serviceSire", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["serviceSireName", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "serviceSireName")], [0, 1]],
            ["lastDryDate", [nil, XSD::QName.new(NsReproduction, "lastDryDate")], [0, 1]],
            ["expectedCalvingDate", [nil, XSD::QName.new(NsReproduction, "expectedCalvingDate")], [0, 1]],
            ["reproductionStatus", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "reproductionStatus")]],
            ["lastInHeatDate", [nil, XSD::QName.new(NsReproduction, "lastInHeatDate")], [0, 1]],
            ["participantAnimal", "CrvApiClient::Api::Reproduction::ParticipantAnimalId[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalReproductionLastParity,
        :schema_type => XSD::QName.new(NsReproductionTypes, "animalReproductionLastParity"),
        :schema_element => [
            ["animal", "CrvApiClient::Api::Reproduction::AnimalId"],
            ["animalNrShort", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalNrShort")]],
            ["animalName", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalName")], [0, 1]],
            ["farmersAnimalNr", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "farmersAnimalNr")], [0, 1]],
            ["calving", "CrvApiClient::Api::Reproduction::Calving", [0, 1]],
            ["lastInseminationDate", [nil, XSD::QName.new(NsReproduction, "lastInseminationDate")], [0, 1]],
            ["serviceSire", "CrvApiClient::Api::Reproduction::AnimalId[]", [0, nil]],
            ["serviceSireName", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "serviceSireName")], [0, 1]],
            ["serviceSireSemenType", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "serviceSireSemenType")], [0, 1]],
            ["dryDate", [nil, XSD::QName.new(NsReproduction, "dryDate")], [0, 1]],
            ["expectedCalvingDate", [nil, XSD::QName.new(NsReproduction, "expectedCalvingDate")], [0, 1]],
            ["reproductionStatus", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "reproductionStatus")]],
            ["lastInHeatDate", [nil, XSD::QName.new(NsReproduction, "lastInHeatDate")], [0, 1]],
            ["participantAnimal", "CrvApiClient::Api::Reproduction::ParticipantAnimalId[]", [0, nil]],
            ["nrOfInseminations", [nil, XSD::QName.new(NsReproduction, "nrOfInseminations")], [0, 1]],
            ["lastPregnancyCheckDate", [nil, XSD::QName.new(NsReproduction, "lastPregnancyCheckDate")], [0, 1]],
            ["pregnancyCheckResult", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "pregnancyCheckResult")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalReproductionIndication,
        :schema_type => XSD::QName.new(NsReproductionTypes, "animalReproductionIndication"),
        :schema_element => [
            ["animal", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["participantAnimal", "CrvApiClient::Api::Reproduction::ParticipantAnimalId", [0, 1]],
            ["indication", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "indication")]],
            ["indicationDateTime", [nil, XSD::QName.new(NsReproduction, "indicationDateTime")], [0, 1]],
            ["indicationExpirationDateTime", [nil, XSD::QName.new(NsReproduction, "indicationExpirationDateTime")], [0, 1]],
            ["indicationCertainty", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "indicationCertainty")], [0, 1]],
            ["indicator", "CrvApiClient::Api::Reproduction::ParticipantId", [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::InseminationForFlushing,
        :schema_type => XSD::QName.new(NsReproductionTypes, "inseminationForFlushing"),
        :schema_element => [
            ["serialNr", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "serialNr")], [0, 1]],
            ["inseminationDate", [nil, XSD::QName.new(NsReproduction, "inseminationDate")]],
            ["bull", "CrvApiClient::Api::Reproduction::AnimalId"],
            ["bullCd", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "bullCd")], [0, 1]],
            ["semenType", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "semenType")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalExamination,
        :schema_type => XSD::QName.new(NsReproductionTypes, "animalExamination"),
        :schema_element => [
            ["cow", "CrvApiClient::Api::Reproduction::AnimalId"],
            ["cowScanned", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "cowScanned")]],
            ["examinationCd", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "examinationCd")]],
            ["examinationResult", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "examinationResult")], [0, 1]],
            ["registrationTime", [nil, XSD::QName.new(NsReproduction, "registrationTime")]],
            ["productAmount", "CrvApiClient::Api::Reproduction::ProductAmount[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::EmbryoFrozen,
        :schema_type => XSD::QName.new(NsReproductionTypes, "embryoFrozen"),
        :schema_element => [
            ["embryoSerialNr", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "embryoSerialNr")]],
            ["trypsineBatchNr", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "trypsineBatchNr")]],
            ["mediumBatchNr", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "mediumBatchNr")]],
            ["containerNr", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "containerNr")]],
            ["canisterNr", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "canisterNr")]],
            ["qualityCd", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "qualityCd")]],
            ["stageCd", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "stageCd")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Flushing,
        :schema_type => XSD::QName.new(NsReproductionTypes, "flushing"),
        :schema_element => [
            ["dam", "CrvApiClient::Api::Reproduction::AnimalId"],
            ["embryoCollectionNr", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "embryoCollectionNr")]],
            ["flushingSolutionBatchNr", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "flushingSolutionBatchNr")]],
            ["holdingSolutionBatchNr", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "holdingSolutionBatchNr")]],
            ["numberOfOocyte", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "numberOfOocyte")], [0, 1]],
            ["numberOfEmbryo", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "numberOfEmbryo")], [0, 1]],
            ["numberOfEmbryoFrozen", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "numberOfEmbryoFrozen")], [0, 1]],
            ["debtor", "CrvApiClient::Api::Reproduction::ParticipantId_", [0, 1]],
            ["registrationTime", [nil, XSD::QName.new(NsReproduction, "registrationTime")]],
            ["inseminationForFlushing", "CrvApiClient::Api::Reproduction::InseminationForFlushing[]", [0, nil]],
            ["embryoFrozen", "CrvApiClient::Api::Reproduction::EmbryoFrozen[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Insemination,
        :schema_type => XSD::QName.new(NsReproductionTypes, "insemination"),
        :schema_element => [
            ["cow", "CrvApiClient::Api::Reproduction::AnimalId"],
            ["cowScanned", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "cowScanned")]],
            ["bullCd", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "bullCd")]],
            ["bullCdScanned", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "bullCdScanned")]],
            ["chargeNr", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "chargeNr")]],
            ["chargeNrScanned", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "chargeNrScanned")]],
            ["bull", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["semenType", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "semenType")]],
            ["ownStock", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "ownStock")]],
            ["semenChargeCd", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "semenChargeCd")]],
            ["fertilityScore", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "fertilityScore")], [0, 1]],
            ["examinationCd", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "examinationCd")], [0, 1]],
            ["inseminationForFlushing", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "inseminationForFlushing")]],
            ["registrationTime", [nil, XSD::QName.new(NsReproduction, "registrationTime")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Indications,
        :schema_type => XSD::QName.new(NsReproductionTypes, "indications"),
        :schema_element => [
            ["indication", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "indication")]],
            ["indicationDateTime", nil],
            ["indicationCertaintyOld", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "indicationCertaintyOld")]],
            ["indicationCertaintyNew", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "indicationCertaintyNew")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Transplantation,
        :schema_type => XSD::QName.new(NsReproductionTypes, "transplantation"),
        :schema_element => [
            ["cow", "CrvApiClient::Api::Reproduction::AnimalId"],
            ["cowScanned", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "cowScanned")]],
            ["recipientRejected", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "recipientRejected")]],
            ["embryoCollectionNr", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "embryoCollectionNr")], [0, 1]],
            ["embryoSerialNr", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "embryoSerialNr")], [0, 1]],
            ["chargeEmbryo", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "chargeEmbryo")], [0, 1]],
            ["sire", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["bullCdSire", ["SOAP::SOAPString", XSD::QName.new(NsReproduction, "bullCdSire")], [0, 1]],
            ["dam", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["embryoCollectionDate", [nil, XSD::QName.new(NsReproduction, "embryoCollectionDate")], [0, 1]],
            ["debtor", "CrvApiClient::Api::Reproduction::ParticipantId_", [0, 1]],
            ["registrationTime", [nil, XSD::QName.new(NsReproduction, "registrationTime")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ProductDescription,
        :schema_type => XSD::QName.new(NsProductTypes, "productDescription"),
        :schema_element => [
            ["productCd", ["SOAP::SOAPString", XSD::QName.new(NsProduct, "productCd")]],
            ["description", ["SOAP::SOAPString", XSD::QName.new(NsProduct, "description")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::BullDetails_,
        :schema_type => XSD::QName.new(NsProductTypes, "bullDetails"),
        :schema_element => [
            ["bullCd", ["SOAP::SOAPString", XSD::QName.new(NsProduct, "bullCd")]],
            ["bullName", ["SOAP::SOAPString", XSD::QName.new(NsProduct, "bullName")]],
            ["bull", "CrvApiClient::Api::Reproduction::AnimalId"],
            ["sireName", ["SOAP::SOAPString", XSD::QName.new(NsProduct, "sireName")]],
            ["damSireName", ["SOAP::SOAPString", XSD::QName.new(NsProduct, "damSireName")]],
            ["colourHair", ["SOAP::SOAPString", XSD::QName.new(NsProduct, "colourHair")]],
            ["breedFactor1", ["SOAP::SOAPString", XSD::QName.new(NsProduct, "breedFactor1")], [0, 1]],
            ["breedFactor2", ["SOAP::SOAPString", XSD::QName.new(NsProduct, "breedFactor2")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ProductAmount,
        :schema_type => XSD::QName.new(NsProductTypes, "productAmount"),
        :schema_element => [
            ["productCd", ["SOAP::SOAPString", XSD::QName.new(NsProduct, "productCd")]],
            ["batchNr", ["SOAP::SOAPString", XSD::QName.new(NsProduct, "batchNr")], [0, 1]],
            ["amount", ["SOAP::SOAPString", XSD::QName.new(NsProduct, "amount")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalOffer,
        :schema_type => XSD::QName.new(NsBreedingTypes, "animalOffer"),
        :schema_element => [
            ["animalOfferType", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "animalOfferType")], [0, 1]],
            ["animalId", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["owner", "CrvApiClient::Api::Reproduction::ParticipantId", [0, 1]],
            ["keeper", "CrvApiClient::Api::Reproduction::ParticipantId", [0, 1]],
            ["agreement", ["CrvApiClient::Api::Reproduction::BooleanType", XSD::QName.new(NsBreeding, "agreement")], [0, 1]],
            ["ibrFree", ["CrvApiClient::Api::Reproduction::BooleanType", XSD::QName.new(NsBreeding, "ibrFree")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalBullAdvice,
        :schema_type => XSD::QName.new(NsBreedingTypes, "animalBullAdvice"),
        :schema_element => [
            ["animalId", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["recommendedBull", "CrvApiClient::Api::Reproduction::RecommendedBull[]", [0, 3]],
            ["missingAdvice", "CrvApiClient::Api::Reproduction::MissingAdvice[]", [0, 3]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalDetailsBreeding,
        :schema_type => XSD::QName.new(NsBreedingTypes, "animalDetailsBreeding"),
        :schema_element => [
            ["animalId", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["animalName", ["SOAP::SOAPString", XSD::QName.new(NsAnimal, "animalName")], [0, 1]],
            ["breedCalculation", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "breedCalculation")], [0, 1]],
            ["contractNumber", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "contractNumber")], [0, 1]],
            ["embryoNumber", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "embryoNumber")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalOfferAnalysisRequest,
        :schema_type => XSD::QName.new(NsBreedingTypes, "animalOfferAnalysisRequest"),
        :schema_element => [
            ["requestDate", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "requestDate")], [0, 1]],
            ["requestTime", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "requestTime")], [0, 1]],
            ["analysisType", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "analysisType")], [0, 1]],
            ["analysisName", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "analysisName")], [0, 1]],
            ["requested", ["CrvApiClient::Api::Reproduction::BooleanType", XSD::QName.new(NsBreeding, "requested")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalOfferAnalysis,
        :schema_type => XSD::QName.new(NsBreedingTypes, "animalOfferAnalysis"),
        :schema_element => [
            ["analysisType", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "analysisType")], [0, 1]],
            ["analysisName", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "analysisName")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnalysisRequest,
        :schema_type => XSD::QName.new(NsBreedingTypes, "analysisRequest"),
        :schema_element => [
            ["analysisType", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "analysisType")], [0, 1]],
            ["requested", ["CrvApiClient::Api::Reproduction::BooleanType", XSD::QName.new(NsBreeding, "requested")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalOfferStatus,
        :schema_type => XSD::QName.new(NsBreedingTypes, "animalOfferStatus"),
        :schema_element => [
            ["statusDate", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "statusDate")], [0, 1]],
            ["statusTime", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "statusTime")], [0, 1]],
            ["registrant", "CrvApiClient::Api::Reproduction::ParticipantId", [0, 1]],
            ["registrantName", ["SOAP::SOAPString", XSD::QName.new(NsParticipant, "registrantName")], [0, 1]],
            ["processCode", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "processCode")], [0, 1]],
            ["processName", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "processName")], [0, 1]],
            ["statusType", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "statusType")], [0, 1]],
            ["statusDescription", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "statusDescription")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::MissingAdvice,
        :schema_type => XSD::QName.new(NsBreedingTypes, "missingAdvice"),
        :schema_element => [
            ["ranking", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "ranking")]],
            ["missingAdviceType", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "missingAdviceType")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::RecommendedBull,
        :schema_type => XSD::QName.new(NsBreedingTypes, "recommendedBull"),
        :schema_element => [
            ["ranking", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "ranking")]],
            ["name", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "name")], [0, 1]],
            ["aiCode", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["semenType", ["SOAP::SOAPString", XSD::QName.new(NsBreeding, "semenType")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::GetHerdListRequestType,
        :schema_type => XSD::QName.new(NsC_1, "GetHerdListRequestType"),
        :schema_element => [
            ["messageHeader", ["CrvApiClient::Api::Reproduction::ADEExchangedDocumentType", XSD::QName.new(NsC_1, "MessageHeader")]],
            ["standardRequest", ["CrvApiClient::Api::Reproduction::StandardRequestType", XSD::QName.new(NsC_1, "StandardRequest")]],
            ["specificRequestGetHerdList", ["CrvApiClient::Api::Reproduction::SpecificRequestGetHerdListType", XSD::QName.new(NsC_1, "SpecificRequestGetHerdList")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::GetHerdListResponseType,
        :schema_type => XSD::QName.new(NsC_1, "GetHerdListResponseType"),
        :schema_element => [
            ["messageHeader", ["CrvApiClient::Api::Reproduction::ADEExchangedDocumentType", XSD::QName.new(NsC_1, "MessageHeader")]],
            ["standardResponse", ["CrvApiClient::Api::Reproduction::StandardResponseType", XSD::QName.new(NsC_1, "StandardResponse")]],
            ["specificResponseGetHerdList", ["CrvApiClient::Api::Reproduction::SpecificResponseGetHerdListType", XSD::QName.new(NsC_1, "SpecificResponseGetHerdList")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::UpdateAnimalRequestType,
        :schema_type => XSD::QName.new(NsC_1, "UpdateAnimalRequestType"),
        :schema_element => [
            ["messageHeader", ["CrvApiClient::Api::Reproduction::ADEExchangedDocumentType", XSD::QName.new(NsC_1, "MessageHeader")]],
            ["standardRequest", ["CrvApiClient::Api::Reproduction::StandardRequestType", XSD::QName.new(NsC_1, "StandardRequest")]],
            ["specificRequestAnimal", ["CrvApiClient::Api::Reproduction::SpecificRequestAnimalType", XSD::QName.new(NsC_1, "SpecificRequestAnimal")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::UpdateAnimalResponseType,
        :schema_type => XSD::QName.new(NsC_1, "UpdateAnimalResponseType"),
        :schema_element => [
            ["messageHeader", ["CrvApiClient::Api::Reproduction::ADEExchangedDocumentType", XSD::QName.new(NsC_1, "MessageHeader")]],
            ["standardResponse", ["CrvApiClient::Api::Reproduction::StandardResponseType", XSD::QName.new(NsC_1, "StandardResponse")]],
            ["specificResponse", ["CrvApiClient::Api::Reproduction::SpecificResponseType", XSD::QName.new(NsC_1, "SpecificResponse")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::UpdateDeviceRequestType,
        :schema_type => XSD::QName.new(NsC_1, "UpdateDeviceRequestType"),
        :schema_element => [
            ["messageHeader", ["CrvApiClient::Api::Reproduction::ADEExchangedDocumentType", XSD::QName.new(NsC_1, "MessageHeader")]],
            ["standardRequest", ["CrvApiClient::Api::Reproduction::StandardRequestType", XSD::QName.new(NsC_1, "StandardRequest")]],
            ["specificRequestDevice", ["CrvApiClient::Api::Reproduction::SpecificRequestDeviceType", XSD::QName.new(NsC_1, "SpecificRequestDevice")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::UpdateDeviceResponseType,
        :schema_type => XSD::QName.new(NsC_1, "UpdateDeviceResponseType"),
        :schema_element => [
            ["messageHeader", ["CrvApiClient::Api::Reproduction::ADEExchangedDocumentType", XSD::QName.new(NsC_1, "MessageHeader")]],
            ["standardResponse", ["CrvApiClient::Api::Reproduction::StandardResponseType", XSD::QName.new(NsC_1, "StandardResponse")]],
            ["specificResponse", ["CrvApiClient::Api::Reproduction::SpecificResponseType", XSD::QName.new(NsC_1, "SpecificResponse")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::UpdateLivestockLocationRequestType,
        :schema_type => XSD::QName.new(NsC_1, "UpdateLivestockLocationRequestType"),
        :schema_element => [
            ["messageHeader", ["CrvApiClient::Api::Reproduction::ADEExchangedDocumentType", XSD::QName.new(NsC_1, "MessageHeader")]],
            ["standardRequest", ["CrvApiClient::Api::Reproduction::StandardRequestType", XSD::QName.new(NsC_1, "StandardRequest")]],
            ["specificRequestLivestockLocation", ["CrvApiClient::Api::Reproduction::SpecificRequestLivestockLocationType", XSD::QName.new(NsC_1, "SpecificRequestLivestockLocation")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::UpdateLivestockLocationResponseType,
        :schema_type => XSD::QName.new(NsC_1, "UpdateLivestockLocationResponseType"),
        :schema_element => [
            ["messageHeader", ["CrvApiClient::Api::Reproduction::ADEExchangedDocumentType", XSD::QName.new(NsC_1, "MessageHeader")]],
            ["standardResponse", ["CrvApiClient::Api::Reproduction::StandardResponseType", XSD::QName.new(NsC_1, "StandardResponse")]],
            ["specificResponse", ["CrvApiClient::Api::Reproduction::SpecificResponseType", XSD::QName.new(NsC_1, "SpecificResponse")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::UpdateMilkingResultRequestType,
        :schema_type => XSD::QName.new(NsC_1, "UpdateMilkingResultRequestType"),
        :schema_element => [
            ["messageHeader", ["CrvApiClient::Api::Reproduction::ADEExchangedDocumentType", XSD::QName.new(NsC_1, "MessageHeader")]],
            ["standardRequest", ["CrvApiClient::Api::Reproduction::StandardRequestType", XSD::QName.new(NsC_1, "StandardRequest")]],
            ["specificRequestMilingResult", ["CrvApiClient::Api::Reproduction::SpecificRequestMilkingResultType", XSD::QName.new(NsC_1, "SpecificRequestMilingResult")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::UpdateMilkingResultResponseType,
        :schema_type => XSD::QName.new(NsC_1, "UpdateMilkingResultResponseType"),
        :schema_element => [
            ["messageHeader", ["CrvApiClient::Api::Reproduction::ADEExchangedDocumentType", XSD::QName.new(NsC_1, "MessageHeader")]],
            ["standardResponse", ["CrvApiClient::Api::Reproduction::StandardResponseType", XSD::QName.new(NsC_1, "StandardResponse")]],
            ["specificResponse", ["CrvApiClient::Api::Reproduction::SpecificResponseType", XSD::QName.new(NsC_1, "SpecificResponse")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ADEExchangedDocumentType,
        :schema_type => XSD::QName.new(NsC_1, "ADEExchangedDocumentType"),
        :schema_element => [
            ["identifier", ["CrvApiClient::Api::Reproduction::IDType", XSD::QName.new(NsC_1, "Identifier")]],
            ["issueing", [nil, XSD::QName.new(NsC_1, "Issueing")]],
            ["version", [nil, XSD::QName.new(NsC_1, "Version")]],
            ["type", ["CrvApiClient::Api::Reproduction::CodeType", XSD::QName.new(NsC_1, "Type")]],
            ["language", ["CrvApiClient::Api::Reproduction::CodeType", XSD::QName.new(NsC_1, "Language")], [0, 1]],
            ["senderParty", ["CrvApiClient::Api::Reproduction::ADEPartyType", XSD::QName.new(NsC_1, "SenderParty")]],
            ["recipientParty", ["CrvApiClient::Api::Reproduction::ADEPartyType", XSD::QName.new(NsC_1, "RecipientParty")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ADEPartyType,
        :schema_type => XSD::QName.new(NsC_1, "ADEPartyType"),
        :schema_element => [
            ["name", ["CrvApiClient::Api::Reproduction::NameType", XSD::QName.new(NsC_1, "Name")], [0, 1]],
            ["iD", ["CrvApiClient::Api::Reproduction::IDType", XSD::QName.new(NsC_1, "ID")]],
            ["country", ["CrvApiClient::Api::Reproduction::ISOTwoletterCountryCodeIdentifierContentType", XSD::QName.new(NsC_1, "Country")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::SpecificRequestGetHerdListType,
        :schema_type => XSD::QName.new(NsC_1, "SpecificRequestGetHerdListType"),
        :schema_element => [
            ["dataToBeCompressed", [nil, XSD::QName.new(NsC_1, "DataToBeCompressed")]],
            ["specificRequestDetail", ["CrvApiClient::Api::Reproduction::SpecificRequestGetHerdListType::SpecificRequestDetail", XSD::QName.new(NsC_1, "SpecificRequestDetail")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::SpecificRequestGetHerdListType::SpecificRequestDetail,
        :schema_name => XSD::QName.new(NsC_1, "SpecificRequestDetail"),
        :is_anonymous => true,
        :schema_qualified => true,
        :schema_element => [:choice,
                            ["ticketRequest", ["CrvApiClient::Api::Reproduction::TicketRequestType", XSD::QName.new(NsC_1, "TicketRequest")]],
                            ["herdListRequest", ["CrvApiClient::Api::Reproduction::HerdListRequestType", XSD::QName.new(NsC_1, "HerdListRequest")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::SpecificResponseGetHerdListType,
        :schema_type => XSD::QName.new(NsC_1, "SpecificResponseGetHerdListType"),
        :schema_element => [:choice,
                            ["ticketResponse", ["CrvApiClient::Api::Reproduction::TicketResponseType", XSD::QName.new(NsC_1, "TicketResponse")]],
                            ["herdListMessage", ["CrvApiClient::Api::Reproduction::HerdListMessageType", XSD::QName.new(NsC_1, "HerdListMessage")]],
                            ["getHerdListResponseZipMessage", ["CrvApiClient::Api::Reproduction::ZipMessageType", XSD::QName.new(NsC_1, "GetHerdListResponseZipMessage")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::SpecificRequestAnimalType,
        :schema_type => XSD::QName.new(NsC_1, "SpecificRequestAnimalType"),
        :schema_element => [:choice,
                            ["ticketRequest", ["CrvApiClient::Api::Reproduction::TicketRequestType", XSD::QName.new(NsC_1, "TicketRequest")]],
                            ["animalListMessage", ["CrvApiClient::Api::Reproduction::AnimalListMessageType", XSD::QName.new(NsC_1, "AnimalListMessage")]],
                            ["updateAnimalRequestZipMessage", ["CrvApiClient::Api::Reproduction::ZipMessageType", XSD::QName.new(NsC_1, "UpdateAnimalRequestZipMessage")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::SpecificRequestDeviceType,
        :schema_type => XSD::QName.new(NsC_1, "SpecificRequestDeviceType"),
        :schema_element => [:choice,
                            ["ticketRequest", ["CrvApiClient::Api::Reproduction::TicketRequestType", XSD::QName.new(NsC_1, "TicketRequest")]],
                            ["deviceListMessage", ["CrvApiClient::Api::Reproduction::DeviceListMessageType", XSD::QName.new(NsC_1, "DeviceListMessage")]],
                            ["updateDeviceRequestZipMessage", ["CrvApiClient::Api::Reproduction::ZipMessageType", XSD::QName.new(NsC_1, "UpdateDeviceRequestZipMessage")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::SpecificRequestLivestockLocationType,
        :schema_type => XSD::QName.new(NsC_1, "SpecificRequestLivestockLocationType"),
        :schema_element => [:choice,
                            ["ticketRequest", ["CrvApiClient::Api::Reproduction::TicketRequestType", XSD::QName.new(NsC_1, "TicketRequest")]],
                            ["livestockLocation", ["CrvApiClient::Api::Reproduction::LivestockLocationType", XSD::QName.new(NsC_1, "LivestockLocation")]],
                            ["updateLivestockLocationrequestZipMessage", ["CrvApiClient::Api::Reproduction::ZipMessageType", XSD::QName.new(NsC_1, "UpdateLivestockLocationrequestZipMessage")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::SpecificRequestMilkingResultType,
        :schema_type => XSD::QName.new(NsC_1, "SpecificRequestMilkingResultType"),
        :schema_element => [:choice,
                            ["ticketRequest", ["CrvApiClient::Api::Reproduction::TicketRequestType", XSD::QName.new(NsC_1, "TicketRequest")]],
                            ["milkingResult", ["CrvApiClient::Api::Reproduction::MilkingResultType", XSD::QName.new(NsC_1, "MilkingResult")]],
                            ["updateMilkingResultRequestZipMessage", ["CrvApiClient::Api::Reproduction::ZipMessageType", XSD::QName.new(NsC_1, "UpdateMilkingResultRequestZipMessage")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::StandardRequestType,
        :schema_type => XSD::QName.new(NsC_1, "StandardRequestType"),
        :schema_element => [:choice,
                            ["authenticationToken", ["CrvApiClient::Api::Reproduction::TextType", XSD::QName.new(NsC_1, "AuthenticationToken")]],
                            ["authentificationLogin", ["CrvApiClient::Api::Reproduction::StandardRequestType::AuthentificationLogin", XSD::QName.new(NsC_1, "AuthentificationLogin")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::StandardRequestType::AuthentificationLogin,
        :schema_name => XSD::QName.new(NsC_1, "AuthentificationLogin"),
        :is_anonymous => true,
        :schema_qualified => true,
        :schema_element => [
            ["userName", ["CrvApiClient::Api::Reproduction::TextType", XSD::QName.new(NsC_1, "UserName")]],
            ["password", ["CrvApiClient::Api::Reproduction::TextType", XSD::QName.new(NsC_1, "Password")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ZipMessageType,
        :schema_type => XSD::QName.new(NsC_1, "ZipMessageType"),
        :schema_element => [
            ["zIPMessage", ["CrvApiClient::Api::Reproduction::BinaryObjectType", XSD::QName.new(NsC_1, "ZIPMessage")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::TicketResponseType,
        :schema_type => XSD::QName.new(NsC_1, "TicketResponseType"),
        :schema_element => [
            ["ticketID", ["CrvApiClient::Api::Reproduction::IDType", XSD::QName.new(NsC_1, "TicketID")]],
            ["notBefore", [nil, XSD::QName.new(NsC_1, "NotBefore")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::TicketRequestType,
        :schema_type => XSD::QName.new(NsC_1, "TicketRequestType"),
        :schema_element => [
            ["ticketID", ["CrvApiClient::Api::Reproduction::IDType", XSD::QName.new(NsC_1, "TicketID")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::HerdListRequestType,
        :schema_type => XSD::QName.new(NsC_1, "HerdListRequestType"),
        :schema_element => [
            ["gender", ["CrvApiClient::Api::Reproduction::GenderCodeType", XSD::QName.new(NsC_1, "Gender")], [0, 1]],
            ["periode", ["CrvApiClient::Api::Reproduction::MeasureType", XSD::QName.new(NsC_1, "Periode")], [0, 1]],
            ["location", ["CrvApiClient::Api::Reproduction::IDType", XSD::QName.new(NsC_1, "Location")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalListMessageType,
        :schema_type => XSD::QName.new(NsC_1, "AnimalListMessageType"),
        :schema_element => [
            ["animalDetail", ["CrvApiClient::Api::Reproduction::AnimalListMessageType::AnimalDetail[]", XSD::QName.new(NsC_1, "AnimalDetail")], [1, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalListMessageType::AnimalDetail,
        :schema_name => XSD::QName.new(NsC_1, "AnimalDetail"),
        :is_anonymous => true,
        :schema_qualified => true,
        :schema_element => [
            ["animalCoreDataSet", ["CrvApiClient::Api::Reproduction::AnimalCoreDataSetType", XSD::QName.new(NsC_1, "AnimalCoreDataSet")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::DeviceListMessageType,
        :schema_type => XSD::QName.new(NsC_1, "DeviceListMessageType"),
        :schema_element => [
            ["device", ["CrvApiClient::Api::Reproduction::DeviceType[]", XSD::QName.new(NsC_1, "Device")], [1, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::DeviceType,
        :schema_type => XSD::QName.new(NsC_1, "DeviceType"),
        :schema_element => [
            ["identifier", ["CrvApiClient::Api::Reproduction::IDType", XSD::QName.new(NsC_1, "Identifier")]],
            ["manufacturer", ["CrvApiClient::Api::Reproduction::ManufacturerCodeType", XSD::QName.new(NsC_1, "Manufacturer")], [0, 1]],
            ["softwareVersion", ["CrvApiClient::Api::Reproduction::TextType", XSD::QName.new(NsC_1, "SoftwareVersion")], [0, 1]],
            ["hardwareVersion", ["CrvApiClient::Api::Reproduction::TextType", XSD::QName.new(NsC_1, "HardwareVersion")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalCoreDataSetType,
        :schema_type => XSD::QName.new(NsC_1, "AnimalCoreDataSetType"),
        :schema_element => [
            ["identifier", ["CrvApiClient::Api::Reproduction::IDType", XSD::QName.new(NsC_1, "Identifier")]],
            ["alternativeIdentity", ["CrvApiClient::Api::Reproduction::AnimalIdentityType[]", XSD::QName.new(NsC_1, "AlternativeIdentity")], [0, nil]],
            ["specie", ["CrvApiClient::Api::Reproduction::SpecieCodeType", XSD::QName.new(NsC_1, "Specie")], [0, 1]],
            ["gender", ["CrvApiClient::Api::Reproduction::GenderCodeType", XSD::QName.new(NsC_1, "Gender")], [0, 1]],
            ["birth", [nil, XSD::QName.new(NsC_1, "Birth")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalExtendedDataSetType,
        :schema_type => XSD::QName.new(NsC_1, "AnimalExtendedDataSetType"),
        :schema_element => [
            ["lastLocalization", [nil, XSD::QName.new(NsC_1, "LastLocalization")], [0, 1]],
            ["lastParturition", [nil, XSD::QName.new(NsC_1, "LastParturition")], [0, 1]],
            ["lastInsemination", [nil, XSD::QName.new(NsC_1, "LastInsemination")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalIdentityType,
        :schema_type => XSD::QName.new(NsC_1, "AnimalIdentityType"),
        :schema_element => [
            ["identifier", ["CrvApiClient::Api::Reproduction::IDType", XSD::QName.new(NsC_1, "Identifier")]],
            ["label", ["CrvApiClient::Api::Reproduction::LabelCodeType", XSD::QName.new(NsC_1, "Label")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalMilkingResultType,
        :schema_type => XSD::QName.new(NsC_1, "AnimalMilkingResultType"),
        :schema_element => [
            ["animalIdentity", ["CrvApiClient::Api::Reproduction::AnimalIdentityType", XSD::QName.new(NsC_1, "AnimalIdentity")]],
            ["location", ["CrvApiClient::Api::Reproduction::IDType", XSD::QName.new(NsC_1, "Location")]],
            ["milkingStartingTime", [nil, XSD::QName.new(NsC_1, "MilkingStartingTime")]],
            ["milkingDuration", ["CrvApiClient::Api::Reproduction::MeasureType", XSD::QName.new(NsC_1, "MilkingDuration")], [0, 1]],
            ["milkingVisitDuration", ["CrvApiClient::Api::Reproduction::MeasureType", XSD::QName.new(NsC_1, "MilkingVisitDuration")], [0, 1]],
            ["milkingType", ["CrvApiClient::Api::Reproduction::MilkingTypeCodeType", XSD::QName.new(NsC_1, "MilkingType")], [0, 1]],
            ["milkingMilkWeight", ["CrvApiClient::Api::Reproduction::MeasureType", XSD::QName.new(NsC_1, "MilkingMilkWeight")], [0, 1]],
            ["milkingSucces", [nil, XSD::QName.new(NsC_1, "MilkingSucces")]],
            ["milkingParlourUnit", ["CrvApiClient::Api::Reproduction::TextType", XSD::QName.new(NsC_1, "MilkingParlourUnit")], [0, 1]],
            ["milkingBoxNumber", ["CrvApiClient::Api::Reproduction::TextType", XSD::QName.new(NsC_1, "MilkingBoxNumber")], [0, 1]],
            ["characteristics", ["CrvApiClient::Api::Reproduction::MilkCharacteristicsType[]", XSD::QName.new(NsC_1, "Characteristics")], [0, nil]],
            ["quarterMilking", ["CrvApiClient::Api::Reproduction::QuarterMilkingType[]", XSD::QName.new(NsC_1, "QuarterMilking")], [0, 4]],
            ["animalMilkingSample", ["CrvApiClient::Api::Reproduction::AnimalMilkingSampleType", XSD::QName.new(NsC_1, "AnimalMilkingSample")], [0, 1]],
            ["milkingDeviceID", ["CrvApiClient::Api::Reproduction::IDType", XSD::QName.new(NsC_1, "MilkingDeviceID")], [0, 1]],
            ["measureDeviceID", ["CrvApiClient::Api::Reproduction::IDType", XSD::QName.new(NsC_1, "MeasureDeviceID")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalMilkingSampleType,
        :schema_type => XSD::QName.new(NsC_1, "AnimalMilkingSampleType"),
        :schema_element => [
            ["bottleIdentifierType", ["CrvApiClient::Api::Reproduction::BottleIdentifierCodeType", XSD::QName.new(NsC_1, "BottleIdentifierType")], [0, 1]],
            ["rackNumber", ["CrvApiClient::Api::Reproduction::IDType", XSD::QName.new(NsC_1, "RackNumber")]],
            ["bottlePosition", ["CrvApiClient::Api::Reproduction::IDType", XSD::QName.new(NsC_1, "BottlePosition")], [0, 1]],
            ["bottleIdentifier", ["CrvApiClient::Api::Reproduction::IDType", XSD::QName.new(NsC_1, "BottleIdentifier")], [0, 1]],
            ["validSampleFillingIndicator", ["CrvApiClient::Api::Reproduction::ValidSampleFillingIndicatorCodeType", XSD::QName.new(NsC_1, "ValidSampleFillingIndicator")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ErrorType,
        :schema_type => XSD::QName.new(NsC_1, "ErrorType"),
        :schema_element => [
            ["errorID", ["CrvApiClient::Api::Reproduction::TextType", XSD::QName.new(NsC_1, "ErrorID")]],
            ["errorSeverity", ["CrvApiClient::Api::Reproduction::ErrorSeverityCodeType", XSD::QName.new(NsC_1, "ErrorSeverity")], [0, 1]],
            ["errorDescription", ["CrvApiClient::Api::Reproduction::TextType", XSD::QName.new(NsC_1, "ErrorDescription")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::HerdListMessageType,
        :schema_type => XSD::QName.new(NsC_1, "HerdListMessageType"),
        :schema_element => [
            ["location", ["CrvApiClient::Api::Reproduction::LivestockLocationType", XSD::QName.new(NsC_1, "Location")]],
            ["herdListAnimalDescription", ["CrvApiClient::Api::Reproduction::HerdListLineType[]", XSD::QName.new(NsC_1, "HerdListAnimalDescription")], [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::LivestockLocationType,
        :schema_type => XSD::QName.new(NsC_1, "LivestockLocationType"),
        :schema_element => [
            ["identifier", ["CrvApiClient::Api::Reproduction::IDType", XSD::QName.new(NsC_1, "Identifier")]],
            ["identifierType", ["CrvApiClient::Api::Reproduction::LivestockLocationIdentifierCodeType", XSD::QName.new(NsC_1, "IdentifierType")]],
            ["name", ["CrvApiClient::Api::Reproduction::NameType", XSD::QName.new(NsC_1, "Name")]],
            ["country", ["CrvApiClient::Api::Reproduction::ISOTwoletterCountryCodeIdentifierContentType", XSD::QName.new(NsC_1, "Country")]],
            ["type", ["CrvApiClient::Api::Reproduction::LivestockLocationTypeCodeType", XSD::QName.new(NsC_1, "Type")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::MilkingLocationType,
        :schema_type => XSD::QName.new(NsC_1, "MilkingLocationType"),
        :schema_element => [
            ["identification", ["CrvApiClient::Api::Reproduction::IDType", XSD::QName.new(NsC_1, "Identification")]],
            ["name", ["CrvApiClient::Api::Reproduction::NameType", XSD::QName.new(NsC_1, "Name")]],
            ["country", ["CrvApiClient::Api::Reproduction::ISOTwoletterCountryCodeIdentifierContentType", XSD::QName.new(NsC_1, "Country")]],
            ["type", ["CrvApiClient::Api::Reproduction::CodeType", XSD::QName.new(NsC_1, "Type")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::MilkingResultType,
        :schema_type => XSD::QName.new(NsC_1, "MilkingResultType"),
        :schema_element => [
            ["animalMilkingResult", ["CrvApiClient::Api::Reproduction::AnimalMilkingResultType[]", XSD::QName.new(NsC_1, "AnimalMilkingResult")], [1, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::HerdListLineType,
        :schema_type => XSD::QName.new(NsC_1, "HerdListLineType"),
        :schema_element => [
            ["animalCoreDataSet", ["CrvApiClient::Api::Reproduction::AnimalCoreDataSetType", XSD::QName.new(NsC_1, "AnimalCoreDataSet")]],
            ["animalExtendedDataSet", ["CrvApiClient::Api::Reproduction::AnimalExtendedDataSetType", XSD::QName.new(NsC_1, "AnimalExtendedDataSet")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::MilkCharacteristicsType,
        :schema_type => XSD::QName.new(NsC_1, "MilkCharacteristicsType"),
        :schema_element => [
            ["milkCharacteristicCode", ["CrvApiClient::Api::Reproduction::MilkCharacteristicCodeType", XSD::QName.new(NsC_1, "MilkCharacteristicCode")]],
            ["milkCharacteristicValue", ["CrvApiClient::Api::Reproduction::MeasureType", XSD::QName.new(NsC_1, "MilkCharacteristicValue")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::QuarterMilkingType,
        :schema_type => XSD::QName.new(NsC_1, "QuarterMilkingType"),
        :schema_element => [
            ["quarterID", ["CrvApiClient::Api::Reproduction::QuarterCodeType", XSD::QName.new(NsC_1, "QuarterID")]],
            ["quarterMilkingDuration", ["CrvApiClient::Api::Reproduction::MeasureType", XSD::QName.new(NsC_1, "QuarterMilkingDuration")], [0, 1]],
            ["quarterMilkingWeight", ["CrvApiClient::Api::Reproduction::MeasureType", XSD::QName.new(NsC_1, "QuarterMilkingWeight")], [0, 1]],
            ["quarterCharacteristics", ["CrvApiClient::Api::Reproduction::MilkCharacteristicsType[]", XSD::QName.new(NsC_1, "QuarterCharacteristics")], [0, nil]],
            ["quarterSampling", ["CrvApiClient::Api::Reproduction::AnimalMilkingSampleType", XSD::QName.new(NsC_1, "QuarterSampling")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::SpecificResponseType,
        :schema_type => XSD::QName.new(NsC_1, "SpecificResponseType"),
        :schema_element => [
            ["requestProcessingTicket", ["CrvApiClient::Api::Reproduction::TicketResponseType", XSD::QName.new(NsC_1, "RequestProcessingTicket")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::StandardResponseType,
        :schema_type => XSD::QName.new(NsC_1, "StandardResponseType"),
        :schema_element => [
            ["requestProcessingStatus", ["CrvApiClient::Api::Reproduction::RequestProcessingStatusCodeType", XSD::QName.new(NsC_1, "RequestProcessingStatus")]],
            ["requestID", ["CrvApiClient::Api::Reproduction::IDType", XSD::QName.new(NsC_1, "RequestID")]],
            ["requestProcessingError", ["CrvApiClient::Api::Reproduction::ErrorType[]", XSD::QName.new(NsC_1, "RequestProcessingError")], [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AmountType,
        :schema_type => XSD::QName.new(NsC_13, "AmountType"),
        :schema_attribute => {
            XSD::QName.new(nil, "currencyID") => "SOAP::SOAPToken"
        }
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::BinaryObjectType,
        :schema_type => XSD::QName.new(NsC_13, "BinaryObjectType"),
        :schema_attribute => {
            XSD::QName.new(nil, "format") => "SOAP::SOAPString",
            XSD::QName.new(nil, "mimeCode") => "SOAP::SOAPToken",
            XSD::QName.new(nil, "encodingCode") => "SOAP::SOAPToken",
            XSD::QName.new(nil, "characterSetCode") => "SOAP::SOAPToken",
            XSD::QName.new(nil, "uri") => "SOAP::SOAPAnyURI",
            XSD::QName.new(nil, "filename") => "SOAP::SOAPString"
        }
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::GraphicType,
        :schema_type => XSD::QName.new(NsC_13, "GraphicType"),
        :schema_attribute => {
            XSD::QName.new(nil, "format") => "SOAP::SOAPString",
            XSD::QName.new(nil, "mimeCode") => "SOAP::SOAPToken",
            XSD::QName.new(nil, "encodingCode") => "SOAP::SOAPToken",
            XSD::QName.new(nil, "uri") => "SOAP::SOAPAnyURI",
            XSD::QName.new(nil, "filename") => "SOAP::SOAPString"
        }
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::PictureType,
        :schema_type => XSD::QName.new(NsC_13, "PictureType"),
        :schema_attribute => {
            XSD::QName.new(nil, "format") => "SOAP::SOAPString",
            XSD::QName.new(nil, "mimeCode") => "SOAP::SOAPToken",
            XSD::QName.new(nil, "encodingCode") => "SOAP::SOAPToken",
            XSD::QName.new(nil, "uri") => "SOAP::SOAPAnyURI",
            XSD::QName.new(nil, "filename") => "SOAP::SOAPString"
        }
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::SoundType,
        :schema_type => XSD::QName.new(NsC_13, "SoundType"),
        :schema_attribute => {
            XSD::QName.new(nil, "format") => "SOAP::SOAPString",
            XSD::QName.new(nil, "mimeCode") => "SOAP::SOAPToken",
            XSD::QName.new(nil, "encodingCode") => "SOAP::SOAPToken",
            XSD::QName.new(nil, "uri") => "SOAP::SOAPAnyURI",
            XSD::QName.new(nil, "filename") => "SOAP::SOAPString"
        }
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::VideoType,
        :schema_type => XSD::QName.new(NsC_13, "VideoType"),
        :schema_attribute => {
            XSD::QName.new(nil, "format") => "SOAP::SOAPString",
            XSD::QName.new(nil, "mimeCode") => "SOAP::SOAPToken",
            XSD::QName.new(nil, "encodingCode") => "SOAP::SOAPToken",
            XSD::QName.new(nil, "uri") => "SOAP::SOAPAnyURI",
            XSD::QName.new(nil, "filename") => "SOAP::SOAPString"
        }
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::CodeType,
        :schema_type => XSD::QName.new(NsC_13, "CodeType"),
        :schema_attribute => {
            XSD::QName.new(nil, "listID") => "SOAP::SOAPToken",
            XSD::QName.new(nil, "listAgencyID") => "SOAP::SOAPToken",
            XSD::QName.new(nil, "listAgencyName") => "SOAP::SOAPString",
            XSD::QName.new(nil, "listName") => "SOAP::SOAPString",
            XSD::QName.new(nil, "listVersionID") => "SOAP::SOAPToken",
            XSD::QName.new(nil, "name") => "SOAP::SOAPString",
            XSD::QName.new(nil, "languageID") => "SOAP::SOAPLanguage",
            XSD::QName.new(nil, "listURI") => "SOAP::SOAPAnyURI",
            XSD::QName.new(nil, "listSchemeURI") => "SOAP::SOAPAnyURI"
        }
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::IDType,
        :schema_type => XSD::QName.new(NsC_13, "IDType"),
        :schema_attribute => {
            XSD::QName.new(nil, "schemeID") => "SOAP::SOAPToken",
            XSD::QName.new(nil, "schemeName") => "SOAP::SOAPString",
            XSD::QName.new(nil, "schemeAgencyID") => "SOAP::SOAPToken",
            XSD::QName.new(nil, "schemeAgencyName") => "SOAP::SOAPString",
            XSD::QName.new(nil, "schemeVersionID") => "SOAP::SOAPToken",
            XSD::QName.new(nil, "schemeDataURI") => "SOAP::SOAPAnyURI",
            XSD::QName.new(nil, "schemeURI") => "SOAP::SOAPAnyURI"
        }
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::MeasureType,
        :schema_type => XSD::QName.new(NsC_13, "MeasureType"),
        :schema_attribute => {
            XSD::QName.new(nil, "unitCode") => "SOAP::SOAPToken"
        }
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::QuantityType,
        :schema_type => XSD::QName.new(NsC_13, "QuantityType"),
        :schema_attribute => {
            XSD::QName.new(nil, "unitCode") => "SOAP::SOAPToken"
        }
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::TextType,
        :schema_type => XSD::QName.new(NsC_13, "TextType"),
        :schema_attribute => {
            XSD::QName.new(nil, "languageID") => "SOAP::SOAPLanguage"
        }
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::NameType,
        :schema_type => XSD::QName.new(NsC_13, "NameType"),
        :schema_attribute => {
            XSD::QName.new(nil, "languageID") => "SOAP::SOAPLanguage"
        }
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::BooleanType,
        :schema_type => XSD::QName.new(NsCommonTypes, "booleanType")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::NotificationType,
        :schema_type => XSD::QName.new(NsCommonTypes, "notificationType")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::RepresentationType,
        :schema_type => XSD::QName.new(NsDictionaryTypes, "representationType")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::CountryCode,
        :schema_type => XSD::QName.new(NsAnimalTypes, "countryCode")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::KeeperType,
        :schema_type => XSD::QName.new(NsAnimalTypes, "keeperType")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::Sex,
        :schema_type => XSD::QName.new(NsAnimalTypes, "sex")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::MIMEMediaTypeContentType,
        :schema_type => XSD::QName.new(NsC_20130103, "MIMEMediaTypeContentType")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::MeasurementUnitCommonCodeContentType,
        :schema_type => XSD::QName.new(NsC_8, "MeasurementUnitCommonCodeContentType")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::CharacterSetCodeContentType,
        :schema_type => XSD::QName.new(NsC_20130108, "CharacterSetCodeContentType")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ISO3AlphaCurrencyCodeContentType,
        :schema_type => XSD::QName.new(NsC_20120831, "ISO3AlphaCurrencyCodeContentType")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::CharacterSetEncodingCodeContentType,
        :schema_type => XSD::QName.new(NsC_40106, "CharacterSetEncodingCodeContentType")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AgencyIdentificationCodeContentType,
        :schema_type => XSD::QName.new(NsD12A, "AgencyIdentificationCodeContentType")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ISOTwoletterCountryCodeIdentifierContentType,
        :schema_type => XSD::QName.new(NsSecondEdition2006VI13, "ISOTwoletterCountryCodeIdentifierContentType")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::GenderCodeType,
        :schema_type => XSD::QName.new(NsC_10, "GenderCodeType")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::LivestockLocationIdentifierCodeType,
        :schema_type => XSD::QName.new(NsC_10_0, "LivestockLocationIdentifierCodeType")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::LivestockLocationTypeCodeType,
        :schema_type => XSD::QName.new(NsC_10_1, "LivestockLocationTypeCodeType")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::MilkingTypeCodeType,
        :schema_type => XSD::QName.new(NsC_10_2, "MilkingTypeCodeType")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::LabelCodeType,
        :schema_type => XSD::QName.new(NsC_10_3, "LabelCodeType")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ValidSampleFillingIndicatorCodeType,
        :schema_type => XSD::QName.new(NsC_10_4, "ValidSampleFillingIndicatorCodeType")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::BottleIdentifierCodeType,
        :schema_type => XSD::QName.new(NsC_10_5, "BottleIdentifierCodeType")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::RequestProcessingStatusCodeType,
        :schema_type => XSD::QName.new(NsC_10_6, "RequestProcessingStatusCodeType")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ErrorSeverityCodeType,
        :schema_type => XSD::QName.new(NsC_10_7, "ErrorSeverityCodeType")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::SpecieCodeType,
        :schema_type => XSD::QName.new(NsC_10_8, "SpecieCodeType")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::MilkCharacteristicCodeType,
        :schema_type => XSD::QName.new(NsC_10_9, "MilkCharacteristicCodeType")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::QuarterCodeType,
        :schema_type => XSD::QName.new(NsC_10_10, "QuarterCodeType")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ManufacturerCodeType,
        :schema_type => XSD::QName.new(NsC_10_11, "ManufacturerCodeType")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ListTopGestationCalvingRequest,
        :schema_name => XSD::QName.new(NsReproductionMessages, "listTopGestationCalvingRequest"),
        :schema_element => [
            ["contextMessage", "CrvApiClient::Api::Reproduction::ContextMessage"],
            ["requestMessage", "CrvApiClient::Api::Reproduction::ListTopGestationCalvingRequestType"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ListTopGestationCalvingResponse,
        :schema_name => XSD::QName.new(NsReproductionMessages, "listTopGestationCalvingResponse"),
        :schema_element => [
            ["responseMessage", "CrvApiClient::Api::Reproduction::ListTopGestationCalvingResponseType", [0, 1]],
            ["serviceMessage", "CrvApiClient::Api::Reproduction::ServiceMessage"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ListFertilizationRequest,
        :schema_name => XSD::QName.new(NsReproductionMessages, "listFertilizationRequest"),
        :schema_element => [
            ["contextMessage", "CrvApiClient::Api::Reproduction::ContextMessage"],
            ["requestMessage", "CrvApiClient::Api::Reproduction::ListFertilizationRequestType"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ListFertilizationResponse,
        :schema_name => XSD::QName.new(NsReproductionMessages, "listFertilizationResponse"),
        :schema_element => [
            ["responseMessage", "CrvApiClient::Api::Reproduction::ListFertilizationResponseType", [0, 1]],
            ["serviceMessage", "CrvApiClient::Api::Reproduction::ServiceMessage"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ListAnimalReproductionRequest,
        :schema_name => XSD::QName.new(NsReproductionMessages, "listAnimalReproductionRequest"),
        :schema_element => [
            ["contextMessage", "CrvApiClient::Api::Reproduction::ContextMessage"],
            ["requestMessage", "CrvApiClient::Api::Reproduction::ListAnimalReproductionRequestType"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ListAnimalReproductionResponse,
        :schema_name => XSD::QName.new(NsReproductionMessages, "listAnimalReproductionResponse"),
        :schema_element => [
            ["responseMessage", "CrvApiClient::Api::Reproduction::ListAnimalReproductionResponseType", [0, 1]],
            ["serviceMessage", "CrvApiClient::Api::Reproduction::ServiceMessage"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AddAnimalReproductionIndicationRequest,
        :schema_name => XSD::QName.new(NsReproductionMessages, "addAnimalReproductionIndicationRequest"),
        :schema_element => [
            ["contextMessage", "CrvApiClient::Api::Reproduction::ContextMessage"],
            ["requestMessage", "CrvApiClient::Api::Reproduction::AddAnimalReproductionIndicationRequestType"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AddAnimalReproductionIndicationResponse,
        :schema_name => XSD::QName.new(NsReproductionMessages, "addAnimalReproductionIndicationResponse"),
        :schema_element => [
            ["responseMessage", "SOAP::SOAPString", [0, 1]],
            ["serviceMessage", "CrvApiClient::Api::Reproduction::ServiceMessage"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AddAiEtDeliveryRequest,
        :schema_name => XSD::QName.new(NsReproductionMessages, "addAiEtDeliveryRequest"),
        :schema_element => [
            ["contextMessage", "CrvApiClient::Api::Reproduction::ContextMessage"],
            ["requestMessage", "CrvApiClient::Api::Reproduction::AddAiEtDeliveryRequestType"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AddAiEtDeliveryResponse,
        :schema_name => XSD::QName.new(NsReproductionMessages, "addAiEtDeliveryResponse"),
        :schema_element => [
            ["responseMessage", "SOAP::SOAPString", [0, 1]],
            ["serviceMessage", "CrvApiClient::Api::Reproduction::ServiceMessage"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AddPreferredBullRequest,
        :schema_name => XSD::QName.new(NsReproductionMessages, "addPreferredBullRequest"),
        :schema_element => [
            ["contextMessage", "CrvApiClient::Api::Reproduction::ContextMessage"],
            ["requestMessage", "CrvApiClient::Api::Reproduction::AddPreferredBullRequestType"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AddPreferredBullResponse,
        :schema_name => XSD::QName.new(NsReproductionMessages, "addPreferredBullResponse"),
        :schema_element => [
            ["responseMessage", "SOAP::SOAPString", [0, 1]],
            ["serviceMessage", "CrvApiClient::Api::Reproduction::ServiceMessage"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::DeletePreferredBullRequest,
        :schema_name => XSD::QName.new(NsReproductionMessages, "deletePreferredBullRequest"),
        :schema_element => [
            ["contextMessage", "CrvApiClient::Api::Reproduction::ContextMessage"],
            ["requestMessage", "CrvApiClient::Api::Reproduction::DeletePreferredBullRequestType"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::DeletePreferredBullResponse,
        :schema_name => XSD::QName.new(NsReproductionMessages, "deletePreferredBullResponse"),
        :schema_element => [
            ["responseMessage", "SOAP::SOAPString", [0, 1]],
            ["serviceMessage", "CrvApiClient::Api::Reproduction::ServiceMessage"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ListPreferredBullRequest,
        :schema_name => XSD::QName.new(NsReproductionMessages, "listPreferredBullRequest"),
        :schema_element => [
            ["contextMessage", "CrvApiClient::Api::Reproduction::ContextMessage"],
            ["requestMessage", "CrvApiClient::Api::Reproduction::ListPreferredBullRequestType", [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ListPreferredBullResponse,
        :schema_name => XSD::QName.new(NsReproductionMessages, "listPreferredBullResponse"),
        :schema_element => [
            ["responseMessage", "CrvApiClient::Api::Reproduction::ListPreferredBullResponseType", [0, 1]],
            ["serviceMessage", "CrvApiClient::Api::Reproduction::ServiceMessage"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ListReproductionLastParityRequest,
        :schema_name => XSD::QName.new(NsReproductionMessages, "listReproductionLastParityRequest"),
        :schema_element => [
            ["contextMessage", "CrvApiClient::Api::Reproduction::ContextMessage"],
            ["requestMessage", "CrvApiClient::Api::Reproduction::ListReproductionLastParityRequestType", [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ListReproductionLastParityResponse,
        :schema_name => XSD::QName.new(NsReproductionMessages, "listReproductionLastParityResponse"),
        :schema_element => [
            ["responseMessage", "CrvApiClient::Api::Reproduction::ListReproductionLastParityResponseType", [0, 1]],
            ["serviceMessage", "CrvApiClient::Api::Reproduction::ServiceMessage"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ListAnimalIndicationRequest,
        :schema_name => XSD::QName.new(NsReproductionMessages, "listAnimalIndicationRequest"),
        :schema_element => [
            ["contextMessage", "CrvApiClient::Api::Reproduction::ContextMessage"],
            ["requestMessage", "CrvApiClient::Api::Reproduction::ListAnimalIndicationRequestType", [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ListAnimalIndicationResponse,
        :schema_name => XSD::QName.new(NsReproductionMessages, "listAnimalIndicationResponse"),
        :schema_element => [
            ["responseMessage", "CrvApiClient::Api::Reproduction::ListAnimalIndicationResponseType", [0, 1]],
            ["serviceMessage", "CrvApiClient::Api::Reproduction::ServiceMessage"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ModifyAnimalIndicationRequest,
        :schema_name => XSD::QName.new(NsReproductionMessages, "modifyAnimalIndicationRequest"),
        :schema_element => [
            ["contextMessage", "CrvApiClient::Api::Reproduction::ContextMessage"],
            ["requestMessage", "CrvApiClient::Api::Reproduction::ModifyAnimalIndicationRequestType", [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ModifyAnimalIndicationResponse,
        :schema_name => XSD::QName.new(NsReproductionMessages, "modifyAnimalIndicationResponse"),
        :schema_element => [
            ["responseMessage", "SOAP::SOAPString", [0, 1]],
            ["serviceMessage", "CrvApiClient::Api::Reproduction::ServiceMessage"]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ServiceMessage,
        :schema_name => XSD::QName.new(NsCommonTypes, "serviceMessage"),
        :schema_element => [
            ["serviceStatus", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "serviceStatus")]],
            ["messageCode", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "messageCode")], [0, 1]],
            ["messageText", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "messageText")], [0, 1]],
            ["messageType", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "messageType")], [0, 1]],
            ["sourceType", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "sourceType")], [0, 1]],
            ["sourceCode", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "sourceCode")], [0, 1]],
            ["serviceMessageDetail", "CrvApiClient::Api::Reproduction::ServiceMessageDetail[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ServiceMessageDetail,
        :schema_name => XSD::QName.new(NsCommonTypes, "serviceMessageDetail"),
        :schema_element => [
            ["serviceStatus", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "serviceStatus")], [0, 1]],
            ["codeDetail", "CrvApiClient::Api::Reproduction::CodeDetail[]", [0, nil]],
            ["messageCode", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "messageCode")], [0, 1]],
            ["messageText", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "messageText")], [0, 1]],
            ["messageType", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "messageType")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ContextMessage,
        :schema_name => XSD::QName.new(NsCommonTypes, "contextMessage"),
        :schema_element => [
            ["sessionId", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "sessionId")], [0, 1]],
            ["processId", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "processId")], [0, 1]],
            ["instanceId", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "instanceId")], [0, 1]],
            ["username", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "username")], [0, 1]],
            ["userType", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "userType")], [0, 1]],
            ["password", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "password")], [0, 1]],
            ["organisation", "CrvApiClient::Api::Reproduction::ParticipantId", [0, 1]],
            ["provider", "CrvApiClient::Api::Reproduction::ParticipantId", [0, 1]],
            ["customer", "CrvApiClient::Api::Reproduction::ParticipantId", [0, 1]],
            ["keeper", "CrvApiClient::Api::Reproduction::ParticipantId", [0, 1]],
            ["animal", "CrvApiClient::Api::Reproduction::AnimalId", [0, 1]],
            ["processCode", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "processCode")], [0, 1]],
            ["messageSource", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "messageSource")], [0, 1]],
            ["languageCode", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "languageCode")], [0, 1]],
            ["timeZone", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "timeZone")], [0, 1]],
            ["contextMessageDetail", "CrvApiClient::Api::Reproduction::ContextMessageDetail[]", [0, nil]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ContextMessageDetail,
        :schema_name => XSD::QName.new(NsCommonTypes, "contextMessageDetail"),
        :schema_element => [
            ["contextCode", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "contextCode")], [0, 1]],
            ["contextValue", ["SOAP::SOAPString", XSD::QName.new(NsCommon, "contextValue")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::BooleanType,
        :schema_name => XSD::QName.new(NsCommon, "actual")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::NotificationType,
        :schema_name => XSD::QName.new(NsCommon, "notificationType")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::BooleanType,
        :schema_name => XSD::QName.new(NsDictionary, "actual")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::RepresentationType,
        :schema_name => XSD::QName.new(NsDictionary, "representationType")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::BooleanType,
        :schema_name => XSD::QName.new(NsAnimal, "IBR")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::BooleanType,
        :schema_name => XSD::QName.new(NsAnimal, "foodChainInfo")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::BooleanType,
        :schema_name => XSD::QName.new(NsAnimal, "foodChainInfoStandard")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::BooleanType,
        :schema_name => XSD::QName.new(NsAnimal, "generalTermsConditions")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::BooleanType,
        :schema_name => XSD::QName.new(NsBreeding, "agreement")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::BooleanType,
        :schema_name => XSD::QName.new(NsBreeding, "ibrFree")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::BooleanType,
        :schema_name => XSD::QName.new(NsBreeding, "requested")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AnimalOfferType,
        :schema_name => XSD::QName.new(NsBreedingTypes, "animalOfferType"),
        :schema_element => [
            ["animalOffer", "CrvApiClient::Api::Reproduction::AnimalOffer", [0, 1]],
            ["animalOfferStatus", "CrvApiClient::Api::Reproduction::AnimalOfferStatus", [0, 1]],
            ["animalOfferAnalysisRequest", "CrvApiClient::Api::Reproduction::AnimalOfferAnalysisRequest", [0, 1]],
            ["animalOfferAnalysis", "CrvApiClient::Api::Reproduction::AnimalOfferAnalysis", [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::GetHerdListRequestType,
        :schema_name => XSD::QName.new(NsC_1_0, "GetHerdListRequest"),
        :schema_element => [
            ["messageHeader", ["CrvApiClient::Api::Reproduction::ADEExchangedDocumentType", XSD::QName.new(NsC_1, "MessageHeader")]],
            ["standardRequest", ["CrvApiClient::Api::Reproduction::StandardRequestType", XSD::QName.new(NsC_1, "StandardRequest")]],
            ["specificRequestGetHerdList", ["CrvApiClient::Api::Reproduction::SpecificRequestGetHerdListType", XSD::QName.new(NsC_1, "SpecificRequestGetHerdList")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::GetHerdListResponseType,
        :schema_name => XSD::QName.new(NsC_1_0, "GetHerdListResponse"),
        :schema_element => [
            ["messageHeader", ["CrvApiClient::Api::Reproduction::ADEExchangedDocumentType", XSD::QName.new(NsC_1, "MessageHeader")]],
            ["standardResponse", ["CrvApiClient::Api::Reproduction::StandardResponseType", XSD::QName.new(NsC_1, "StandardResponse")]],
            ["specificResponseGetHerdList", ["CrvApiClient::Api::Reproduction::SpecificResponseGetHerdListType", XSD::QName.new(NsC_1, "SpecificResponseGetHerdList")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::UpdateAnimalRequestType,
        :schema_name => XSD::QName.new(NsC_1_0, "UpdateAnimalRequest"),
        :schema_element => [
            ["messageHeader", ["CrvApiClient::Api::Reproduction::ADEExchangedDocumentType", XSD::QName.new(NsC_1, "MessageHeader")]],
            ["standardRequest", ["CrvApiClient::Api::Reproduction::StandardRequestType", XSD::QName.new(NsC_1, "StandardRequest")]],
            ["specificRequestAnimal", ["CrvApiClient::Api::Reproduction::SpecificRequestAnimalType", XSD::QName.new(NsC_1, "SpecificRequestAnimal")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::UpdateAnimalResponseType,
        :schema_name => XSD::QName.new(NsC_1_0, "UpdateAnimalResponse"),
        :schema_element => [
            ["messageHeader", ["CrvApiClient::Api::Reproduction::ADEExchangedDocumentType", XSD::QName.new(NsC_1, "MessageHeader")]],
            ["standardResponse", ["CrvApiClient::Api::Reproduction::StandardResponseType", XSD::QName.new(NsC_1, "StandardResponse")]],
            ["specificResponse", ["CrvApiClient::Api::Reproduction::SpecificResponseType", XSD::QName.new(NsC_1, "SpecificResponse")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::UpdateDeviceRequestType,
        :schema_name => XSD::QName.new(NsC_1_0, "UpdateDeviceRequest"),
        :schema_element => [
            ["messageHeader", ["CrvApiClient::Api::Reproduction::ADEExchangedDocumentType", XSD::QName.new(NsC_1, "MessageHeader")]],
            ["standardRequest", ["CrvApiClient::Api::Reproduction::StandardRequestType", XSD::QName.new(NsC_1, "StandardRequest")]],
            ["specificRequestDevice", ["CrvApiClient::Api::Reproduction::SpecificRequestDeviceType", XSD::QName.new(NsC_1, "SpecificRequestDevice")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::UpdateDeviceResponseType,
        :schema_name => XSD::QName.new(NsC_1_0, "UpdateDeviceResponse"),
        :schema_element => [
            ["messageHeader", ["CrvApiClient::Api::Reproduction::ADEExchangedDocumentType", XSD::QName.new(NsC_1, "MessageHeader")]],
            ["standardResponse", ["CrvApiClient::Api::Reproduction::StandardResponseType", XSD::QName.new(NsC_1, "StandardResponse")]],
            ["specificResponse", ["CrvApiClient::Api::Reproduction::SpecificResponseType", XSD::QName.new(NsC_1, "SpecificResponse")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::UpdateLivestockLocationRequestType,
        :schema_name => XSD::QName.new(NsC_1_0, "UpdateLivestockLocationRequest"),
        :schema_element => [
            ["messageHeader", ["CrvApiClient::Api::Reproduction::ADEExchangedDocumentType", XSD::QName.new(NsC_1, "MessageHeader")]],
            ["standardRequest", ["CrvApiClient::Api::Reproduction::StandardRequestType", XSD::QName.new(NsC_1, "StandardRequest")]],
            ["specificRequestLivestockLocation", ["CrvApiClient::Api::Reproduction::SpecificRequestLivestockLocationType", XSD::QName.new(NsC_1, "SpecificRequestLivestockLocation")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::UpdateLivestockLocationResponseType,
        :schema_name => XSD::QName.new(NsC_1_0, "UpdateLivestockLocationResponse"),
        :schema_element => [
            ["messageHeader", ["CrvApiClient::Api::Reproduction::ADEExchangedDocumentType", XSD::QName.new(NsC_1, "MessageHeader")]],
            ["standardResponse", ["CrvApiClient::Api::Reproduction::StandardResponseType", XSD::QName.new(NsC_1, "StandardResponse")]],
            ["specificResponse", ["CrvApiClient::Api::Reproduction::SpecificResponseType", XSD::QName.new(NsC_1, "SpecificResponse")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::UpdateMilkingResultRequestType,
        :schema_name => XSD::QName.new(NsC_1_0, "UpdateMilkingResultsRequest"),
        :schema_element => [
            ["messageHeader", ["CrvApiClient::Api::Reproduction::ADEExchangedDocumentType", XSD::QName.new(NsC_1, "MessageHeader")]],
            ["standardRequest", ["CrvApiClient::Api::Reproduction::StandardRequestType", XSD::QName.new(NsC_1, "StandardRequest")]],
            ["specificRequestMilingResult", ["CrvApiClient::Api::Reproduction::SpecificRequestMilkingResultType", XSD::QName.new(NsC_1, "SpecificRequestMilingResult")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::UpdateMilkingResultResponseType,
        :schema_name => XSD::QName.new(NsC_1_0, "UpdateMilkingResultsResponse"),
        :schema_element => [
            ["messageHeader", ["CrvApiClient::Api::Reproduction::ADEExchangedDocumentType", XSD::QName.new(NsC_1, "MessageHeader")]],
            ["standardResponse", ["CrvApiClient::Api::Reproduction::StandardResponseType", XSD::QName.new(NsC_1, "StandardResponse")]],
            ["specificResponse", ["CrvApiClient::Api::Reproduction::SpecificResponseType", XSD::QName.new(NsC_1, "SpecificResponse")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::GetHerdListRequestType,
        :schema_name => XSD::QName.new(NsC_1, "GetHerdListRequest"),
        :schema_element => [
            ["messageHeader", ["CrvApiClient::Api::Reproduction::ADEExchangedDocumentType", XSD::QName.new(NsC_1, "MessageHeader")]],
            ["standardRequest", ["CrvApiClient::Api::Reproduction::StandardRequestType", XSD::QName.new(NsC_1, "StandardRequest")]],
            ["specificRequestGetHerdList", ["CrvApiClient::Api::Reproduction::SpecificRequestGetHerdListType", XSD::QName.new(NsC_1, "SpecificRequestGetHerdList")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::GetHerdListResponseType,
        :schema_name => XSD::QName.new(NsC_1, "GetHerdListResponse"),
        :schema_element => [
            ["messageHeader", ["CrvApiClient::Api::Reproduction::ADEExchangedDocumentType", XSD::QName.new(NsC_1, "MessageHeader")]],
            ["standardResponse", ["CrvApiClient::Api::Reproduction::StandardResponseType", XSD::QName.new(NsC_1, "StandardResponse")]],
            ["specificResponseGetHerdList", ["CrvApiClient::Api::Reproduction::SpecificResponseGetHerdListType", XSD::QName.new(NsC_1, "SpecificResponseGetHerdList")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::UpdateAnimalRequestType,
        :schema_name => XSD::QName.new(NsC_1, "UpdateAnimalRequest"),
        :schema_element => [
            ["messageHeader", ["CrvApiClient::Api::Reproduction::ADEExchangedDocumentType", XSD::QName.new(NsC_1, "MessageHeader")]],
            ["standardRequest", ["CrvApiClient::Api::Reproduction::StandardRequestType", XSD::QName.new(NsC_1, "StandardRequest")]],
            ["specificRequestAnimal", ["CrvApiClient::Api::Reproduction::SpecificRequestAnimalType", XSD::QName.new(NsC_1, "SpecificRequestAnimal")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::UpdateAnimalResponseType,
        :schema_name => XSD::QName.new(NsC_1, "UpdateAnimalResponse"),
        :schema_element => [
            ["messageHeader", ["CrvApiClient::Api::Reproduction::ADEExchangedDocumentType", XSD::QName.new(NsC_1, "MessageHeader")]],
            ["standardResponse", ["CrvApiClient::Api::Reproduction::StandardResponseType", XSD::QName.new(NsC_1, "StandardResponse")]],
            ["specificResponse", ["CrvApiClient::Api::Reproduction::SpecificResponseType", XSD::QName.new(NsC_1, "SpecificResponse")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::UpdateDeviceRequestType,
        :schema_name => XSD::QName.new(NsC_1, "UpdateDeviceRequest"),
        :schema_element => [
            ["messageHeader", ["CrvApiClient::Api::Reproduction::ADEExchangedDocumentType", XSD::QName.new(NsC_1, "MessageHeader")]],
            ["standardRequest", ["CrvApiClient::Api::Reproduction::StandardRequestType", XSD::QName.new(NsC_1, "StandardRequest")]],
            ["specificRequestDevice", ["CrvApiClient::Api::Reproduction::SpecificRequestDeviceType", XSD::QName.new(NsC_1, "SpecificRequestDevice")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::UpdateDeviceResponseType,
        :schema_name => XSD::QName.new(NsC_1, "UpdateDeviceResponse"),
        :schema_element => [
            ["messageHeader", ["CrvApiClient::Api::Reproduction::ADEExchangedDocumentType", XSD::QName.new(NsC_1, "MessageHeader")]],
            ["standardResponse", ["CrvApiClient::Api::Reproduction::StandardResponseType", XSD::QName.new(NsC_1, "StandardResponse")]],
            ["specificResponse", ["CrvApiClient::Api::Reproduction::SpecificResponseType", XSD::QName.new(NsC_1, "SpecificResponse")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::UpdateLivestockLocationRequestType,
        :schema_name => XSD::QName.new(NsC_1, "UpdateLivestockLocationRequest"),
        :schema_element => [
            ["messageHeader", ["CrvApiClient::Api::Reproduction::ADEExchangedDocumentType", XSD::QName.new(NsC_1, "MessageHeader")]],
            ["standardRequest", ["CrvApiClient::Api::Reproduction::StandardRequestType", XSD::QName.new(NsC_1, "StandardRequest")]],
            ["specificRequestLivestockLocation", ["CrvApiClient::Api::Reproduction::SpecificRequestLivestockLocationType", XSD::QName.new(NsC_1, "SpecificRequestLivestockLocation")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::UpdateLivestockLocationResponseType,
        :schema_name => XSD::QName.new(NsC_1, "UpdateLivestockLocationResponse"),
        :schema_element => [
            ["messageHeader", ["CrvApiClient::Api::Reproduction::ADEExchangedDocumentType", XSD::QName.new(NsC_1, "MessageHeader")]],
            ["standardResponse", ["CrvApiClient::Api::Reproduction::StandardResponseType", XSD::QName.new(NsC_1, "StandardResponse")]],
            ["specificResponse", ["CrvApiClient::Api::Reproduction::SpecificResponseType", XSD::QName.new(NsC_1, "SpecificResponse")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::UpdateMilkingResultRequestType,
        :schema_name => XSD::QName.new(NsC_1, "UpdateMilkingResultRequest"),
        :schema_element => [
            ["messageHeader", ["CrvApiClient::Api::Reproduction::ADEExchangedDocumentType", XSD::QName.new(NsC_1, "MessageHeader")]],
            ["standardRequest", ["CrvApiClient::Api::Reproduction::StandardRequestType", XSD::QName.new(NsC_1, "StandardRequest")]],
            ["specificRequestMilingResult", ["CrvApiClient::Api::Reproduction::SpecificRequestMilkingResultType", XSD::QName.new(NsC_1, "SpecificRequestMilingResult")]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::UpdateMilkingResultResponseType,
        :schema_name => XSD::QName.new(NsC_1, "UpdateMilkingResultResponse"),
        :schema_element => [
            ["messageHeader", ["CrvApiClient::Api::Reproduction::ADEExchangedDocumentType", XSD::QName.new(NsC_1, "MessageHeader")]],
            ["standardResponse", ["CrvApiClient::Api::Reproduction::StandardResponseType", XSD::QName.new(NsC_1, "StandardResponse")]],
            ["specificResponse", ["CrvApiClient::Api::Reproduction::SpecificResponseType", XSD::QName.new(NsC_1, "SpecificResponse")], [0, 1]]
        ]
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::MIMEMediaTypeContentType,
        :schema_name => XSD::QName.new(NsC_20130103, "MIMEMediaType")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::MeasurementUnitCommonCodeContentType,
        :schema_name => XSD::QName.new(NsC_8, "MeasurementUnitCommonCode")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::CharacterSetCodeContentType,
        :schema_name => XSD::QName.new(NsC_20130108, "CharacterSetCode")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ISO3AlphaCurrencyCodeContentType,
        :schema_name => XSD::QName.new(NsC_20120831, "ISO3AlphaCurrencyCode")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::CharacterSetEncodingCodeContentType,
        :schema_name => XSD::QName.new(NsC_40106, "CharacterSetEncodingCode")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::AgencyIdentificationCodeContentType,
        :schema_name => XSD::QName.new(NsD12A, "AgencyIdentificationCode")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ISOTwoletterCountryCodeIdentifierContentType,
        :schema_name => XSD::QName.new(NsSecondEdition2006VI13, "ISOTwoletterCountryCodeIdentifier")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::GenderCodeType,
        :schema_name => XSD::QName.new(NsC_10, "GenderCode")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::LivestockLocationIdentifierCodeType,
        :schema_name => XSD::QName.new(NsC_10_0, "LivestockLocationIdentifierCode")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::LivestockLocationTypeCodeType,
        :schema_name => XSD::QName.new(NsC_10_1, "LivestockLocationTypeCode")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::MilkingTypeCodeType,
        :schema_name => XSD::QName.new(NsC_10_2, "MilkingTypeCode")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::LabelCodeType,
        :schema_name => XSD::QName.new(NsC_10_3, "LabelCode")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ValidSampleFillingIndicatorCodeType,
        :schema_name => XSD::QName.new(NsC_10_4, "ValidSampleFillingIndicatorCode")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::BottleIdentifierCodeType,
        :schema_name => XSD::QName.new(NsC_10_5, "BottleIdentifierCode")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::RequestProcessingStatusCodeType,
        :schema_name => XSD::QName.new(NsC_10_6, "RequestProcessingStatusCode")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ErrorSeverityCodeType,
        :schema_name => XSD::QName.new(NsC_10_7, "ErrorSeverityCode")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::SpecieCodeType,
        :schema_name => XSD::QName.new(NsC_10_8, "SpecieCode")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::MilkCharacteristicCodeType,
        :schema_name => XSD::QName.new(NsC_10_9, "MilkCharacteristicCode")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::QuarterCodeType,
        :schema_name => XSD::QName.new(NsC_10_10, "QuarterCode")
    )

    LiteralRegistry.register(
        :class => CrvApiClient::Api::Reproduction::ManufacturerCodeType,
        :schema_name => XSD::QName.new(NsC_10_11, "ManufacturerCode")
    )
  end

end
